@@ -5,9 +5,9 @@
 ** analyst.cpp
 ** analyse the game and play
 **
-** Version : $Id: analyst.cpp,v 1.19 2004/04/06 22:02:18 lusum Exp $
+** Version : $Id: analyst.cpp,v 1.34 2004/10/09 13:18:51 audoux Exp $
 **
-** Author(s) : Pascal Audoux - Carlo
+** Author(s) : Pascal Audoux - Sardi Carlo
 **
 ** Date : 06/02/2001
 **
@@ -35,7 +35,9 @@
 #include "libCommon/calendar.h"
 #include "libCommon/dataTheme.h"
 #include "libCommon/genericBase.h"
+#include "libCommon/genericBonus.h"
 #include "libCommon/genericBuilding.h"
+#include "libCommon/genericChest.h"
 #include "libCommon/genericLord.h"
 #include "libCommon/genericMap.h"
 #include "libCommon/genericEvent.h"
@@ -70,7 +72,11 @@ Analyst::Analyst()
 		_lords[i] = new GenericLord();
 		_lords[i]->setId( i );
 	}*/
-
+	_numTurn=-1;
+	_numlords=0;
+	for(int i = PR_ENEMY;i<=PR_LAST;i++){ 
+		_priorities[i]=i;
+	}	
 }
 
 Analyst::~Analyst()
@@ -80,25 +86,31 @@ Analyst::~Analyst()
 	delete _calendar;
 }
 
-void Analyst::reinit()
+void Analyst::reinitAi()
 {
+	reinit();
 
-	delete _player;
-	delete _map;
-	delete _calendar;
+	//XXX : cause bug, but to use when socket api will change
+	//delete _player;
+	//delete _map;
+	//delete _calendar;
 	
 	_fight = 0;
-	_calendar = new Calendar();
+	//_calendar = new Calendar();
 	_calendar->reinit();
 
-	_map = new GenericMap();
-	_player = new GenericPlayer( _map );
+	//_map = new GenericMap();
+	//_player = new GenericPlayer( _map );
 
 	/*_lords = new GenericLord * [ DataTheme.lords.count() ];
 	for( uint i = 0; i < DataTheme.lords.count(); i++ ) {
 		_lords[i] = new GenericLord();
 		_lords[i]->setId( i );
 	}*/
+	_player->cleanData();
+	_map->cleanData();
+	_numTurn=-1;
+	_numlords=0;
 
 }
 
@@ -195,7 +207,7 @@ void Analyst::socketFight()
 
 	switch( _socket->getCla2() ) {
 	case C_FIGHT_INIT:
-		ialogN( "INIT" );
+		ialogN( "FIGHT INIT" );
 		if( ! _fight ) {
 			_fight = new FightAnalyst( this );
 			_fight->setSocket( _socket );
@@ -203,10 +215,16 @@ void Analyst::socketFight()
 		_fight->handleFightSocket();
 		break;
 	case C_FIGHT_END:
-		ialogN( "END" );
+		ialogN( "FIGHT END" );
+		bool isCrea;
+		isCrea	= _fight->IsCreature(); 
+		_fight->updateUnits();
 		delete _fight;
 		_fight = 0;
-		_socket->sendLordTurn( PL_SAME_LORD );
+		if(InTurn() && isCrea){ 
+		ialogV( "FIGHT END creature" );
+			_socket->sendLordTurn( PL_SAME_LORD );
+		}
 		break;
 	default:
 		if( _fight ) {
@@ -226,6 +244,26 @@ void Analyst::socketFight()
 void Analyst::socketQR()
 {
 	ialogV( "SO_QR" );
+	switch( _socket->getCla2() ) {
+	case C_QR_MSG_NEXT: 
+		break;
+	case C_QR_MSG_END:
+		/// XXX: maybe we can display in log the msg...
+		break;
+	case C_QR_LEVEL: {
+		ialogV( "level" );
+		//_socket->sendAnswer( 0 );
+		} break;
+	case C_QR_CHEST: {
+		ialogV( "Chest" );
+		_socket->sendAnswerEnum( 0 );
+		_socket->sendLordTurn( PL_SAME_LORD );
+		} break;
+	case C_QR_ANSWER:
+		logEE( "Should not happen" );
+		break;
+	}
+
 }
 
 void Analyst::socketExch()
@@ -373,12 +411,12 @@ void Analyst::socketModif()
 	case C_MOD_CELL:
 		socketModifCell();
 		break;
-	case C_MOD_LORD:
-		socketModifLord();
-		break;
 	case C_MOD_PLAYER:
 		socketModifPlayer();
 		break;
+	case C_MOD_LORD:
+		socketModifLord();
+		break;
 	case C_MOD_BASE:
 		socketModifBase();
 		break;
@@ -516,18 +554,24 @@ void Analyst::socketModifLordVisit()
 	int row = _socket->readInt();
 	int col = _socket->readInt();
 	uchar id = _socket->readChar();
+	uchar present = _socket->readChar();
 
-	/// XXX: memory leak no new -> use _lords (cf game.cpp too !!)
-	GenericLord * lord = _lords.at( id );
+		/// XXX: memory leak no new -> use _lords (cf game.cpp too !!)
+		GenericLord * lord = _lords.at( id );
+	
+		if( present == 1 ) {
 
-	//new GenericLord();
-	//lord->setActive( true );
-	//lord->setId( id );
-	/// XXX: change
-	lord->setOwner( 0 );
-	lord->moveTo( _map->at( row, col ) );
-	//_lords.at( id ) = lord;
+			//new GenericLord();
+			//lord->setActive( true );
+			//lord->setId( id );
+			/// XXX: change
+			lord->setOwner( 0 );
+			lord->moveTo( _map->at( row, col ) );
+			//_lords.at( id ) = lord;
 
+		} else {
+			lord->getCell()->setLord(NULL);
+		}
 }
 
 void Analyst::socketModifLordNew()
@@ -550,13 +594,20 @@ void Analyst::socketModifLordUnit()
 	uchar race = _socket->readChar();
 	uchar level = _socket->readChar();
 	int nb = _socket->readInt();
-
-	GenericFightUnit * unit = new GenericFightUnit();
-	unit->setCreature( race, level );
+	GenericFightUnit * unit = 0;
+	unit =_lords.at( id )->getUnit( num );
+	if(!unit){
+		unit = new GenericFightUnit();
+		unit->setCreature( race, level );
+		unit->setMove( _socket->readChar() );
+		unit->setHealth( _socket->readInt() );
+	}
+	
 	unit->setNumber( nb );
-	unit->setMove( _socket->readChar() );
-	unit->setHealth( _socket->readInt() );
-
+	if( nb == 0){
+		delete unit;
+		unit = 0;
+	}
 	_lords.at( id )->setUnit( num, unit );
 	/// XXX: remove/delete old unit ??
 }
@@ -566,24 +617,19 @@ void Analyst::socketModifLordRemove()
 	int idLord = _socket->readChar();
 	GenericLord * lord = _lords.at( idLord );
 	GenericPlayer * player = lord->getOwner();
-	if( player ) {
-		player->removeLord( lord );
-		if( player == _player ) {
+
+	lord->removeFromGame();
+
+	/* if our turn (numTurn !=-1) pass, else do nothing*/
+	if(InTurn()){
+		if( player && player == _player ) {
+			/*our lord is dead */
 			_socket->sendLordTurn( PL_PASS_TURN );
 		} else {
+			/* enemy */
 			_socket->sendLordTurn( PL_SAME_LORD );
 		}
 	}
-
-	GenericCell * cell = lord->getCell();
-	if( cell ) {
-		cell->setLord( 0 );
-	}
-	lord->reinit();
-
-	//XXX: Remove lord from map
-	delete lord;
-	//if( lord ) lord->getOwner()->removeLord( lord );
 }
 
 void Analyst::socketModifPlayer()
@@ -612,6 +658,9 @@ void Analyst::socketModifBase()
 	case C_BASE_UNIT:
 		socketModifBaseUnit();
 		break;
+	case C_BASE_POPUL:
+		socketModifBasePopulation();
+		break;
 	}
 }
 
@@ -654,6 +703,17 @@ void Analyst::socketModifBaseOwner()
 	}
 }
 
+void Analyst::socketModifBasePopulation()
+{
+	int row = _socket->readInt();
+	int col = _socket->readInt();
+	uint popul = _socket->readChar();
+	GenericBase * base = (GenericBase*) _map->at( row, col )->getBase();
+
+	if(base)
+		base->setPopulation(popul);	
+}
+
 void Analyst::socketModifBaseBuilding()
 {
 	int row = _socket->readInt();
@@ -742,6 +802,17 @@ GenericArtefact * Analyst::getArtefactById( int id )
 	return ret;
 }
 
+GenericPlayer * Analyst::getPlayer( uint num )
+{
+	GenericPlayer * ret = 0;
+	
+	if( num < _players.count() ) {
+		ret = _players.at( num );
+	}
+	
+	return ret;
+}
+
 void Analyst::socketModifEvent()
 {
 	switch( _socket->getCla3() ) {
@@ -763,11 +834,26 @@ void Analyst::socketModifEvent()
 			artefact->setId( id );
 			artefact->setType( typeArtefact );
 		} else if( type == GenericEvent::EventBonus ) {
-			/// XXX: todo (bonus)
-		} else if( type == GenericEvent::EventChest ) {
-			/// XXX: todo (chest)
+		uchar typeBonus = _socket->readChar();
+		uchar nbParam = _socket->readChar();
+
+		GenericBonus * bonus = new GenericBonus( );
+		event->setBonus( bonus );
+		bonus->setType( (GenericBonus::BonusType) typeBonus );
+		for( uint i = 0; i < nbParam; i++ ) {
+			bonus->addParam( _socket->readInt() );
 		}
+		bonus->setupBonus();
+	} else if( type == GenericEvent::EventChest ) {
+		uchar nbParam = _socket->readChar();
+
+		GenericChest * chest = new GenericChest();
+		event->setChest( chest );
+		for( uint i = 0; i < nbParam; i++ ) {
+			chest->addParam( _socket->readInt() );
 		}
+	}
+	}
 		break;
 	case C_EVENT_DEL: {
 		int row = _socket->readInt();
@@ -816,12 +902,17 @@ void Analyst::socketTurn()
 	ialogV( "SO_TURN" );
 
 	switch( _socket->getCla2() ) {
-	case C_TURN_BEG:
-		socketTurnBegin();
-		break;
-	case C_TURN_PLAY:
-		ialogV( "Player: %d", _socket->readChar() );
-		break;
+	//case C_TURN_BEG:
+	//	socketTurnBegin();
+	//	break;
+	case C_TURN_PLAY: {
+			uint num = _socket->readChar();
+			if( num == _player->getNum() ) {
+				socketTurnBegin();
+			} else {
+				ialogV( "Player: %d,get num %d", num,_player->getNum() );
+			}
+		} break;
 	case C_TURN_END:
 		ialogC( "Should not happen (SO_TURN/C_TURN_END)" );
 		break;
@@ -830,11 +921,17 @@ void Analyst::socketTurn()
 		break;
 	case C_TURN_PLORD:{
 		int nlord = _socket->readInt();
-		_numlords = _player->numLord();
-		if( nlord >= _numlords || _numTurn==0){
-			_socket->sendTurnEnd();
-		} else {
-			playLordTurn(nlord);
+		ialogV("nlord %d",nlord);
+		if(InTurn()){
+			_numlords = _player->numLord();
+			if( nlord >= _numlords || _numTurn==0 || _numlords == 0){
+				ialogN("End turn");
+				_socket->sendTurnEnd();
+				_numTurn=-1;
+			} else {
+				ialogN("Play lord turn");
+				playLordTurn(nlord);
+			}
 		}
 		} break;
 	}
@@ -848,7 +945,6 @@ void Analyst::socketTurnBegin()
 		_player->newWeek();
 	}
 	_player->newTurn();
-//	_fightCpt = PL_PASS_TURN;
 	_numTurn=2 * _player->numLord() + 4; /* workaround for weirds game bugs */
 
 	if( _player->numBase() > 0 ){
@@ -862,56 +958,63 @@ void Analyst::socketTurnBegin()
 
 void Analyst::playLordTurn( int nlord )
 {
-//	_fightCpt = PL_SAME_LORD;
-	ialogN("init lord");
+	ialogV("init lord");
 	analyzeLord( _player->getLord( nlord ) );
 }
 
 void Analyst::analyzeLord( GenericLord * lord )
 {
-	_movePoints = lord->getCharac( MOVE );
+	int movePoints = lord->getCharac( MOVE );
 	GenericCell * cell = lord->getCell();
-	_rowFlee = 1;
-	_colFlee = 1;
+	GenericCell * destinationCell;
+		
+	struct aiData *data;
+	data = new aiData;
 
-	_startApprRow = 0;
-	_startApprCol = 0;
+	data->rowFlee = 1;
+	data->colFlee = 1;
+	data->startApprRow = 0;
+	data->startApprCol = 0;
+	data->destinationCell = cell;
+	data->curPrior = PR_LAST;
+	data->mincost = movePoints + 10;
+	data->fightCpt = _fightCpt;
 
-	_prior = PR_LAST;
-	_mincost = _movePoints+10;
 	_map->getPath()->reinit( _map );
 	_map->getPath()->computePath( cell );
 	
 	if(noPath(cell)){
 		ialogV("no path");
-		_movePoints=0;
+		movePoints=0;
 	}
 		
 
-	if( _movePoints > 0 ) {
-		analyzeLordMap( lord );
+	if( movePoints > 0 ) {
+		analyzeLordMap( lord, data );
+		_fightCpt = data->fightCpt;
+		destinationCell = data->destinationCell;
 		
 		if( _fightCpt == PL_SAME_LORD_NOFIGHT) {
-			randomPath(cell);
+			destinationCell = randomPath(lord,data);
 		}
 
-		if(_destinationCell  == cell){
+		if(destinationCell  == cell){
 			ialogN("no good");
 			_fightCpt=PL_PASS_TURN;
 		}
 
-		ialogV("flee row %d, col %d, fightCpt %d",_rowFlee,_colFlee,_fightCpt);
+		ialogV("flee row %d, col %d, fightCpt %d",data->rowFlee,data->colFlee,_fightCpt);
 		ialogV("startRow %d, startCol %d",cell->getRow(),cell->getCol());
-		ialogV("destRow %d, destCol %d",_destinationCell->getRow(),_destinationCell->getCol());
+		ialogV("destRow %d, destCol %d",destinationCell->getRow(),destinationCell->getCol());
 
 		if(_fightCpt==PL_SAME_LORD_NOFIGHT){
 		/* if no possibility to move, destination cell = starting cell and sanity check*/
-			if(_map->getPath()->getDist(_destinationCell)>_movePoints || (_map->getPath()->isPath(_destinationCell)==false))  {
-				_destinationCell  = cell;
+			if(lord->computeCostMvt(destinationCell) > movePoints || (_map->getPath()->isPath(destinationCell)==false))  {
+				destinationCell  = cell;
 				_fightCpt=PL_PASS_TURN;
 			}
-			if(_map->getPath()->isPath(_destinationCell)==true && _destinationCell  != cell){
-				QStack<GenericCell> * path = _map->getPath()->giveCells( _destinationCell );
+			if(_map->getPath()->isPath(destinationCell)==true && destinationCell  != cell){
+				QPtrStack<GenericCell> * path = _map->getPath()->giveCells( destinationCell );
 				while( ! path->isEmpty() ) {
 					GenericCell * movCell = path->pop();
 					_socket->sendMvt(lord->getId(), movCell->getRow(), movCell->getCol() );
@@ -919,13 +1022,13 @@ void Analyst::analyzeLord( GenericLord * lord )
 				delete path;
 			}
 		}else{
-			if(_map->getPath()->isNearPath(_destinationCell)==true && _destinationCell  != cell){
-				QStack<GenericCell> * path = _map->getPath()->giveNearCells( _destinationCell );
+			if(_map->getPath()->isNearPath(destinationCell)==true && destinationCell  != cell){
+				QPtrStack<GenericCell> * path = _map->getPath()->giveNearCells( destinationCell );
 				while( ! path->isEmpty() ) {
 					GenericCell * movCell = path->pop();
 					_socket->sendMvt(lord->getId(), movCell->getRow(), movCell->getCol() );
 				}
-				_socket->sendMvt(lord->getId(), _destinationCell->getRow(), _destinationCell->getCol() );
+				_socket->sendMvt(lord->getId(), destinationCell->getRow(), destinationCell->getCol() );
 				delete path;
 			}
 		}
@@ -938,54 +1041,56 @@ void Analyst::analyzeLord( GenericLord * lord )
 		_fightCpt=PL_SAME_LORD;
 	}
 		_numTurn--;
-		ialogV("Turn finish");
+		ialogV("Turn finish %d",_fightCpt);
 	_socket->sendLordTurn(_fightCpt);
+	delete data;
 }
 
-void Analyst::analyzeLordMap( GenericLord * lord )
+void Analyst::analyzeLordMap( GenericLord * lord ,struct aiData * data)
 {
 	unsigned int i, j;
 	GenericCell * cell;
 
 	int opPower;
-	int cost;
+	//int cost;
 
-	_fightCpt = PL_SAME_LORD_NOFIGHT;
+	data->fightCpt = PL_SAME_LORD_NOFIGHT;
+	/* the priority with lower value is the more important*/
 		
 	for( i = 0; i < _map->getHeight(); i++ ) {
 		for( j = 0; j < _map->getWidth(); j++ ) {
 			cell = _map->at( i, j );
-			if( cell->getLord() && ( PR_ENEMY <= _prior ) && cell->getCoeff() != -1 ) {
+			if( cell->getLord() && ( lord->getPrio(PR_ENEMY) <= data->curPrior ) && cell->getCoeff() != -1 ) {
 				if( cell->getLord()->getOwner() != _player ) {
 					opPower = getRandPower( cell->getLord() );
-					manageMeetings(lord,cell ,PR_ENEMY,opPower,1);
+					ialogN( "Try Enemy");
+					data->fightCpt=manageMeetings(lord,cell ,lord->getPrio(PR_ENEMY),opPower,true,data);
 				}
-			} else if( cell->getBase() && (PR_BASE	<= _prior ) && cell->getCoeff() != -1 )	{
+			} else if( cell->getBase() && (lord->getPrio(PR_BASE)	<= data->curPrior ) && cell->getCoeff() != -1 )	{
 				if( cell->getBase()->getOwner() != _player || cell->getBase()->isUnitBought() ) {
 					ialogN( "Try Base");
-					manageMeetings(lord,cell ,PR_BASE,0,0);
+					data->fightCpt=manageMeetings(lord,cell ,lord->getPrio(PR_BASE),0,false,data);
 				}
-			} else if( cell->getBuilding() && (PR_BUILD <= _prior) && cell->getCoeff() != -1 ) {
+			} else if( cell->getBuilding() && (lord->getPrio(PR_BUILD) <= data->curPrior) && cell->getCoeff() != -1 ) {
 				if( cell->getBuilding()->getOwner() != _player ) {
-					manageMeetings(lord,cell ,PR_BUILD,0,0);
-					cost = _map->getPath()->getDist( cell );
 					ialogN( "Try Build");
+					data->fightCpt=manageMeetings(lord,cell ,lord->getPrio(PR_BUILD),0,false,data);
 				}
 			} else if( cell->getEvent()){
-				if(cell->getEvent()->getType()==GenericEvent::EventArtefact && ( PR_ART < _prior ) && ( cell->getCoeff() != -1 ) )	{
+				if(cell->getEvent()->getType()==GenericEvent::EventArtefact && ( lord->getPrio(PR_ART) < data->curPrior ) && ( cell->getCoeff() != -1 ) )	{
 					ialogN( "Try Event-Artefact");
-					manageMeetings(lord,cell ,PR_ART,0,0);
-				} else if( cell->getEvent()->getType()==GenericEvent::EventBonus && ( PR_BONUS < _prior ) && ( cell->getCoeff() != -1 ) )	{
+					data->fightCpt=manageMeetings(lord,cell ,lord->getPrio(PR_ART),0,false,data);
+				} else if( cell->getEvent()->getType()==GenericEvent::EventBonus && ( lord->getPrio(PR_BONUS) < data->curPrior ) && ( cell->getCoeff() != -1 ) )	{
 					ialogN( "Try Event-Bonus");
-					manageMeetings(lord,cell ,PR_BONUS,0,0);
-				} else if( cell->getEvent()->getType()==GenericEvent::EventChest && ( PR_CHEST < _prior ) && ( cell->getCoeff() != -1 ) )	{
+					data->fightCpt=manageMeetings(lord,cell ,lord->getPrio(PR_BONUS),0,false,data);
+				} else if( cell->getEvent()->getType()==GenericEvent::EventChest && ( lord->getPrio(PR_CHEST)< data->curPrior ) && ( cell->getCoeff() != -1 ) )	{
 					ialogN( "Try Event-chest");
-					manageMeetings(lord,cell ,PR_CHEST,0,0);
+					data->fightCpt=manageMeetings(lord,cell ,lord->getPrio(PR_CHEST),0,false,data);
 				}
-			} else if( cell->getCreature() && (PR_CREAT < _prior) && ( cell->getCoeff() != -1 ) ){
+			} else if( cell->getCreature() && (lord->getPrio(PR_CREAT) < data->curPrior) && ( cell->getCoeff() != -1 ) ){
 				ialogN( "Try Creat");
 				opPower = getCreaturePower( cell->getCreature() );
-				manageMeetings(lord,cell ,PR_CREAT,opPower,0);
+				data->fightCpt=manageMeetings(lord,cell ,lord->getPrio(PR_CREAT),opPower,false,data);
 			}
 		}//for i
 	}//for j
@@ -995,20 +1100,58 @@ void Analyst::analyzeLordMap( GenericLord * lord )
 void Analyst::socketGame()
 {
 	ialogN( "SO_GAME" );
-	if( _socket->getCla2() == C_GAME_END ) {
-		reinit();
-		//_player->cleanData();
-		//_map->cleanData();
-		//_calendar->reinit();
-	} else if( _socket->getCla2() == C_GAME_LOST ) {
-		int nb = _socket->readChar();
-		ialogN("player %d has lost",nb);
-		//reinit();
-		//_player->cleanData();
-		//_map->cleanData();
+	switch( _socket->getCla2() ) {
+		case C_GAME_END :	{
+		  reinitAi();
+		  ialogN( "SO_GAME_END" );
+			}
+			break;
+		case C_GAME_LOST : {
+		  int nb = _socket->readChar();
+		  ialogN("player %d has lost",nb);
+		  ialogN( "SO_GAME_LOST" );
+			}
+			break;
+		case C_GAME_WIN : {
+		  int nb = _socket->readChar();
+		  ialogN("player %d has win",nb);
+		  ialogN( "SO_GAME_WIN" );
+			}
+			break;
+	 	case C_GAME_BEGIN : {
+			ialogN( "SO_GAME_ BEGIN" );
+			}
+			break;
+		case C_GAME_INFO :
+			socketGameInfo();
+			break;
+		default : {
+			ialogN( "Should not happens" );
+			ialogN("sock %d ",_socket->getCla2());
+			}
+			break;
 	}
+		
 }
 
+void Analyst::socketGameInfo()
+{
+	ialogN( "SO_GAME_INFO " );
+	switch( _socket->getCla3() ) {
+	case C_INFOPLAYER_TEAM: {
+			uchar player = _socket->readChar();	
+			uchar teamId = _socket->readChar();
+			if( getPlayer( player ) ) {
+				getPlayer( player )->setTeam( teamId );
+			}
+		} break;
+	case C_INFOPLAYER_NAME:
+		break;
+	}
+
+}
+
+
 int Analyst::getRandPower( GenericLord * lord )
 {
 	int power = 0;
@@ -1098,20 +1241,32 @@ void Analyst::manageBase(GenericBase * base)
 }
 
 
-
 void Analyst::enterBase(GenericLord * lord,GenericBase * base )
 {
+	int i;
+	int j;
 
 	base->enter( lord );
+		for(i=0;i<MAX_UNIT;i++){
+			for(j=0;j<MAX_UNIT;j++){
+				if(lord->getUnit(i) && lord->getUnit(j) && i!=j){
+					if(lord->getUnit(i)->getCreature()==lord->getUnit(j)->getCreature()){
+						lord->getUnit(j)->addNumber(lord->getUnit(i)->getNumber());
+						base->setVisitorUnit(i,0);
+						_socket->sendExchangeUnit( lord, i, lord, j );
+					}
+				}
+			}
+		}
 	if(lord->countUnits()<MAX_UNIT){
-		for(int i=0;i<MAX_UNIT;i++){
-			for(int j=0;j<MAX_UNIT;j++){
+		for(i=0;i<MAX_UNIT;i++){
+			for(j=0;j<MAX_UNIT;j++){
 				if(!lord->getUnit(j) && base->getGarrisonUnit(i)){
 					lord->setUnit(j,base->getGarrisonUnit(i));
 					base->setGarrisonUnit(i,0);
 					_socket->sendExchangeBaseUnit( base, i, lord, j );
 					//ialogN("Exch ,pos i %d ,pos j %d",i,j);
-				}
+				} 
 				if(lord->getUnit(j) && base->getGarrisonUnit(i)){
 					if(lord->getUnit(j)->getCreature()==base->getGarrisonUnit(i)->getCreature()){
 						lord->getUnit(j)->addNumber(base->getGarrisonUnit(i)->getNumber());
@@ -1127,83 +1282,91 @@ void Analyst::enterBase(GenericLord * lord,GenericBase * base )
 }
 
 
-int Analyst::manageMeetings(GenericLord * lord,GenericCell * cell ,int prior,int opPower, int isFlee )
+int Analyst::manageMeetings(GenericLord * lord,GenericCell * cell ,int prior,int opPower, bool isFlee, struct aiData * data )
 {
 	int cost;
 	int startRow = lord->getCell()->getRow();
 	int startCol = lord->getCell()->getCol();
 	int myPower = getPower( lord );
 	GenericCell * tcell;
-	int i=cell->getRow();
-	int j=cell->getCol();
+	int dRow = cell->getRow();
+	int dCol = cell->getCol();
+	int movePoints = lord->getCharac( MOVE );
 
 	if(opPower>0)
 		ialogN("opPower %d, myPower %d",opPower,myPower);	
 
-	_fightCpt = PL_SAME_LORD_NOFIGHT;
 	tcell=_map->getPath()->getNearCell(	cell );
 	cost = _map->getPath()->getDist( tcell );
-	if( _prior > prior ) {
-		_mincost = _movePoints+10;
+	/* if they are more targets with same priority, use that with minimal cost*/
+	if( data->curPrior > prior ) {
+		data->mincost = movePoints+10;
 	}
-	if( ( cost < _mincost ) && ( cost <= _movePoints )
+	
+	/* is the target is reachable, go */
+	if( ( cost < data->mincost ) && ( cost <= movePoints )
 			&& ( cost > 0 ) && ( myPower > opPower ) ) {
-//		if(opPower>0){
-			_fightCpt = PL_SAME_LORD;
-//		}
-		_destinationCell = cell;
-		_mincost = cost;
-		_prior = prior;
+		data->destinationCell = cell;
+		data->mincost = cost;
+		data->curPrior = prior;
 		ialogN("Meeting");
-		return true;
-	} else if( cost < (_movePoints + 5 ) && cost != -1 ) {
-		if( ( startRow - i ) > 0 ) {
-			_startApprRow = i;
-			if( myPower < opPower && isFlee==1) {
-				_startApprRow = startRow;
+		return PL_SAME_LORD;
+		
+	/* else go near target (or flee if enemy is more powerful) */
+	} else if( cost < ( movePoints + 5 ) && cost != -1 ) {
+		if(  startRow > dRow ) {
+			data->startApprRow = dRow;
+			if( myPower < opPower && isFlee) {
+				data->startApprRow = startRow;
+				data->rowFlee = 1;
 			}
 		} else {
-			_startApprRow = startRow;
-			if( myPower < opPower && isFlee==1) {
-				_rowFlee = -1;
+			data->startApprRow = startRow;
+			if( myPower < opPower && isFlee) {
+				data->startApprRow = dRow;
+				data->rowFlee = -1;
 			}
 		}
-		if( ( startCol - j ) > 0 ){
-			_startApprCol = j;
-			if( myPower < opPower && isFlee==1) {
-				_startApprCol = startCol;
+		if( startCol > dCol ){
+			data->startApprCol = dCol;
+			if( myPower < opPower && isFlee) {
+				data->startApprCol = startCol;
+				data->colFlee = 1;
 			}
 		} else {
-			_startApprCol = startCol;
-			if( myPower < opPower && isFlee==1) {
-				_colFlee = -1;
+			data->startApprCol = startCol;
+			if( myPower < opPower && isFlee) {
+				data->startApprCol = dCol;
+				data->colFlee = -1;
 			}
 		}
-		if( myPower < opPower && isFlee==1) {
-			_prior = prior;
+		
+		if( myPower < opPower && isFlee) {
+			data->curPrior = prior;
 		}
 	}
-	return false;
+	return PL_SAME_LORD_NOFIGHT;
 }
 
-void Analyst::randomPath(GenericCell * cell )
+GenericCell * Analyst::randomPath(GenericLord * lord, struct aiData * data)
 {
 
-		int startRow= cell->getRow();
-		int startCol= cell->getCol();
+		int movePoints = lord->getCharac( MOVE );
+		int startRow= lord->getCell()->getRow();
+		int startCol= lord->getCell()->getCol();
 		int sameTry=0;
 		int moreTry=0;
 		int i,j;
 		long he = (long)_map->getHeight();
 		long wi = (long)_map->getWidth();
-
+		 
 		do {
 			do {
-				if( _startApprRow ) {
-					i = _startApprRow + (_rowFlee)*(int)(_movePoints*(rand()/(RAND_MAX+1.0)));
+				if( data->startApprRow ) {
+					i = data->startApprRow + ( data->rowFlee)*(int)( movePoints*(rand()/(RAND_MAX+1.0)));
 					moreTry++;
-					if(moreTry>19){
-						i=_startApprRow;
+					if(moreTry>19 ) {
+						i=data->startApprRow;
 					}	
 				} else {
 					i=(int) (he*(rand()/(RAND_MAX+1.0)));
@@ -1211,11 +1374,11 @@ void Analyst::randomPath(GenericCell * cell )
 			}while(i>=(int) he || i<0);
 			moreTry=0;
 			do{
-				if(_startApprCol){
-					j=_startApprCol+(_colFlee)*(int)(_movePoints*(rand()/(RAND_MAX+1.0)));
+				if(data->startApprCol){
+					j=data->startApprCol+(data->colFlee)*(int)( movePoints*(rand()/(RAND_MAX+1.0)));
 					moreTry++;
-					if(moreTry>19){
-						j=_startApprCol;
+					if(moreTry>19 ){
+						j=data->startApprCol;
 					}	
 				} else {
 					j=(int) (wi*(rand()/(RAND_MAX+1.0)));
@@ -1225,12 +1388,12 @@ void Analyst::randomPath(GenericCell * cell )
 			if( i == startRow && j == startCol ){
 				sameTry++;
 			} else {
-				if(_map->getPath()->getDist(_map->at(i, j))<=_movePoints && (_map->getPath()->isPath(_map->at(i, j))==true))  {
-					sameTry=20;
+				if( lord->computeCostMvt(_map->at(i, j))<= movePoints && (_map->getPath()->isPath(_map->at(i, j))==true) && lord->computeCostMvt(_map->at(i, j)) > 0)  {
+					sameTry=30;
 				}
 			}
-		} while( (_map->getPath()->getDist(_map->at(i, j))>_movePoints || _map->getPath()->isPath(_map->at(i, j))==false) && sameTry<20 );
-		_destinationCell = _map->at( i, j );
+		} while(( lord->computeCostMvt(_map->at(i, j)) > movePoints || _map->getPath()->isPath(_map->at(i, j))==false) && sameTry<30 );
+		return _map->at( i, j );
 }
 
 int Analyst::noPath(GenericCell * cell)
