@@ -1,4 +1,19 @@
 <!DOCTYPE TS><TS>
+<context>
+    <name>ArtefactAction</name>
+    <message>
+        <source>Add</source>
+        <translation type="unfinished">Hinzufügen</translation>
+    </message>
+    <message>
+        <source>Edit</source>
+        <translation type="unfinished">Bearbeiten</translation>
+    </message>
+    <message>
+        <source>Del</source>
+        <translation type="unfinished">Entfernen</translation>
+    </message>
+</context>
 <context>
     <name>AskCost</name>
     <message>
@@ -17,6 +32,21 @@
         <translation type="unfinished">Entfernen</translation>
     </message>
 </context>
+<context>
+    <name>BuildingAction</name>
+    <message>
+        <source>Add</source>
+        <translation type="unfinished">Hinzufügen</translation>
+    </message>
+    <message>
+        <source>Edit</source>
+        <translation type="unfinished">Bearbeiten</translation>
+    </message>
+    <message>
+        <source>Del</source>
+        <translation type="unfinished">Entfernen</translation>
+    </message>
+</context>
 <context>
     <name>DecorationEffect</name>
     <message>
@@ -32,6 +62,160 @@
         <translation>Entfernen</translation>
     </message>
 </context>
+<context>
+    <name>DialogArtefactAction</name>
+    <message>
+        <source>Action type: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Characteristic</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Spell</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Fixed value</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ratio</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Modification type: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Parameter: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Value: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ok</source>
+        <translation type="unfinished">Ok</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished">Abbrechen</translation>
+    </message>
+</context>
+<context>
+    <name>DialogBuildingAction</name>
+    <message>
+        <source>Action type: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Date</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>First Time</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>First Time Lord</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Next Time</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Attack</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Defense</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Power</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Knowledge</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Move</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Maxmove</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>TechPoint</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>MaxTechPoint</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Morale</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Luck</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Vision</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Experience</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Skill</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Artefact</source>
+        <translation type="unfinished">Artefakt</translation>
+    </message>
+    <message>
+        <source>Unit</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Resource</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Random Resource</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Elementary Action: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Param: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Coeff: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ok</source>
+        <translation type="unfinished">Ok</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished">Abbrechen</translation>
+    </message>
+</context>
 <context>
     <name>DialogEffect</name>
     <message>
@@ -46,6 +230,10 @@
         <source>Cancel</source>
         <translation>Abbrechen</translation>
     </message>
+    <message>
+        <source>Effect value: </source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditCost</name>
@@ -132,6 +320,29 @@
         <translation>Anzahl: </translation>
     </message>
 </context>
+<context>
+    <name>MapDispositionEditor</name>
+    <message>
+        <source>Free</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Occupied</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Door</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Columns:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rows:</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>PreviewBaseDialog</name>
     <message>
@@ -149,6 +360,30 @@
         <source>&apos; with param </source>
         <translation>&apos; mit Parameter</translation>
     </message>
+    <message>
+        <source>Action: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Charac </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Spell </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source> modify by </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>%</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source> elementary </source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SectionArtefact</name>
@@ -189,12 +424,28 @@
     </message>
     <message>
         <source>Preview</source>
-        <translation>Vorschau</translation>
+        <translation type="obsolete">Vorschau</translation>
     </message>
     <message>
         <source> Base : %d/%d</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Res Cost: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Growth: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Loss: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Preview inside</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SectionBuilding</name>
@@ -218,6 +469,14 @@
         <source>Picture: </source>
         <translation>Bild: </translation>
     </message>
+    <message>
+        <source>Number Frames: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Animation Freq.: </source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SectionCreature</name>
@@ -265,11 +524,18 @@
         <translation>Bild:</translation>
     </message>
 </context>
+<context>
+    <name>SectionExperience</name>
+    <message>
+        <source>List of required experience to gain for accessing the next level:</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>SectionGeneral</name>
     <message>
         <source>Fog of war</source>
-        <translation>Fog of war</translation>
+        <translation type="obsolete">Fog of war</translation>
     </message>
     <message>
         <source>Number of unit/lord</source>
@@ -279,6 +545,10 @@
         <source>Logo (200x180): </source>
         <translation>Logo(200x180):</translation>
     </message>
+    <message>
+        <source>Vision management: </source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SectionGround</name>
@@ -333,6 +603,14 @@
         <source> Building : %d/%d</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Action: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Params: </source>
+        <translation type="unfinished">Parameter:</translation>
+    </message>
 </context>
 <context>
     <name>SectionLord</name>
@@ -358,7 +636,7 @@
     </message>
     <message>
         <source>Race : </source>
-        <translation>Rasse:</translation>
+        <translation type="obsolete">Rasse:</translation>
     </message>
     <message>
         <source>Attack : </source>
@@ -384,6 +662,45 @@
         <source>Vision : </source>
         <translation>Sichtreichweite:</translation>
     </message>
+    <message>
+        <source> (Race: </source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>SectionLordCategory</name>
+    <message>
+        <source>Lord Categories</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Name: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Description: </source>
+        <translation type="unfinished">Beschreibung:</translation>
+    </message>
+    <message>
+        <source>Race: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Evolution of Attack skill (weight): </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Evolution of Defense skill (weight): </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Evolution of Power skill (weight): </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Evolution of Knowledge skill (weight): </source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SectionMachine</name>
@@ -481,6 +798,14 @@
         <source>War Machines</source>
         <translation>Kriegsmaschinerie</translation>
     </message>
+    <message>
+        <source>Lord Categories</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Levels</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SectionTeam</name>
@@ -582,5 +907,17 @@
         <source>F1</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Can&apos;t load theme</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Theme </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source> has not been loaded successfully</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
