@@ -1,4 +1,19 @@
 <!DOCTYPE TS><TS>
+<context>
+    <name>ArtefactAction</name>
+    <message>
+        <source>Add</source>
+        <translation>Ajouter</translation>
+    </message>
+    <message>
+        <source>Edit</source>
+        <translation>Editer</translation>
+    </message>
+    <message>
+        <source>Del</source>
+        <translation>Supprimer</translation>
+    </message>
+</context>
 <context>
     <name>AskCost</name>
     <message>
@@ -10,11 +25,26 @@
     <name>AskDiversificationList</name>
     <message>
         <source>New</source>
-        <translation type="unfinished"></translation>
+        <translation>Nouveau</translation>
     </message>
     <message>
         <source>Del</source>
-        <translation type="unfinished">Supprimer</translation>
+        <translation>Supprimer</translation>
+    </message>
+</context>
+<context>
+    <name>BuildingAction</name>
+    <message>
+        <source>Add</source>
+        <translation>Ajouter</translation>
+    </message>
+    <message>
+        <source>Edit</source>
+        <translation>Editer</translation>
+    </message>
+    <message>
+        <source>Del</source>
+        <translation>Supprimer</translation>
     </message>
 </context>
 <context>
@@ -32,6 +62,160 @@
         <translation>Supprimer</translation>
     </message>
 </context>
+<context>
+    <name>DialogArtefactAction</name>
+    <message>
+        <source>Action type: </source>
+        <translation>Type d&apos;action:</translation>
+    </message>
+    <message>
+        <source>Characteristic</source>
+        <translation>Caractéristique</translation>
+    </message>
+    <message>
+        <source>Spell</source>
+        <translation>Sort</translation>
+    </message>
+    <message>
+        <source>Fixed value</source>
+        <translation>Valeur</translation>
+    </message>
+    <message>
+        <source>Ratio</source>
+        <translation>Ratio</translation>
+    </message>
+    <message>
+        <source>Modification type: </source>
+        <translation>Type de modif:</translation>
+    </message>
+    <message>
+        <source>Parameter: </source>
+        <translation>Paramètre:</translation>
+    </message>
+    <message>
+        <source>Value: </source>
+        <translation>Valeur:</translation>
+    </message>
+    <message>
+        <source>Ok</source>
+        <translation>Ok</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation>Annuler</translation>
+    </message>
+</context>
+<context>
+    <name>DialogBuildingAction</name>
+    <message>
+        <source>Action type: </source>
+        <translation>Type d&apos;action:</translation>
+    </message>
+    <message>
+        <source>Date</source>
+        <translation>Date</translation>
+    </message>
+    <message>
+        <source>First Time</source>
+        <translation>Première fois</translation>
+    </message>
+    <message>
+        <source>First Time Lord</source>
+        <translation>Première fois pour ce seigneur</translation>
+    </message>
+    <message>
+        <source>Next Time</source>
+        <translation>Autres fois</translation>
+    </message>
+    <message>
+        <source>Attack</source>
+        <translation>Attaque</translation>
+    </message>
+    <message>
+        <source>Defense</source>
+        <translation>Défense</translation>
+    </message>
+    <message>
+        <source>Power</source>
+        <translation>Puissance</translation>
+    </message>
+    <message>
+        <source>Knowledge</source>
+        <translation>Savoir</translation>
+    </message>
+    <message>
+        <source>Move</source>
+        <translation>Déplacement</translation>
+    </message>
+    <message>
+        <source>Maxmove</source>
+        <translation>Déplacement max</translation>
+    </message>
+    <message>
+        <source>TechPoint</source>
+        <translation>Technicité</translation>
+    </message>
+    <message>
+        <source>MaxTechPoint</source>
+        <translation>Technicité max</translation>
+    </message>
+    <message>
+        <source>Morale</source>
+        <translation>Moral</translation>
+    </message>
+    <message>
+        <source>Luck</source>
+        <translation>Chance</translation>
+    </message>
+    <message>
+        <source>Vision</source>
+        <translation>Vision</translation>
+    </message>
+    <message>
+        <source>Experience</source>
+        <translation>Expérience</translation>
+    </message>
+    <message>
+        <source>Skill</source>
+        <translation>Compétence</translation>
+    </message>
+    <message>
+        <source>Artefact</source>
+        <translation>Artefact</translation>
+    </message>
+    <message>
+        <source>Unit</source>
+        <translation>Unité</translation>
+    </message>
+    <message>
+        <source>Resource</source>
+        <translation>Ressource</translation>
+    </message>
+    <message>
+        <source>Random Resource</source>
+        <translation>Ressource aléatoire</translation>
+    </message>
+    <message>
+        <source>Elementary Action: </source>
+        <translation>Action élémentaire :</translation>
+    </message>
+    <message>
+        <source>Param: </source>
+        <translation>Paramètre :</translation>
+    </message>
+    <message>
+        <source>Coeff: </source>
+        <translation>Coeff :</translation>
+    </message>
+    <message>
+        <source>Ok</source>
+        <translation>Ok</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation>Annuler</translation>
+    </message>
+</context>
 <context>
     <name>DialogEffect</name>
     <message>
@@ -46,6 +230,10 @@
         <source>Cancel</source>
         <translation>Annuler</translation>
     </message>
+    <message>
+        <source>Effect value: </source>
+        <translation>Effet:</translation>
+    </message>
 </context>
 <context>
     <name>EditCost</name>
@@ -132,6 +320,29 @@
         <translation>Nombre:</translation>
     </message>
 </context>
+<context>
+    <name>MapDispositionEditor</name>
+    <message>
+        <source>Free</source>
+        <translation>Libre</translation>
+    </message>
+    <message>
+        <source>Occupied</source>
+        <translation>Occupé</translation>
+    </message>
+    <message>
+        <source>Door</source>
+        <translation>Porte</translation>
+    </message>
+    <message>
+        <source>Columns:</source>
+        <translation>Colonnes : </translation>
+    </message>
+    <message>
+        <source>Rows:</source>
+        <translation>Lignes : </translation>
+    </message>
+</context>
 <context>
     <name>PreviewBaseDialog</name>
     <message>
@@ -149,6 +360,30 @@
         <source>&apos; with param </source>
         <translation>&apos; avec comme paramètre </translation>
     </message>
+    <message>
+        <source>Action: </source>
+        <translation>Action:</translation>
+    </message>
+    <message>
+        <source>Charac </source>
+        <translation>Carac</translation>
+    </message>
+    <message>
+        <source>Spell </source>
+        <translation>Sort</translation>
+    </message>
+    <message>
+        <source> modify by </source>
+        <translation>modifié par</translation>
+    </message>
+    <message>
+        <source>%</source>
+        <translation>%</translation>
+    </message>
+    <message>
+        <source> elementary </source>
+        <translation>élémentaire</translation>
+    </message>
 </context>
 <context>
     <name>SectionArtefact</name>
@@ -189,12 +424,28 @@
     </message>
     <message>
         <source>Preview</source>
-        <translation>Prévisualisation</translation>
+        <translation type="obsolete">Prévisualisation</translation>
     </message>
     <message>
         <source> Base : %d/%d</source>
         <translation>Base : %d/%d</translation>
     </message>
+    <message>
+        <source>Res Cost: </source>
+        <translation>Coût ress :</translation>
+    </message>
+    <message>
+        <source>Growth: </source>
+        <translation>Croissance : </translation>
+    </message>
+    <message>
+        <source>Loss: </source>
+        <translation>Perte : </translation>
+    </message>
+    <message>
+        <source>Preview inside</source>
+        <translation>Prévisualisation intérieur</translation>
+    </message>
 </context>
 <context>
     <name>SectionBuilding</name>
@@ -218,6 +469,14 @@
         <source>Picture: </source>
         <translation>Image :</translation>
     </message>
+    <message>
+        <source>Number Frames: </source>
+        <translation>Nombre d&apos;animations :</translation>
+    </message>
+    <message>
+        <source>Animation Freq.: </source>
+        <translation>Fréq. d&apos;animation :</translation>
+    </message>
 </context>
 <context>
     <name>SectionCreature</name>
@@ -265,11 +524,18 @@
         <translation>Image :</translation>
     </message>
 </context>
+<context>
+    <name>SectionExperience</name>
+    <message>
+        <source>List of required experience to gain for accessing the next level:</source>
+        <translation>Liste des points d&apos;expériences pour changer de niveau :</translation>
+    </message>
+</context>
 <context>
     <name>SectionGeneral</name>
     <message>
         <source>Fog of war</source>
-        <translation>Champ de vision</translation>
+        <translation type="obsolete">Champ de vision</translation>
     </message>
     <message>
         <source>Number of unit/lord</source>
@@ -279,6 +545,10 @@
         <source>Logo (200x180): </source>
         <translation>Logo (200x180) :</translation>
     </message>
+    <message>
+        <source>Vision management: </source>
+        <translation>Gestion de la vision : </translation>
+    </message>
 </context>
 <context>
     <name>SectionGround</name>
@@ -333,6 +603,14 @@
         <source> Building : %d/%d</source>
         <translation>Bâtiment : %d/%d</translation>
     </message>
+    <message>
+        <source>Action: </source>
+        <translation>Action:</translation>
+    </message>
+    <message>
+        <source>Params: </source>
+        <translation>Paramètres :</translation>
+    </message>
 </context>
 <context>
     <name>SectionLord</name>
@@ -358,7 +636,7 @@
     </message>
     <message>
         <source>Race : </source>
-        <translation>Race :</translation>
+        <translation type="obsolete">Race :</translation>
     </message>
     <message>
         <source>Attack : </source>
@@ -384,6 +662,45 @@
         <source>Vision : </source>
         <translation>Vision :</translation>
     </message>
+    <message>
+        <source> (Race: </source>
+        <translation>(Race :</translation>
+    </message>
+</context>
+<context>
+    <name>SectionLordCategory</name>
+    <message>
+        <source>Lord Categories</source>
+        <translation>Catégories des seigneurs</translation>
+    </message>
+    <message>
+        <source>Name: </source>
+        <translation>Nom :</translation>
+    </message>
+    <message>
+        <source>Description: </source>
+        <translation>Description :</translation>
+    </message>
+    <message>
+        <source>Race: </source>
+        <translation>Race :</translation>
+    </message>
+    <message>
+        <source>Evolution of Attack skill (weight): </source>
+        <translation>Evolution de l&apos;attaque (pondération) :</translation>
+    </message>
+    <message>
+        <source>Evolution of Defense skill (weight): </source>
+        <translation>Evolution de la défense (pondération) :</translation>
+    </message>
+    <message>
+        <source>Evolution of Power skill (weight): </source>
+        <translation>Evolution de la puissance (pondération) :</translation>
+    </message>
+    <message>
+        <source>Evolution of Knowledge skill (weight): </source>
+        <translation>Evolution du savoir (pondération) :</translation>
+    </message>
 </context>
 <context>
     <name>SectionMachine</name>
@@ -481,6 +798,14 @@
         <source>War Machines</source>
         <translation>Machines</translation>
     </message>
+    <message>
+        <source>Lord Categories</source>
+        <translation>Catégories des seigneurs</translation>
+    </message>
+    <message>
+        <source>Levels</source>
+        <translation>Niveaux</translation>
+    </message>
 </context>
 <context>
     <name>SectionTeam</name>
@@ -582,5 +907,17 @@
         <source>F1</source>
         <translation>F1</translation>
     </message>
+    <message>
+        <source>Can&apos;t load theme</source>
+        <translation>Impossible de charger le thème</translation>
+    </message>
+    <message>
+        <source>Theme </source>
+        <translation>Thème</translation>
+    </message>
+    <message>
+        <source> has not been loaded successfully</source>
+        <translation>n&apos;a pas été chargé correctement</translation>
+    </message>
 </context>
 </TS>
