@@ -1,4 +1,19 @@
 <!DOCTYPE TS><TS>
+<context>
+    <name>ArtefactAction</name>
+    <message>
+        <source>Add</source>
+        <translation>Aggiungi</translation>
+    </message>
+    <message>
+        <source>Edit</source>
+        <translation>Modifica</translation>
+    </message>
+    <message>
+        <source>Del</source>
+        <translation>Cancella</translation>
+    </message>
+</context>
 <context>
     <name>AskCost</name>
     <message>
@@ -17,6 +32,21 @@
         <translation>Cancella</translation>
     </message>
 </context>
+<context>
+    <name>BuildingAction</name>
+    <message>
+        <source>Add</source>
+        <translation>Aggiungi</translation>
+    </message>
+    <message>
+        <source>Edit</source>
+        <translation>Modifica</translation>
+    </message>
+    <message>
+        <source>Del</source>
+        <translation>Cancella</translation>
+    </message>
+</context>
 <context>
     <name>DecorationEffect</name>
     <message>
@@ -32,6 +62,160 @@
         <translation>Cancella</translation>
     </message>
 </context>
+<context>
+    <name>DialogArtefactAction</name>
+    <message>
+        <source>Action type: </source>
+        <translation>Tipo di azione:</translation>
+    </message>
+    <message>
+        <source>Characteristic</source>
+        <translation>Caratteristica</translation>
+    </message>
+    <message>
+        <source>Spell</source>
+        <translation>Sortilegio</translation>
+    </message>
+    <message>
+        <source>Fixed value</source>
+        <translation>Valore</translation>
+    </message>
+    <message>
+        <source>Ratio</source>
+        <translation>Percentuale</translation>
+    </message>
+    <message>
+        <source>Modification type: </source>
+        <translation>Tasso di modifica:</translation>
+    </message>
+    <message>
+        <source>Parameter: </source>
+        <translation>Parametro:</translation>
+    </message>
+    <message>
+        <source>Value: </source>
+        <translation>Valore:</translation>
+    </message>
+    <message>
+        <source>Ok</source>
+        <translation>Ok</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation>Annulla</translation>
+    </message>
+</context>
+<context>
+    <name>DialogBuildingAction</name>
+    <message>
+        <source>Action type: </source>
+        <translation>Tipo di azione:</translation>
+    </message>
+    <message>
+        <source>Date</source>
+        <translation>Data</translation>
+    </message>
+    <message>
+        <source>First Time</source>
+        <translation>Prima volta</translation>
+    </message>
+    <message>
+        <source>First Time Lord</source>
+        <translation>Prima volta signore</translation>
+    </message>
+    <message>
+        <source>Next Time</source>
+        <translation>Prossima volta</translation>
+    </message>
+    <message>
+        <source>Attack</source>
+        <translation>Attacco</translation>
+    </message>
+    <message>
+        <source>Defense</source>
+        <translation>Difesa</translation>
+    </message>
+    <message>
+        <source>Power</source>
+        <translation>Potere</translation>
+    </message>
+    <message>
+        <source>Knowledge</source>
+        <translation>Conoscenza</translation>
+    </message>
+    <message>
+        <source>Move</source>
+        <translation>Movimento</translation>
+    </message>
+    <message>
+        <source>Maxmove</source>
+        <translation>Movimento max</translation>
+    </message>
+    <message>
+        <source>TechPoint</source>
+        <translation>Punti di tecnica</translation>
+    </message>
+    <message>
+        <source>MaxTechPoint</source>
+        <translation>Max. Punti di tecnica</translation>
+    </message>
+    <message>
+        <source>Morale</source>
+        <translation>Morale</translation>
+    </message>
+    <message>
+        <source>Luck</source>
+        <translation>Fortuna</translation>
+    </message>
+    <message>
+        <source>Vision</source>
+        <translation>Visione</translation>
+    </message>
+    <message>
+        <source>Experience</source>
+        <translation>Esperienza</translation>
+    </message>
+    <message>
+        <source>Skill</source>
+        <translation>Abilità</translation>
+    </message>
+    <message>
+        <source>Artefact</source>
+        <translation>Artefatto</translation>
+    </message>
+    <message>
+        <source>Unit</source>
+        <translation>Unità</translation>
+    </message>
+    <message>
+        <source>Resource</source>
+        <translation>Risorsa</translation>
+    </message>
+    <message>
+        <source>Random Resource</source>
+        <translation>Risorsa casuale</translation>
+    </message>
+    <message>
+        <source>Elementary Action: </source>
+        <translation>Azione elementare:</translation>
+    </message>
+    <message>
+        <source>Param: </source>
+        <translation>Parametro:</translation>
+    </message>
+    <message>
+        <source>Coeff: </source>
+        <translation>Coeff:</translation>
+    </message>
+    <message>
+        <source>Ok</source>
+        <translation></translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation>Annulla</translation>
+    </message>
+</context>
 <context>
     <name>DialogEffect</name>
     <message>
@@ -44,7 +228,11 @@
     </message>
     <message>
         <source>Cancel</source>
-        <translation>Cancella</translation>
+        <translation>Annulla</translation>
+    </message>
+    <message>
+        <source>Effect value: </source>
+        <translation>Valore dell&apos;effetto:</translation>
     </message>
 </context>
 <context>
@@ -55,7 +243,7 @@
     </message>
     <message>
         <source>Cancel</source>
-        <translation>Cancella</translation>
+        <translation>Annulla</translation>
     </message>
 </context>
 <context>
@@ -132,6 +320,29 @@
         <translation>Numero:</translation>
     </message>
 </context>
+<context>
+    <name>MapDispositionEditor</name>
+    <message>
+        <source>Free</source>
+        <translation>Libero</translation>
+    </message>
+    <message>
+        <source>Occupied</source>
+        <translation>Occupato</translation>
+    </message>
+    <message>
+        <source>Door</source>
+        <translation>Entrata</translation>
+    </message>
+    <message>
+        <source>Columns:</source>
+        <translation>Colonne:</translation>
+    </message>
+    <message>
+        <source>Rows:</source>
+        <translation>Righe:</translation>
+    </message>
+</context>
 <context>
     <name>PreviewBaseDialog</name>
     <message>
@@ -149,6 +360,30 @@
         <source>&apos; with param </source>
         <translation>&apos; con parametro </translation>
     </message>
+    <message>
+        <source>Action: </source>
+        <translation>Azione:</translation>
+    </message>
+    <message>
+        <source>Charac </source>
+        <translation>Caratteristica </translation>
+    </message>
+    <message>
+        <source>Spell </source>
+        <translation>Sortilegio</translation>
+    </message>
+    <message>
+        <source> modify by </source>
+        <translation> modificata di </translation>
+    </message>
+    <message>
+        <source>%</source>
+        <translation>%</translation>
+    </message>
+    <message>
+        <source> elementary </source>
+        <translation> elementare </translation>
+    </message>
 </context>
 <context>
     <name>SectionArtefact</name>
@@ -189,12 +424,28 @@
     </message>
     <message>
         <source>Preview</source>
-        <translation>Anteprima</translation>
+        <translation type="obsolete">Anteprima</translation>
     </message>
     <message>
         <source> Base : %d/%d</source>
         <translation>Castello: %d/%d</translation>
     </message>
+    <message>
+        <source>Res Cost: </source>
+        <translation>Costo ris:</translation>
+    </message>
+    <message>
+        <source>Growth: </source>
+        <translation>Crescita:</translation>
+    </message>
+    <message>
+        <source>Loss: </source>
+        <translation>Diminuzione:</translation>
+    </message>
+    <message>
+        <source>Preview inside</source>
+        <translation>Anteprima interno</translation>
+    </message>
 </context>
 <context>
     <name>SectionBuilding</name>
@@ -218,6 +469,14 @@
         <source>Picture: </source>
         <translation>Immagine:</translation>
     </message>
+    <message>
+        <source>Number Frames: </source>
+        <translation>Numero di frame:</translation>
+    </message>
+    <message>
+        <source>Animation Freq.: </source>
+        <translation>Frequenza di animazione:</translation>
+    </message>
 </context>
 <context>
     <name>SectionCreature</name>
@@ -265,11 +524,18 @@
         <translation>Immagine:</translation>
     </message>
 </context>
+<context>
+    <name>SectionExperience</name>
+    <message>
+        <source>List of required experience to gain for accessing the next level:</source>
+        <translation>Lista di punti esperienza richiesti per accedere al livello successivo:</translation>
+    </message>
+</context>
 <context>
     <name>SectionGeneral</name>
     <message>
         <source>Fog of war</source>
-        <translation>Nebbia di guerra</translation>
+        <translation type="obsolete">Nebbia di guerra</translation>
     </message>
     <message>
         <source>Number of unit/lord</source>
@@ -279,6 +545,10 @@
         <source>Logo (200x180): </source>
         <translation>Logo (200x180): </translation>
     </message>
+    <message>
+        <source>Vision management: </source>
+        <translation>Gestione della vista:</translation>
+    </message>
 </context>
 <context>
     <name>SectionGround</name>
@@ -329,6 +599,14 @@
         <source> Building : %d/%d</source>
         <translation>Edificio : %d/%d</translation>
     </message>
+    <message>
+        <source>Action: </source>
+        <translation>Azione:</translation>
+    </message>
+    <message>
+        <source>Params: </source>
+        <translation>Parametri:</translation>
+    </message>
 </context>
 <context>
     <name>SectionLord</name>
@@ -354,7 +632,7 @@
     </message>
     <message>
         <source>Race : </source>
-        <translation>Specie:</translation>
+        <translation type="obsolete">Specie:</translation>
     </message>
     <message>
         <source>Attack : </source>
@@ -380,6 +658,45 @@
         <source>Vision : </source>
         <translation>Visione :</translation>
     </message>
+    <message>
+        <source> (Race: </source>
+        <translation>(Specie:</translation>
+    </message>
+</context>
+<context>
+    <name>SectionLordCategory</name>
+    <message>
+        <source>Lord Categories</source>
+        <translation>Categorie dei signori</translation>
+    </message>
+    <message>
+        <source>Name: </source>
+        <translation>Nome:</translation>
+    </message>
+    <message>
+        <source>Description: </source>
+        <translation>Descrizione:</translation>
+    </message>
+    <message>
+        <source>Race: </source>
+        <translation>Specie:</translation>
+    </message>
+    <message>
+        <source>Evolution of Attack skill (weight): </source>
+        <translation>Evoluzione dell&apos;abilità attacco (peso):</translation>
+    </message>
+    <message>
+        <source>Evolution of Defense skill (weight): </source>
+        <translation>Evoluzione dell&apos;abilità difesa (peso):</translation>
+    </message>
+    <message>
+        <source>Evolution of Power skill (weight): </source>
+        <translation>Evoluzione dell&apos;abilità potere (peso):</translation>
+    </message>
+    <message>
+        <source>Evolution of Knowledge skill (weight): </source>
+        <translation>Evoluzione dell&apos;abilità conoscenza (peso):</translation>
+    </message>
 </context>
 <context>
     <name>SectionMachine</name>
@@ -477,6 +794,14 @@
         <source>War Machines</source>
         <translation>Macchine da guerra</translation>
     </message>
+    <message>
+        <source>Lord Categories</source>
+        <translation>Categorie dei signori</translation>
+    </message>
+    <message>
+        <source>Levels</source>
+        <translation>Livelli</translation>
+    </message>
 </context>
 <context>
     <name>SectionTeam</name>
@@ -578,5 +903,17 @@
         <source>F1</source>
         <translation>F1</translation>
     </message>
+    <message>
+        <source>Can&apos;t load theme</source>
+        <translation>Non posso caricare il tema</translation>
+    </message>
+    <message>
+        <source>Theme </source>
+        <translation>Il tema </translation>
+    </message>
+    <message>
+        <source> has not been loaded successfully</source>
+        <translation> non è stato caricato con successo</translation>
+    </message>
 </context>
 </TS>
