@@ -1,582 +1,919 @@
 <!DOCTYPE TS><TS>
+<context>
+    <name>ArtefactAction</name>
+    <message>
+        <source>Add</source>
+        <translation>Добавить</translation>
+    </message>
+    <message>
+        <source>Edit</source>
+        <translation>Редактировать</translation>
+    </message>
+    <message>
+        <source>Del</source>
+        <translation>Удалить</translation>
+    </message>
+</context>
 <context>
     <name>AskCost</name>
     <message>
         <source>Change</source>
-        <translation type="unfinished"></translation>
+        <translation>Изменить</translation>
     </message>
 </context>
 <context>
     <name>AskDiversificationList</name>
     <message>
         <source>New</source>
-        <translation type="unfinished"></translation>
+        <translation>Новый</translation>
     </message>
     <message>
         <source>Del</source>
-        <translation type="unfinished"></translation>
+        <translation>Удалить</translation>
+    </message>
+</context>
+<context>
+    <name>BuildingAction</name>
+    <message>
+        <source>Add</source>
+        <translation>Добавить</translation>
+    </message>
+    <message>
+        <source>Edit</source>
+        <translation>Редактировать</translation>
+    </message>
+    <message>
+        <source>Del</source>
+        <translation>Удалить</translation>
     </message>
 </context>
 <context>
     <name>DecorationEffect</name>
     <message>
         <source>Add</source>
-        <translation type="unfinished"></translation>
+        <translation>Добавить</translation>
     </message>
     <message>
         <source>Edit</source>
-        <translation type="unfinished"></translation>
+        <translation>Редактировать</translation>
     </message>
     <message>
         <source>Del</source>
-        <translation type="unfinished"></translation>
+        <translation>Удалить</translation>
+    </message>
+</context>
+<context>
+    <name>DialogArtefactAction</name>
+    <message>
+        <source>Action type: </source>
+        <translation>Тип действия:</translation>
+    </message>
+    <message>
+        <source>Characteristic</source>
+        <translation>Характеристика</translation>
+    </message>
+    <message>
+        <source>Spell</source>
+        <translation>Заклинание</translation>
+    </message>
+    <message>
+        <source>Fixed value</source>
+        <translation>Фиксированное значение</translation>
+    </message>
+    <message>
+        <source>Ratio</source>
+        <translation>Пропорция</translation>
+    </message>
+    <message>
+        <source>Modification type: </source>
+        <translation>Тип изменения:</translation>
+    </message>
+    <message>
+        <source>Parameter: </source>
+        <translation>Параметр:</translation>
+    </message>
+    <message>
+        <source>Value: </source>
+        <translation>Величина:</translation>
+    </message>
+    <message>
+        <source>Ok</source>
+        <translation>ОК</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation>Отмена</translation>
+    </message>
+</context>
+<context>
+    <name>DialogBuildingAction</name>
+    <message>
+        <source>Action type: </source>
+        <translation>Тип действия:</translation>
+    </message>
+    <message>
+        <source>Date</source>
+        <translation>Дата</translation>
+    </message>
+    <message>
+        <source>First Time</source>
+        <translation>Первый раз</translation>
+    </message>
+    <message>
+        <source>First Time Lord</source>
+        <translation>Лорд в первый раз</translation>
+    </message>
+    <message>
+        <source>Next Time</source>
+        <translation>Следующий раз</translation>
+    </message>
+    <message>
+        <source>Attack</source>
+        <translation>Атака</translation>
+    </message>
+    <message>
+        <source>Defense</source>
+        <translation>Защита</translation>
+    </message>
+    <message>
+        <source>Power</source>
+        <translation>Сила</translation>
+    </message>
+    <message>
+        <source>Knowledge</source>
+        <translation>Знание</translation>
+    </message>
+    <message>
+        <source>Move</source>
+        <translation>Движение</translation>
+    </message>
+    <message>
+        <source>Maxmove</source>
+        <translation>Максимальное движение</translation>
+    </message>
+    <message>
+        <source>TechPoint</source>
+        <translation>Техническая точка</translation>
+    </message>
+    <message>
+        <source>MaxTechPoint</source>
+        <translation>Максимальная техническа точка</translation>
+    </message>
+    <message>
+        <source>Morale</source>
+        <translation>Мораль</translation>
+    </message>
+    <message>
+        <source>Luck</source>
+        <translation>Удача</translation>
+    </message>
+    <message>
+        <source>Vision</source>
+        <translation>Дальность видения</translation>
+    </message>
+    <message>
+        <source>Experience</source>
+        <translation>Опыт</translation>
+    </message>
+    <message>
+        <source>Skill</source>
+        <translation>Навык</translation>
+    </message>
+    <message>
+        <source>Artefact</source>
+        <translation>Артефакт</translation>
+    </message>
+    <message>
+        <source>Unit</source>
+        <translation>Юнит</translation>
+    </message>
+    <message>
+        <source>Resource</source>
+        <translation>Ресурс</translation>
+    </message>
+    <message>
+        <source>Random Resource</source>
+        <translation>Случайный ресурс</translation>
+    </message>
+    <message>
+        <source>Elementary Action: </source>
+        <translation>Элементарное действие:</translation>
+    </message>
+    <message>
+        <source>Param: </source>
+        <translation>Параметр:</translation>
+    </message>
+    <message>
+        <source>Coeff: </source>
+        <translation>Коэффициент:</translation>
+    </message>
+    <message>
+        <source>Ok</source>
+        <translation>ОК</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation>Отмена</translation>
     </message>
 </context>
 <context>
     <name>DialogEffect</name>
     <message>
         <source>Effect type: </source>
-        <translation type="unfinished"></translation>
+        <translation>Тип эффекта:</translation>
     </message>
     <message>
         <source>Ok</source>
-        <translation type="unfinished"></translation>
+        <translation>ОК</translation>
     </message>
     <message>
         <source>Cancel</source>
-        <translation type="unfinished"></translation>
+        <translation>Отмена</translation>
+    </message>
+    <message>
+        <source>Effect value: </source>
+        <translation>Сила эффекта:</translation>
     </message>
 </context>
 <context>
     <name>EditCost</name>
     <message>
         <source>Ok</source>
-        <translation type="unfinished"></translation>
+        <translation>ОК</translation>
     </message>
     <message>
         <source>Cancel</source>
-        <translation type="unfinished"></translation>
+        <translation>Отмена</translation>
     </message>
 </context>
 <context>
     <name>EditCreature</name>
     <message>
         <source>Name: </source>
-        <translation type="unfinished"></translation>
+        <translation>Название:</translation>
     </message>
     <message>
         <source>Attack: </source>
-        <translation type="unfinished"></translation>
+        <translation>Атака:</translation>
     </message>
     <message>
         <source>Defense: </source>
-        <translation type="unfinished"></translation>
+        <translation>Защита:</translation>
     </message>
     <message>
         <source>Max Health: </source>
-        <translation type="unfinished"></translation>
+        <translation>Максимальное Здоровье:</translation>
     </message>
     <message>
         <source>Max Move: </source>
-        <translation type="unfinished"></translation>
+        <translation>Максимальное количество ходов:</translation>
     </message>
     <message>
         <source>Dist Attack: </source>
-        <translation type="unfinished"></translation>
+        <translation>Атака на расстоянии:</translation>
     </message>
     <message>
         <source>Min Damages: </source>
-        <translation type="unfinished"></translation>
+        <translation>Минимальное повреждение:</translation>
     </message>
     <message>
         <source>Max Damages: </source>
-        <translation type="unfinished"></translation>
+        <translation>Максимальное повреждение:</translation>
     </message>
     <message>
         <source>Morale: </source>
-        <translation type="unfinished"></translation>
+        <translation>Мораль:</translation>
     </message>
     <message>
         <source>Luck: </source>
-        <translation type="unfinished"></translation>
+        <translation>Удача:</translation>
     </message>
     <message>
         <source>Size: </source>
-        <translation type="unfinished"></translation>
+        <translation>Размер:</translation>
     </message>
     <message>
         <source>Cost: </source>
-        <translation type="unfinished"></translation>
+        <translation>Цена:</translation>
     </message>
     <message>
         <source>Maintenance cost: </source>
-        <translation type="unfinished"></translation>
+        <translation>Цена разработки:</translation>
     </message>
     <message>
         <source>Picture: </source>
-        <translation type="unfinished"></translation>
+        <translation>Изображение:</translation>
     </message>
 </context>
 <context>
     <name>EditTroop</name>
     <message>
         <source>Race : </source>
-        <translation type="unfinished"></translation>
+        <translation>Раса:</translation>
     </message>
     <message>
         <source>Name : </source>
-        <translation type="unfinished"></translation>
+        <translation>Название:</translation>
     </message>
     <message>
         <source>Number : </source>
-        <translation type="unfinished"></translation>
+        <translation>Количество:</translation>
+    </message>
+</context>
+<context>
+    <name>MapDispositionEditor</name>
+    <message>
+        <source>Free</source>
+        <translation>Свободный</translation>
+    </message>
+    <message>
+        <source>Occupied</source>
+        <translation>Занятый</translation>
+    </message>
+    <message>
+        <source>Door</source>
+        <translation>Дверь</translation>
+    </message>
+    <message>
+        <source>Columns:</source>
+        <translation>Колонки:</translation>
+    </message>
+    <message>
+        <source>Rows:</source>
+        <translation>Строки:</translation>
     </message>
 </context>
 <context>
     <name>PreviewBaseDialog</name>
     <message>
         <source>Buildings</source>
-        <translation type="unfinished"></translation>
+        <translation>Здания</translation>
     </message>
 </context>
 <context>
     <name>QObject</name>
     <message>
         <source>Effect &apos;</source>
-        <translation type="unfinished"></translation>
+        <translation>Эффект &apos;</translation>
     </message>
     <message>
         <source>&apos; with param </source>
-        <translation type="unfinished"></translation>
+        <translation>&apos; с параметром</translation>
+    </message>
+    <message>
+        <source>Action: </source>
+        <translation>Действие:</translation>
+    </message>
+    <message>
+        <source>Charac </source>
+        <translation>Персонаж</translation>
+    </message>
+    <message>
+        <source>Spell </source>
+        <translation>Заклинание</translation>
+    </message>
+    <message>
+        <source> modify by </source>
+        <translation>изменить с помощью</translation>
+    </message>
+    <message>
+        <source>%</source>
+        <translation>%</translation>
+    </message>
+    <message>
+        <source> elementary </source>
+        <translation>элементарно</translation>
     </message>
 </context>
 <context>
     <name>SectionArtefact</name>
     <message>
         <source>Artefact</source>
-        <translation type="unfinished"></translation>
+        <translation>Артефакт</translation>
     </message>
     <message>
         <source>Name: </source>
-        <translation type="unfinished"></translation>
+        <translation>Название:</translation>
     </message>
     <message>
         <source>Position: </source>
-        <translation type="unfinished"></translation>
+        <translation>Позиция:</translation>
     </message>
     <message>
         <source>Icon: </source>
-        <translation type="unfinished"></translation>
+        <translation>Иконка:</translation>
     </message>
     <message>
         <source>Item: </source>
-        <translation type="unfinished"></translation>
+        <translation>Объект:</translation>
     </message>
 </context>
 <context>
     <name>SectionBase</name>
     <message>
         <source> Base </source>
-        <translation type="unfinished"></translation>
+        <translation>База</translation>
     </message>
     <message>
         <source>Name: </source>
-        <translation type="unfinished"></translation>
+        <translation>Название:</translation>
     </message>
     <message>
         <source>Population: </source>
-        <translation type="unfinished"></translation>
+        <translation>Население:</translation>
     </message>
     <message>
         <source>Preview</source>
-        <translation type="unfinished"></translation>
+        <translation type="obsolete">Предпросмотр</translation>
     </message>
     <message>
         <source> Base : %d/%d</source>
-        <translation type="unfinished"></translation>
+        <translation>База: %d%d</translation>
+    </message>
+    <message>
+        <source>Res Cost: </source>
+        <translation>Стоимость ресурса:</translation>
+    </message>
+    <message>
+        <source>Growth: </source>
+        <translation>Рост:</translation>
+    </message>
+    <message>
+        <source>Loss: </source>
+        <translation>Потеря:</translation>
+    </message>
+    <message>
+        <source>Preview inside</source>
+        <translation>Просмотр внутри</translation>
     </message>
 </context>
 <context>
     <name>SectionBuilding</name>
     <message>
         <source>Building</source>
-        <translation type="unfinished"></translation>
+        <translation>Здание</translation>
     </message>
     <message>
         <source>Name: </source>
-        <translation type="unfinished"></translation>
+        <translation>Название:</translation>
     </message>
     <message>
         <source>Description: </source>
-        <translation type="unfinished"></translation>
+        <translation>Описание:</translation>
     </message>
     <message>
         <source>Type: </source>
-        <translation type="unfinished"></translation>
+        <translation>Тип:</translation>
     </message>
     <message>
         <source>Picture: </source>
-        <translation type="unfinished"></translation>
+        <translation>Изображение:</translation>
+    </message>
+    <message>
+        <source>Number Frames: </source>
+        <translation>Количество фреймов:</translation>
+    </message>
+    <message>
+        <source>Animation Freq.: </source>
+        <translation>Частота анимации:</translation>
     </message>
 </context>
 <context>
     <name>SectionCreature</name>
     <message>
         <source>Race</source>
-        <translation type="unfinished"></translation>
+        <translation>Раса</translation>
     </message>
     <message>
         <source>Name: </source>
-        <translation type="unfinished"></translation>
+        <translation>Имя:</translation>
     </message>
     <message>
         <source> Creature </source>
-        <translation type="unfinished"></translation>
+        <translation>Создание</translation>
     </message>
     <message>
         <source> Race : %d/%d</source>
-        <translation type="unfinished"></translation>
+        <translation>Раса: %d%d</translation>
     </message>
     <message>
         <source> Creature : %d/%d</source>
-        <translation type="unfinished"></translation>
+        <translation>Создание: %d%d</translation>
     </message>
     <message>
         <source> Creature : %d/??</source>
-        <translation type="unfinished"></translation>
+        <translation>Создание: %d/??</translation>
     </message>
 </context>
 <context>
     <name>SectionDecoration</name>
     <message>
         <source>Decoration</source>
-        <translation type="unfinished"></translation>
+        <translation>Декорация</translation>
     </message>
     <message>
         <source>Name: </source>
-        <translation type="unfinished"></translation>
+        <translation>Название:</translation>
     </message>
     <message>
         <source>Info: </source>
-        <translation type="unfinished"></translation>
+        <translation>Информация:</translation>
     </message>
     <message>
         <source>Image: </source>
-        <translation type="unfinished"></translation>
+        <translation>Изображение:</translation>
+    </message>
+</context>
+<context>
+    <name>SectionExperience</name>
+    <message>
+        <source>List of required experience to gain for accessing the next level:</source>
+        <translation>Список необходимых навыков и опыта для достижения следующего уровня:</translation>
     </message>
 </context>
 <context>
     <name>SectionGeneral</name>
     <message>
         <source>Fog of war</source>
-        <translation type="unfinished"></translation>
+        <translation type="obsolete">Туман войны</translation>
     </message>
     <message>
         <source>Number of unit/lord</source>
-        <translation type="unfinished"></translation>
+        <translation>Количество юнитов/лордов</translation>
     </message>
     <message>
         <source>Logo (200x180): </source>
-        <translation type="unfinished"></translation>
+        <translation>Логотип (200x180):</translation>
+    </message>
+    <message>
+        <source>Vision management: </source>
+        <translation>Управление обзором:</translation>
     </message>
 </context>
 <context>
     <name>SectionGround</name>
     <message>
         <source>Tiles</source>
-        <translation type="unfinished"></translation>
+        <translation>Покрытие</translation>
     </message>
     <message>
         <source>Name: </source>
-        <translation type="unfinished"></translation>
+        <translation>Название:</translation>
     </message>
     <message>
         <source>Coef: </source>
-        <translation type="unfinished"></translation>
+        <translation>Коэффициент:</translation>
     </message>
     <message>
         <source>Color: </source>
-        <translation type="unfinished"></translation>
+        <translation>Цвет:</translation>
     </message>
     <message>
         <source>Tile </source>
-        <translation type="unfinished"></translation>
+        <translation>Покрытие</translation>
     </message>
 </context>
 <context>
     <name>SectionInsideBuilding</name>
     <message>
         <source> Building </source>
-        <translation type="unfinished"></translation>
+        <translation>Здание</translation>
     </message>
     <message>
         <source>Name: </source>
-        <translation type="unfinished"></translation>
+        <translation>Название:</translation>
     </message>
     <message>
         <source>Description: </source>
-        <translation type="unfinished"></translation>
+        <translation>Описание:</translation>
     </message>
     <message>
         <source>Cost: </source>
-        <translation type="unfinished"></translation>
+        <translation>Цена:</translation>
     </message>
     <message>
         <source>Maintenance cost: </source>
-        <translation type="unfinished"></translation>
+        <translation>Цена разработки:</translation>
     </message>
     <message>
         <source> Building : %d/%d</source>
-        <translation type="unfinished"></translation>
+        <translation>Здание: %d%d</translation>
+    </message>
+    <message>
+        <source>Action: </source>
+        <translation>Действие:</translation>
+    </message>
+    <message>
+        <source>Params: </source>
+        <translation>Параметры:</translation>
     </message>
 </context>
 <context>
     <name>SectionLord</name>
     <message>
         <source>Lord</source>
-        <translation type="unfinished"></translation>
+        <translation>Лорд</translation>
     </message>
     <message>
         <source>Photo: </source>
-        <translation type="unfinished"></translation>
+        <translation>Портрет:</translation>
     </message>
     <message>
         <source>Icon: </source>
-        <translation type="unfinished"></translation>
+        <translation>Иконка:</translation>
     </message>
     <message>
         <source>Name : </source>
-        <translation type="unfinished"></translation>
+        <translation>Имя:</translation>
     </message>
     <message>
         <source>Category : </source>
-        <translation type="unfinished"></translation>
+        <translation>Категория:</translation>
     </message>
     <message>
         <source>Race : </source>
-        <translation type="unfinished"></translation>
+        <translation type="obsolete">Раса:</translation>
     </message>
     <message>
         <source>Attack : </source>
-        <translation type="unfinished"></translation>
+        <translation>Атака:</translation>
     </message>
     <message>
         <source>Defense : </source>
-        <translation type="unfinished"></translation>
+        <translation>Защита:</translation>
     </message>
     <message>
         <source>Power : </source>
-        <translation type="unfinished"></translation>
+        <translation>Мощь:</translation>
     </message>
     <message>
         <source>Knowledge : </source>
-        <translation type="unfinished"></translation>
+        <translation>Знание:</translation>
     </message>
     <message>
         <source>MaxMoves : </source>
-        <translation type="unfinished"></translation>
+        <translation>Максимально количество ходов:</translation>
     </message>
     <message>
         <source>Vision : </source>
-        <translation type="unfinished"></translation>
+        <translation>Дальность взгляда:</translation>
+    </message>
+    <message>
+        <source> (Race: </source>
+        <translation>(Раса:</translation>
+    </message>
+</context>
+<context>
+    <name>SectionLordCategory</name>
+    <message>
+        <source>Lord Categories</source>
+        <translation>Категории лордов</translation>
+    </message>
+    <message>
+        <source>Name: </source>
+        <translation>Имя:</translation>
+    </message>
+    <message>
+        <source>Description: </source>
+        <translation>Описание:</translation>
+    </message>
+    <message>
+        <source>Race: </source>
+        <translation>Раса:</translation>
+    </message>
+    <message>
+        <source>Evolution of Attack skill (weight): </source>
+        <translation>Продвижение навыка атаки (вес):</translation>
+    </message>
+    <message>
+        <source>Evolution of Defense skill (weight): </source>
+        <translation>Продвижение уровня защиты (вес):</translation>
+    </message>
+    <message>
+        <source>Evolution of Power skill (weight): </source>
+        <translation>Продвижение уровня силы (вес):</translation>
+    </message>
+    <message>
+        <source>Evolution of Knowledge skill (weight): </source>
+        <translation>Продвижение уровня знания (вес):</translation>
     </message>
 </context>
 <context>
     <name>SectionMachine</name>
     <message>
         <source>War Machine</source>
-        <translation type="unfinished"></translation>
+        <translation>Боевая машина</translation>
     </message>
     <message>
         <source>Name: </source>
-        <translation type="unfinished"></translation>
+        <translation>Название:</translation>
     </message>
     <message>
         <source>Type: </source>
-        <translation type="unfinished"></translation>
+        <translation>Тип:</translation>
     </message>
     <message>
         <source>Param (1): </source>
-        <translation type="unfinished"></translation>
+        <translation>Параметр (1):</translation>
     </message>
     <message>
         <source>Params: </source>
-        <translation type="unfinished"></translation>
+        <translation>Параметры:</translation>
     </message>
     <message>
         <source>Icon: </source>
-        <translation type="unfinished"></translation>
+        <translation>Иконка:</translation>
     </message>
     <message>
         <source>Item: </source>
-        <translation type="unfinished"></translation>
+        <translation>Элемент:</translation>
     </message>
 </context>
 <context>
     <name>SectionRessource</name>
     <message>
         <source>Ressource</source>
-        <translation type="unfinished"></translation>
+        <translation>Ресурс</translation>
     </message>
     <message>
         <source>Name: </source>
-        <translation type="unfinished"></translation>
+        <translation>Название:</translation>
     </message>
     <message>
         <source>Icon: </source>
-        <translation type="unfinished"></translation>
+        <translation>Иконка:</translation>
     </message>
     <message>
         <source>Small icon: </source>
-        <translation type="unfinished"></translation>
+        <translation>Маленькая иконка:</translation>
     </message>
 </context>
 <context>
     <name>SectionSelector</name>
     <message>
         <source>General</source>
-        <translation type="unfinished"></translation>
+        <translation>Общее</translation>
     </message>
     <message>
         <source>Artefacts</source>
-        <translation type="unfinished"></translation>
+        <translation>Артефакты</translation>
     </message>
     <message>
         <source>Teams</source>
-        <translation type="unfinished"></translation>
+        <translation>Команды</translation>
     </message>
     <message>
         <source>Bases</source>
-        <translation type="unfinished"></translation>
+        <translation>Базы</translation>
     </message>
     <message>
         <source>Buildings</source>
-        <translation type="unfinished"></translation>
+        <translation>Здания</translation>
     </message>
     <message>
         <source>Creatures</source>
-        <translation type="unfinished"></translation>
+        <translation>Создания</translation>
     </message>
     <message>
         <source>Decorations</source>
-        <translation type="unfinished"></translation>
+        <translation>Декорации</translation>
     </message>
     <message>
         <source>Grounds</source>
-        <translation type="unfinished"></translation>
+        <translation>Земли</translation>
     </message>
     <message>
         <source>Lords</source>
-        <translation type="unfinished"></translation>
+        <translation>Лорды</translation>
     </message>
     <message>
         <source>Resources</source>
-        <translation type="unfinished"></translation>
+        <translation>Ресурсы</translation>
     </message>
     <message>
         <source>War Machines</source>
-        <translation type="unfinished"></translation>
+        <translation>Боевые машины</translation>
+    </message>
+    <message>
+        <source>Lord Categories</source>
+        <translation>Категории лордов</translation>
+    </message>
+    <message>
+        <source>Levels</source>
+        <translation>Уровни</translation>
     </message>
 </context>
 <context>
     <name>SectionTeam</name>
     <message>
         <source>Team</source>
-        <translation type="unfinished"></translation>
+        <translation>Команда</translation>
     </message>
     <message>
         <source>Name: </source>
-        <translation type="unfinished"></translation>
+        <translation>Название:</translation>
     </message>
     <message>
         <source>Color</source>
-        <translation type="unfinished"></translation>
+        <translation>Цвет</translation>
     </message>
     <message>
         <source>Flag: </source>
-        <translation type="unfinished"></translation>
+        <translation>Флаг:</translation>
     </message>
 </context>
 <context>
     <name>SelectionWidget</name>
     <message>
         <source>None</source>
-        <translation type="unfinished"></translation>
+        <translation>Ничего</translation>
     </message>
 </context>
 <context>
     <name>ThemeInterface</name>
     <message>
         <source>Theme editor for &apos;Attal - Lords of Doom&apos;</source>
-        <translation type="unfinished"></translation>
+        <translation>Редактор тем для &quot;Attal - Лорды судьбы&quot;</translation>
     </message>
     <message>
         <source>Status Bar</source>
-        <translation type="unfinished"></translation>
+        <translation>Статусная панель</translation>
     </message>
     <message>
         <source>New theme</source>
-        <translation type="unfinished"></translation>
+        <translation>Новая тема</translation>
     </message>
     <message>
         <source>Open theme</source>
-        <translation type="unfinished"></translation>
+        <translation>Открыть файл темы</translation>
     </message>
     <message>
         <source>Save theme</source>
-        <translation type="unfinished"></translation>
+        <translation>Сохранить тему</translation>
     </message>
     <message>
         <source>Quit</source>
-        <translation type="unfinished"></translation>
+        <translation>Выйти</translation>
     </message>
     <message>
         <source>Help</source>
-        <translation type="unfinished"></translation>
+        <translation>Помощь</translation>
     </message>
     <message>
         <source>&amp;File</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Файл</translation>
     </message>
     <message>
         <source>&amp;Help</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Помощь</translation>
     </message>
     <message>
         <source>&amp;New theme</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Новая тема</translation>
     </message>
     <message>
         <source>CTRL+N</source>
-        <translation type="unfinished"></translation>
+        <translation>CTRL+N</translation>
     </message>
     <message>
         <source>&amp;Open theme</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Открыть тему</translation>
     </message>
     <message>
         <source>CTRL+O</source>
-        <translation type="unfinished"></translation>
+        <translation>CTRL+O</translation>
     </message>
     <message>
         <source>&amp;Save theme</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Сохранить тему</translation>
     </message>
     <message>
         <source>CTRL+S</source>
-        <translation type="unfinished"></translation>
+        <translation>CTRL+S</translation>
     </message>
     <message>
         <source>&amp;Quit</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Выйти</translation>
     </message>
     <message>
         <source>CTRL+Q</source>
-        <translation type="unfinished"></translation>
+        <translation>CTRL+Q</translation>
     </message>
     <message>
         <source>F1</source>
-        <translation type="unfinished"></translation>
+        <translation>F1</translation>
+    </message>
+    <message>
+        <source>Can&apos;t load theme</source>
+        <translation>Невозможно загрузить тему</translation>
+    </message>
+    <message>
+        <source>Theme </source>
+        <translation>Тема</translation>
+    </message>
+    <message>
+        <source> has not been loaded successfully</source>
+        <translation>не была успешно загружена</translation>
     </message>
 </context>
 </TS>
