@@ -5,7 +5,7 @@
 ** displayBase.cpp
 ** inside the base
 **
-** Version : $Id: displayBase.cpp,v 1.6 2004/04/08 12:49:02 lusum Exp $
+** Version : $Id: displayBase.cpp,v 1.13 2004/10/06 21:00:12 audoux Exp $
 **
 ** Author(s) : Pascal Audoux
 **
@@ -29,6 +29,7 @@
  
 // generic include files
 // include files for QT
+#include <qapplication.h>
 #include <qlayout.h>
 #include <qpixmap.h>
 #include <qpushbutton.h>
@@ -40,6 +41,7 @@
 #include "libCommon/dataTheme.h"
 #include "libCommon/genericBuilding.h"
 #include "libCommon/genericLord.h"
+#include "libCommon/log.h"
 
 #include "libClient/displayCreature.h"
 #include "libClient/game.h"
@@ -55,7 +57,6 @@ extern QString IMAGE_PATH;
 extern ImageTheme ImageTheme;
 extern DataTheme DataTheme;
 
-/** add comments here */
 DisplayBase::DisplayBase( QWidget * parent, const char * name )
 	: QWidget( parent, name )
 {
@@ -64,30 +65,36 @@ DisplayBase::DisplayBase( QWidget * parent, const char * name )
 	_socket = 0;
 	_game = 0;
 	
-	QVBoxLayout * layout = new QVBoxLayout( this );
-
+	_mprices = new PriceMarket();
 	_inside = new InsideBase( this );	
+	
+	_panel = new BaseRightPanel( this );
 	       
-	InsideBaseView * view = new InsideBaseView( _inside, this );		
-	layout->addWidget( view, 1 );
-
-	QHBoxLayout * layH2 = new QHBoxLayout();
-	_baseSummary = new BaseSummary( this );
-	layH2->addWidget( _baseSummary );
+	InsideBaseView * view = new InsideBaseView( _inside, this );
 	
-	_baseLords = new BaseLords( this );
-	layH2->addWidget( _baseLords, 1 );
+	QVBoxLayout * layV1 = new QVBoxLayout();
 	
-	_baseButtons = new BaseButtons( this );
-	layH2->addWidget( _baseButtons );
+	if( qApp->desktop()->width() >= 1024 ) {
+		view->setFixedSize( 960, 720 );
+		view->setVScrollBarMode( QScrollView::AlwaysOff );
+		view->setHScrollBarMode( QScrollView::AlwaysOff );
+		layV1->addWidget( view );
+		layV1->addStretch( 1 );
+	} else {
+		view->setMaximumSize( 960, 720 );
+		layV1->addWidget( view, 1 );
+		//layV1->addStretch( 1 );
+	}
 	
-	layout->addLayout( layH2 );
+	QHBoxLayout * layout = new QHBoxLayout( this );
+	layout->addLayout( layV1, 1 );
+	layout->addWidget( _panel );
 	layout->activate();
 
 	connect( view, SIGNAL( sig_building( GenericInsideBuilding * ) ), SLOT( slot_building( GenericInsideBuilding * ) ) );
-	connect( _baseButtons, SIGNAL( sig_quit() ), SIGNAL( sig_quit() ) );
-	connect( _baseButtons, SIGNAL( sig_exchange() ), _baseLords, SLOT( slot_exchange() ) );
-	connect( _baseLords, SIGNAL( sig_exchange( bool ) ), _baseButtons, SLOT( slot_exchange( bool ) ) );
+	connect( _panel, SIGNAL( sig_quit() ), SIGNAL( sig_quit() ) );
+	//connect( _baseButtons, SIGNAL( sig_exchange() ), _baseLords, SLOT( slot_exchange() ) );
+	//connect( _baseLords, SIGNAL( sig_exchange( bool ) ), _baseButtons, SLOT( slot_exchange( bool ) ) );
 }
 
 void DisplayBase::handleSocket()
@@ -118,10 +125,12 @@ void DisplayBase::handleSocket()
 					_inside->delBuilding( level );
 				}
 			}
-		} else	if( ( _socket->getCla2() == C_MOD_BASE ) &&
-		    ( _socket->getCla3() == C_BASE_UNIT ) ) {
+		} else if( ( _socket->getCla2() == C_MOD_BASE ) && ( _socket->getCla3() == C_BASE_UNIT ) ) {
 			reinit();
 		}
+		if( ( _socket->getCla2() == C_MOD_PLAYER ) && ( _socket->getCla3() == C_PLAY_RESS ) ) {
+			/// XXX:_baseSummary->reinit();
+		}
 		break;
 	case SO_QR:
 		break;
@@ -205,37 +214,59 @@ void DisplayBase::actionSomeCreatures( GenericInsideBuilding * building )
 void DisplayBase::actionMarket()
 {
 	Market mark( this );
+	int cupr,tmpr;
+	uint nbRes = DataTheme.resources.count();
+
+	cupr = 10000;	
+
+	for( uint i = 0; i < nbRes; i++ ) {
+		uint nbases = _player->numBase();
+		for( uint j = 0 ; j < nbases ; j++){
+			PriceMarket * price = DataTheme.bases.at( _player->getBase( j )->getRace())->getPriceMarket();
+			tmpr= price->getResourcePrice( i ) ;
+			if( tmpr < cupr ) {
+				cupr = tmpr;
+			}
+		}
+		if(cupr==10000){
+			cupr=1;
+		}
+		_mprices->setResourcePrice(i,cupr);
+		cupr = 10000;
+	}
+
+
+	mark.setPrices( _mprices );
 	mark.initSocket( _socket );
 	mark.exec();
+	reinit();
 }
 
 void DisplayBase::setPlayer( Player * player )
 {
 	_player = player;
-	_baseSummary->setPlayer( player );
-	_baseLords->setPlayer( player );
-	_baseButtons->setPlayer( player );
+	_panel->setPlayer( player );
 }
 
 void DisplayBase::setBase( GenericBase * base )
 {
 	_base = base;
-	_baseSummary->setBase( base );
-	_baseLords->setBase( base );
+	/// XXX: _baseSummary->setBase( base );
+	//_baseLords->setBase( base );
+	_panel->setBase( base );
 	_inside->setBase( base );
 }
 
 void DisplayBase::reinit()
 {
-	_baseSummary->reinit();
-	_baseLords->reinit();
-	//_inside->reinit();
+	/// XXX:_baseSummary->reinit();
+	_panel->reinit();
 }
 
 void DisplayBase::setSocket( AttalSocket * socket )
 {
 	_socket = socket;
-	_baseLords->setSocket( socket );
+	_panel->setSocket( socket );
 }
 
 /*
@@ -248,6 +279,109 @@ void DisplayBase::slot_newLord()
 
 }
 */
+
+//
+// ----- BaseRightPanel -----
+//
+
+BaseRightPanel::BaseRightPanel( QWidget * parent, const char * name )
+: QWidget( parent, name )
+{
+	_player = 0;
+	_socket = 0;
+	_base = 0;
+	_pbLord = new QPushButton( this );
+	_pbLord->setFixedSize( 60, 60 );
+	
+	_lordLabel = new QLabel( this );
+	_lordLabel->setText( "\n\n" );
+	_lordLabel->setAlignment( Qt::AlignHCenter | Qt::WordBreak );
+	_lordLabel->setMinimumWidth( 64 );
+	_lordLabel->setMinimumHeight( _lordLabel->sizeHint().height() );
+	
+	_pbInfo = new QPushButton( this );
+	_pbInfo->setText( "Info" );
+	FIXEDSIZE( _pbInfo );
+	
+	_bases = new BaseButtons( this );
+	
+	/// XXX: use pixmap instead
+	QPushButton * pbQuit = createButtonOk( this );
+	FIXEDSIZE( pbQuit );
+
+	QVBoxLayout * layout = new QVBoxLayout( this );
+	layout->setMargin( 5 );
+	layout->setSpacing( 10 );
+	layout->addWidget( _pbLord );
+	layout->addWidget( _lordLabel );
+	layout->addSpacing( 10 );
+	layout->addWidget( _pbInfo );
+	layout->addStretch( 1 );
+	layout->addWidget( _bases );
+	layout->addWidget( pbQuit );
+	layout->activate();
+	
+	connect( pbQuit, SIGNAL( clicked() ), SIGNAL( sig_quit() ) );
+	connect( _pbLord, SIGNAL( clicked() ), SLOT( slot_lords() ) );
+	connect( _pbInfo, SIGNAL( clicked() ), SLOT( slot_info() ) );
+}
+
+void BaseRightPanel::slot_lords()
+{
+	DisplayBaseLord displayLords( this );
+	/// XXX: could be gathered
+	displayLords.init( _player, _base, _socket );
+	displayLords.exec();
+	reinit();
+}
+	
+void BaseRightPanel::slot_info()
+{
+	DisplayBaseInfo displayInfo( this );
+	displayInfo.init( _player, _base );
+	displayInfo.exec();
+}
+
+void BaseRightPanel::setPlayer( Player * player )
+{
+	/// XXX: set lord pixmap
+	_player = player;
+}
+
+void BaseRightPanel::setSocket( AttalSocket * socket )
+{
+	_socket = socket;
+}
+
+void BaseRightPanel::setBase( GenericBase * base )
+{
+	_base = base;
+	reinit();
+}
+
+void BaseRightPanel::reinit()
+{
+	GenericLord * lord = 0;
+	QString text;
+
+	 text = "\nNo lord\n";
+	if( _base->getGarrisonLord() ) {
+		lord = _base->getGarrisonLord();
+		text.sprintf( "Lord\n%s\n(Guarrison)", lord->getName().latin1() );
+	} else if( _base->getVisitorLord() ) {
+		lord = _base->getVisitorLord();
+		text.sprintf( "Lord\n%s\n(Visitor)", lord->getName().latin1() );
+	}
+	if( lord ) {
+		_pbLord->setPixmap( * _player->getLordPixmapById( lord->getId() ) );
+	} else {
+		/// XXX: should be optimized in imageTheme
+		_pbLord->setPixmap( QPixmap( IMAGE_PATH + "/lords/noLord.png" ) );
+	}
+	
+	_lordLabel->setText( text );
+}
+
 //
 // ----- BaseSummary -----
 //
@@ -261,6 +395,8 @@ BaseSummary::BaseSummary( QWidget * parent, const char * name )
 	QVBoxLayout * layout = new QVBoxLayout( this );
 	
 	QHBoxLayout * lay1 = new QHBoxLayout();
+	_ress = new RessourceWin(this);
+	lay1->addWidget( _ress );
 	
 	layout->addLayout( lay1 );
 	
@@ -293,7 +429,8 @@ BaseSummary::BaseSummary( QWidget * parent, const char * name )
 void BaseSummary::setPlayer( Player * player )
 {
 	_player = player;
-	
+
+	_ress->setPlayer(player);
 	for( int i = 0; i < 8; i++ ) {
 		_unitIco[i]->setPlayer( player );
 	}
@@ -301,6 +438,7 @@ void BaseSummary::setPlayer( Player * player )
 
 void BaseSummary::reinit()
 {
+	_ress->reinit();
 }
 
 void BaseSummary::setBase( GenericBase * /*base*/ )
@@ -309,6 +447,45 @@ void BaseSummary::setBase( GenericBase * /*base*/ )
 	logEE( "not yet implemented" );
 }
 
+//
+// ----- DisplayBaseInfo  -----
+//
+
+DisplayBaseInfo::DisplayBaseInfo( QWidget * parent, const char * name )
+: QDialog( parent, name, true )
+{
+	_widget = new BaseSummary( this );
+	
+	QPushButton * pbOk = new QPushButton( this );
+	pbOk->setText( "Ok" );
+	FIXEDSIZE( pbOk );
+	
+	QHBoxLayout * layH1 = new QHBoxLayout();
+	layH1->addStretch( 1 );
+	layH1->addWidget( pbOk );
+	layH1->addStretch( 1 );
+	
+	QVBoxLayout * layout = new QVBoxLayout( this );
+	layout->setSpacing( 5 );
+	layout->setMargin( 5 );
+	layout->addWidget( _widget );
+	layout->addLayout( layH1 );
+	layout->activate();	
+	
+	connect( pbOk, SIGNAL( clicked() ), SLOT( accept() ) );
+}
+
+void DisplayBaseInfo::init( Player * player, GenericBase * base )
+{
+	_widget->setBase( base );
+	_widget->setPlayer( player );
+}
+
+void DisplayBaseInfo::reinit()
+{
+	_widget->reinit();
+}
+
 //
 // ----- BaseLords -----
 //
@@ -615,6 +792,43 @@ void BaseLords::unselectPhoto()
 	_visitor->unselectPhoto();
 }
 
+//
+// ----- DisplayBaseLord -----
+//
+
+DisplayBaseLord::DisplayBaseLord( QWidget * parent, const char * name )
+: QDialog( parent, name, true )
+{
+	_widget = new BaseLords( this );
+	
+	QPushButton * pbOk = new QPushButton( this );
+	pbOk->setText( "Ok" );
+	FIXEDSIZE( pbOk );
+	
+	QHBoxLayout * layH1 = new QHBoxLayout();
+	layH1->addStretch( 1 );
+	layH1->addWidget( pbOk );
+	layH1->addStretch( 1 );
+	
+	QVBoxLayout * layout = new QVBoxLayout( this );
+	layout->addWidget( _widget, 1 );
+	layout->addLayout( layH1 );
+	layout->activate();
+	
+	connect( pbOk, SIGNAL( clicked() ), SLOT( accept() ) );
+}
+
+void DisplayBaseLord::init( Player * player, GenericBase * base, AttalSocket * socket )
+{
+	_widget->setPlayer( player );
+	_widget->setSocket( socket );
+	_widget->setBase( base );
+}
+
+//
+// ----- BaseButtons -----
+//
+
 BaseButtons::BaseButtons( QWidget * parent, const char * name )
 	: QWidget( parent, name )
 {
@@ -625,9 +839,6 @@ BaseButtons::BaseButtons( QWidget * parent, const char * name )
 	layout->addWidget( _pbExch );
 	
 	layout->addStretch( 1 );
-	
-	QPushButton * pbOk = createButtonOk( this );
-	layout->addWidget( pbOk );
 		
 	layout->activate();
 	setFixedHeight( 240 );	
@@ -635,7 +846,6 @@ BaseButtons::BaseButtons( QWidget * parent, const char * name )
 	_pbExch->setEnabled( false );
 	
 	connect( _pbExch, SIGNAL( clicked() ), SIGNAL( sig_exchange() ) );
-	connect( pbOk, SIGNAL( clicked() ), SIGNAL( sig_quit() ) );
 }
 
 void BaseButtons::slot_exchange( bool st )
