@@ -5,7 +5,7 @@
 ** game.cpp
 ** Manages the whole game
 **
-** Version : $Id: game.cpp,v 1.28 2004/04/06 22:04:36 lusum Exp $
+** Version : $Id: game.cpp,v 1.46 2004/10/08 23:06:34 audoux Exp $
 **
 ** Author(s) : Pascal Audoux - Carlo
 **
@@ -33,8 +33,8 @@
 #include <qlabel.h>
 #include <qlayout.h>
 #include <qmessagebox.h>
-#include <qstack.h>
 #include <qtabwidget.h>
+#include <qhostaddress.h> 
 // application specific includes
 #include "conf.h"
 #include "libCommon/artefactManager.h"
@@ -49,6 +49,7 @@
 
 #include "libFight/fightUnit.h"
 
+#include "libClient/askChest.h"
 #include "libClient/bonus.h"
 #include "libClient/building.h"
 #include "libClient/chatWidget.h"
@@ -164,7 +165,6 @@ void Game::initWidgets()
 	layout->activate();
 }
 
-/// XXX: usefull ??
 void Game::setPlayerName( QString name ) {
 	_player->setName( name );
 }
@@ -266,7 +266,6 @@ void Game::handleClickLord( Cell * cell )
 				selectedLord->getCell()->getBuilding()->out( selectedLord );
 			}
 			((Lord*)selectedLord)->followPath( _socket );
-			((Lord*)selectedLord)->setColor( QColor( 255, 0, 0 ) );
 		}
 	}		
 }
@@ -317,7 +316,7 @@ void Game::slot_mouseRightPressed( Cell * cell )
 
 void Game::slot_centerMinimap( GenericCell * cell )
 {
-		_view->goToPosition((Cell *) cell);
+	_view->goToPosition((Cell *) cell);
 }
 
 void Game::enter( GenericLord * /*lord*/, GenericBuilding * /*building*/ )
@@ -337,6 +336,8 @@ void Game::beginTurn()
 	_isPlaying = true;
 	_calendar->newDay();
 	_gameInfo->nothing();
+	//_gameInfo->IsPlay();
+	_gameInfo->setStatePlayer( true );
 	if( _calendar->getDay() == 1 ) {
 		_player->newWeek();
 	}
@@ -346,7 +347,7 @@ void Game::beginTurn()
 
 void Game::playerActive( char num )
 {
-	_gameInfo->waitPlayer( getPlayerColor( num ) );
+	_gameInfo->waitPlayer( num );
 }
 
 void Game::endTurn()
@@ -356,11 +357,13 @@ void Game::endTurn()
 		if( _player->shouldEnd() ) {
 			_socket->sendTurnEnd();
 			_isPlaying = false;
+			_gameInfo->setStatePlayer( _isPlaying );
 		} else {
 			QMessageBox msb( "Are you sure ?", "One or more heroes may still move. Are you sure you want to end your turn ?", QMessageBox::Warning, QMessageBox::Yes | QMessageBox::Default, QMessageBox::No | QMessageBox::Escape, 0, this );
 			if ( msb.exec() == QMessageBox::Yes ) {
 				_socket->sendTurnEnd();
 				_isPlaying = false;
+				_gameInfo->setStatePlayer( _isPlaying );
 			}
 		}
 	}
@@ -415,7 +418,7 @@ void Game::endGame()
 	_calendar->reinit();
 	_resourceBar->reinit();
 	reInitLords();
-	_state=MS_NOTHING;
+	_state = MS_NOTHING;
 }
 
 void Game::handleSocket()
@@ -476,37 +479,87 @@ void Game::slot_message( QString msg )
 
 void Game::socketGame()
 {
-	if( _socket->getCla2() == C_GAME_BEG ) {
+	switch( _socket->getCla2() ) {
+	case C_GAME_BEGIN:
 		beginGame( _socket->readChar() );
 		/// XXX: clear old stuff if necessary
-	} else if( _socket->getCla2() == C_GAME_LOST ) {
-		int nb = _socket->readChar();
-		if( nb == getPlayerNumber() ) {
-			endGame();
-		} else {
-			QString text;
-			text = "Player " + QString::number( nb ) + " has lost.";
-			GameMessage msg;
-			msg.setCaption( "A player has lost." );
-			msg.addText( text );
-			msg.addPixmap( ImageTheme.getFlag( nb ) );
-			msg.exec();
-		}
-	} else if( _socket->getCla2() == C_GAME_END ) {
+		break;
+	case C_GAME_LOST:
+		socketGameLost();
+		break;
+	case C_GAME_WIN:
+		socketGameWin();
+		break;
+	case C_GAME_END:
 		endGame();
+		break;
+	case C_GAME_INFO:
+		socketGameInfo();
+		break;
+	default:
+		logEE( "case not handled" );
+		break;
+	}
+}
+
+void Game::socketGameLost()
+{
+	int nb = _socket->readChar();
+	if( nb == _player->getNum() ) {
+		endGame();
+	} else {
+		QString text;
+		text = "Player " + QString::number( nb ) + " has lost.";
+		GameMessage msg;
+		msg.setCaption( "A player has lost." );
+		msg.addText( text );
+		msg.addPixmap( ImageTheme.getFlag( nb ) );
+		msg.exec();
+	}
+}
+
+void Game::socketGameWin()
+{
+	int nb = _socket->readChar();
+	if( nb == _player->getNum() ) {
+		GameMessage msg;
+		msg.addText( "You win !!" );
+		msg.exec();
+		//endGame();
+	} else {
+		GameMessage msg;
+		msg.addText( "A player has win. You lose" );
+		msg.exec();
+		//endGame();
+	}
+}
+
+void Game::socketGameInfo()
+{
+	switch( _socket->getCla3() ) {
+	case C_INFOPLAYER_TEAM: {
+			uchar player = _socket->readChar();	
+			uchar teamId = _socket->readChar();
+			if( getPlayer( player ) ) {
+				getPlayer( player )->setTeam( teamId );
+			}
+		} break;
+	case C_INFOPLAYER_NAME:
+		break;
 	}
 }
 
 void Game::socketTurn()
 {
 	switch( _socket->getCla2() ) {
-	case C_TURN_BEG:
-		beginTurn();
-		/// XXX: clear old stuff if necessary
-		break;
-	case C_TURN_PLAY:
-		playerActive( _socket->readChar() );
-		break;
+	case C_TURN_PLAY: {
+		uint num = _socket->readChar();
+		if( num == _player->getNum() ) {
+			beginTurn();
+		} else {
+			playerActive( num );
+		}
+		} break;
 	case C_TURN_LORD:
 		logEE( "Should not happen (Client : SO_TURN/C_TURN_LORD)" );
 		break;
@@ -854,7 +907,7 @@ void Game::socketModifLord()
 void Game::socketModifLordVisit()
 {
 	/// XXX: not finished, we should use 'num' for the player color
-	/*uchar num = */_socket->readChar();
+	uchar num = _socket->readChar();
 	int row = _socket->readInt();
 	int col = _socket->readInt();
 	uchar id = _socket->readChar();
@@ -874,10 +927,11 @@ void Game::socketModifLordVisit()
 		lord->setSelected( true );
 		lord->setActive( true );
 		/// XXX: change
-		lord->setOwner( 0 );
+		lord->setOwner( getPlayer( num ) );
 		lord->moveTo( _map->at( row, col ) );
 	} else {
 		lord = _realLords[ id ];
+		lord->getCell()->setLord(NULL);
 		if( lord ) {
 			delete lord;
 			_realLords[ id ] = 0;
@@ -915,14 +969,22 @@ void Game::socketModifLordUnit()
 {
 	uchar id = _socket->readChar();
 	uchar num = _socket->readChar();
-	GenericFightUnit * uni = new GenericFightUnit();
 	uchar race = _socket->readChar();
 	uchar level = _socket->readChar();
-	uni->setCreature( race, level );
 	int nb = _socket->readInt();
+	GenericFightUnit * uni = 0;
+	uni =_realLords[ id ]->getUnit( num );
+	if(!uni){
+		uni = new GenericFightUnit();
+		uni->setCreature( race, level );
+		uni->setMove( _socket->readChar() );
+		uni->setHealth( _socket->readInt() );
+	}
 	uni->setNumber( nb );
-	uni->setMove( _socket->readChar() );
-	uni->setHealth( _socket->readInt() );
+	if( nb == 0){
+		delete uni;
+		uni = 0;
+	}	
 	_realLords[ id ]->setUnit( num, uni );
 }
 
@@ -989,6 +1051,9 @@ void Game::socketModifBase()
 	case C_BASE_UNIT:
 		socketModifBaseUnit();
 		break;
+	case C_BASE_POPUL:
+		socketModifBasePopulation();
+		break;
 	}
 }
 
@@ -1076,6 +1141,18 @@ void Game::socketModifBaseUnit()
 	}
 }
 
+void Game::socketModifBasePopulation()
+{
+	int row = _socket->readInt();
+	int col = _socket->readInt();
+	uint popul = _socket->readChar();
+	Base * base = (Base*)_map->at( row, col )->getBase();
+
+	if(base)
+		base->setPopulation(popul);	
+
+}
+
 void Game::socketModifBuilding()
 {
 	switch( _socket->getCla3() ) {
@@ -1088,6 +1165,7 @@ void Game::socketModifBuilding()
 			Building * building = new Building( _map );
 			building->setPosition( _map->at( row, col ) );
 			building->setType( type );
+			_map->computeStoppable( (GenericBuilding *)building );
 			building->show();
 		} // XXX: update building if already created ?
 	}
@@ -1095,8 +1173,12 @@ void Game::socketModifBuilding()
 	case C_BUILD_OWNER: {
 		int row = _socket->readInt();
 		int col = _socket->readInt();
+		GenericBuilding * build = _map->at( row, col )->getBuilding();
 		if( _socket->readChar() == _player->getNum() ) {
-			_player->addBuilding( _map->at( row, col )->getBuilding() );
+			if( build ) {
+				_player->addBuilding( build );
+				build->setOwner( _player );
+			}
 		}
 	}
 	}
@@ -1106,19 +1188,20 @@ void Game::socketModifArtefact()
 {
 	switch( _socket->getCla3() ) {
 		case C_ART_DELLORD: {
-				uint type = _socket->readInt();
-				char lord = _socket->readChar();
-				getLord( lord )->getArtefactManager()->removeArtefactByType( type );
-			}
-			break;
+			uint type = _socket->readInt();
+			char lord = _socket->readChar();
+			getLord( lord )->getArtefactManager()->removeArtefactByType( type );
+		}
+		break;
 		case C_ART_ADDLORD: {
-				uint type = _socket->readInt();
-				char lord = _socket->readChar();
-				if( ! getLord( lord )->getArtefactManager()->hasArtefactType( type ) ) {
-					getLord( lord )->getArtefactManager()->addArtefact( type );
-				}
+			ImageTheme.playSound( AttalSound::SND_GOOD );
+			uint type = _socket->readInt();
+			char lord = _socket->readChar();
+			if( ! getLord( lord )->getArtefactManager()->hasArtefactType( type ) ) {
+				getLord( lord )->getArtefactManager()->addArtefact( type );
 			}
-			break;
+		}
+		break;
 	}
 }
 
@@ -1223,12 +1306,14 @@ void Game::socketConnect()
 	case C_CONN_OK:
 		_socket->sendConnectionName( _player->getName() );
 		_chat->newMessage( QString( "Connection established, %1" ).arg( _player->getName() ) );
+		_chat->newMessage( QString( "Host address %1" ).arg( _socket->peerAddress().toString()));
+		_chat->newMessage( QString( "Host port %1," ).arg( _socket->peerPort())+ QString( " Our port %1" ).arg( _socket->port()));
 		break;
 	case C_CONN_ID:
 		{
 			tmp=_socket->readChar();
 			_player->setNum( tmp );
-			_chat->newMessage( QString( "Connection established, %1" ).arg( _player->getNum() ) );
+			_chat->newMessage( QString( "Connection ID, %1" ).arg( _player->getNum() ) );
 		}
 		break;
 	case C_CONN_NAME:
@@ -1269,22 +1354,42 @@ void Game::slot_displayLord()
 
 void Game::slot_displayBase()
 {
-	_view->goToPosition((Cell *) _player->getSelectedBase()->getCell());
-	emit sig_base( _player->getSelectedBase() );
+	if(_player->getSelectedBase()){
+		_view->goToPosition((Cell *) _player->getSelectedBase()->getCell());
+		emit sig_base( _player->getSelectedBase() );
+	}
 }
 
 void Game::socketQR()
 {
 	switch( _socket->getCla2() ) {
-	case C_QR_NONE:
+	case C_QR_MSG_NEXT: {
+			uchar len = _socket->readChar();
+			for( uint i = 0; i < len; i++ ) {
+				_msg.append( _socket->readChar() );
+			}
+		} break;
+	case C_QR_MSG_END: {
 		//QMessageBox::information( this, "Information", QString( buf+(3*sizeof(char)) ), 0 );
-		QMessageBox::information( this, "Information", "Error in (C_QR_NONE)" );
-		break;
+		uchar len = _socket->readChar();
+		for( uint i = 0; i < len; i++ ) {
+			_msg.append( _socket->readChar() );
+		}
+		QMessageBox::information( this, "Information", _msg );
+		_msg = "";
+		} break;
 	case C_QR_LEVEL: {
 		GainLevel * level = new GainLevel( this );
 		level->reinit();
 		level->exec();
 		_socket->sendAnswer( level->getChoice() );
+		delete level;
+		} break;
+	case C_QR_CHEST: {
+		AskChest * chest = new AskChest();
+		chest->exec();
+		_socket->sendAnswerEnum( chest->getResult() );
+		delete chest;
 		} break;
 	case C_QR_ANSWER:
 		logEE( "Should not happen" );
