@@ -5,7 +5,7 @@
 ** imageTheme.cpp
 ** manage images in theme
 **
-** Version : $Id: imageTheme.cpp,v 1.14 2004/04/04 17:34:27 tribunal2 Exp $
+** Version : $Id: imageTheme.cpp,v 1.20 2004/08/08 12:08:41 audoux Exp $
 **
 ** Author(s) : Pascal Audoux
 **
@@ -29,7 +29,7 @@
 // generic include files
 // include files for QT
 #include <qcanvas.h>
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qpixmap.h>
 #include <qimage.h>
 // application specific include files
@@ -49,11 +49,11 @@ extern QString IMAGE_PATH;
 // ----- CreaturePixmap -----
 //
 
-CreaturePixmap::CreaturePixmap( QList<QPixmap> pix, QList<QPoint> hotspots )
+CreaturePixmap::CreaturePixmap( QPtrList<QPixmap> pix, QPtrList<QPoint> hotspots )
 {
 	_pixmaps[0] = new QCanvasPixmapArray( pix, hotspots );
 
-	QList<QPixmap> newList;
+	QPtrList<QPixmap> newList;
 	for( uint i=0; i<pix.count(); i++ ) {
 		QCanvasPixmap oldPix( *pix.at(i), *hotspots.at(i) );
 		QCanvasPixmap * newPix;
@@ -89,11 +89,11 @@ QCanvasPixmapArray * CreaturePixmap::operator[]( uint i )
 // ----- MapCreaturePixmap -----
 //
 
-MapCreaturePixmap::MapCreaturePixmap( QList<QPixmap> pix, QList<QPoint> hotspots )
+MapCreaturePixmap::MapCreaturePixmap( QPtrList<QPixmap> pix, QPtrList<QPoint> hotspots )
 {
 	_pixmaps[0] = new QCanvasPixmapArray( pix, hotspots );
 
-	QList<QPixmap> newList;
+	QPtrList<QPixmap> newList;
 	for( uint i=0; i<pix.count(); i++ ) {
 		QCanvasPixmap oldPix( *pix.at(i), *hotspots.at(i) );
 		QCanvasPixmap * newPix;
@@ -149,7 +149,9 @@ ImageTheme::ImageTheme()
 	_resourceIcon = 0;
 	_resourceSmallIcon = 0;
 	_flags = 0;
+	_mapFlags = 0;
 	_sound = 0;
+	_isLoaded = false;
 }
 
 ImageTheme::~ImageTheme()
@@ -225,40 +227,35 @@ QPixmap * ImageTheme::getResourceSmallIcom( uint num )
 }
 
 #define CRE_ARRAY( list1, list2 ) \
-QList<QPixmap> list1; \
+QPtrList<QPixmap> list1; \
 list1.setAutoDelete( true ); \
-QList<QPoint> list2; \
+QPtrList<QPoint> list2; \
 list2.setAutoDelete( true )
 
 #define ADD_PIX( list1, list2, name ) \
 list1.append( new QPixmap( IMAGE_PATH + name ) ); \
 list2.append( new QPoint( 0, 0 ) )
 
-void ImageTheme::init()
+bool ImageTheme::init()
 {
-	uint i;
+	_isLoaded = initSkills();
+	_isLoaded = _isLoaded && initCreatures();
+	_isLoaded = _isLoaded && initCells();
+	_isLoaded = _isLoaded && initBuildings();
+	_isLoaded = _isLoaded && initDecorations();
+	_isLoaded = _isLoaded && initTransitions();
+	_isLoaded = _isLoaded && initArtefacts();
+	_isLoaded = _isLoaded && initResources();
+	_isLoaded = _isLoaded && initBonus();
+	_isLoaded = _isLoaded && initChest();
+	_isLoaded = _isLoaded && initMapCreatures();
+	_isLoaded = _isLoaded && initEvents();
+	_isLoaded = _isLoaded && initTeams();
+	_isLoaded = _isLoaded && initLords();
+	_isLoaded = _isLoaded && initBases();
+	_isLoaded = _isLoaded && initSound();
 
-	initSkills();
-	initCreatures();
-	initCells();
-	initBuildings();
-	initDecorations();
-	initTransitions();
-	initArtefacts();
-	initResources();
-	initBonus();
-	initChest();
-	initMapCreatures();
-	initEvents();
-
-	_flags = new QPixmap * [DataTheme.teams.count()];
-	for( i = 0; i < DataTheme.teams.count(); i++ ) {
-		_flags[i] = 0;
-	}
-
-	initLords();
-	initBases();
-	initSound();
+	return isLoaded();
 }
 
 void ImageTheme::save()
@@ -271,34 +268,42 @@ void ImageTheme::clear()
 	if( cells ) {
 		delete cells;
 	}
+	cells = 0;
 
 	if( lords ) {
 		delete lords;
 	}
+	lords = 0;
 	
 	if( bases ) {
 		delete bases;
 	}
+	bases = 0;
 
 	if( buildings ) {
 		delete buildings;
 	}
+	buildings = 0;
 
 	if( insideBuildings ) {
 		delete insideBuildings;
 	}
+	insideBuildings = 0;
 
 	if( skills ) {
 		delete skills;
 	}
+	skills = 0;
 
 	if( transition ) {
 		delete transition;
 	}
+	transition = 0;
 
 	if( decoration ) {
 		delete decoration;
 	}
+	decoration = 0;
 
 	if( creatures ) {
 		int cpt = 0;
@@ -315,6 +320,7 @@ void ImageTheme::clear()
 		}
 		delete [] creatures;
 	}
+	creatures = 0;
 
 	if( artefacts ) {
 		delete artefacts;
@@ -368,6 +374,10 @@ void ImageTheme::clear()
 	if( _flags ) {
 		delete [] _flags;
 	}
+	
+	if( _mapFlags ) {
+		/// TODO
+	}
 
 	delete _sound;
 }
@@ -384,10 +394,10 @@ QPixmap * ImageTheme::getFlag( uint num )
 	QPixmap * ret = 0;
 
 	if( num < DataTheme.teams.count() ) {
-		ret = _flags[num];
-		if( ! ret ) {
-			ret = new QPixmap( IMAGE_PATH + "players/flag_" + QString::number( num ) + ".png" );
+		if( ! _flags[num] ) {
+			_flags[ num ] = new QPixmap( IMAGE_PATH + "players/flag_" + QString::number( num ) + ".png" );
 		}
+		ret = _flags[num];
 	}
 
 	return ret;
@@ -432,15 +442,52 @@ QPixmap * ImageTheme::getBaseSmallPixmap( uint /*num*/ )
 	return _baseSmallPixmap[ 0 ];
 }
 
-void ImageTheme::initSkills()
+QCanvasPixmapArray * ImageTheme::getMapFlag( uint type, uint teamId )
+{
+	return _mapFlags[ type ][ teamId ];
+}
+
+const uint NB_FLAGTYPE = 1;
+
+bool ImageTheme::initTeams()
+{
+	uint i, j;
+	uint nbTeams = DataTheme.teams.count();
+	QString fileName;
+	
+	_flags = new QPixmap * [ nbTeams ];
+	for( i = 0; i < nbTeams; i++ ) {
+		_flags[i] = 0;
+	}
+	
+	/// XXX: NB_FLAGTYPE = 1 = nb of type of flags (only one for the moment but will be extended if managed in dataTheme
+	_mapFlags = new QCanvasPixmapArray ** [ NB_FLAGTYPE ];
+	
+	for( i = 0; i < NB_FLAGTYPE; i++ ) {
+		_mapFlags[ i ] = new QCanvasPixmapArray * [ nbTeams ];
+		for( j = 0; j < nbTeams; j++ ) {
+			CRE_ARRAY( listPixmapFlag, listPointFlag );
+			/// XXX: for the moment, only one pixmap, but maybe one day it will be animated...
+			fileName.sprintf( "players/mapFlag_%d_%d_0.png", i, j );
+			ADD_PIX( listPixmapFlag, listPointFlag, fileName.latin1() );
+			_mapFlags[ i ][ j ] = new QCanvasPixmapArray( listPixmapFlag, listPointFlag );
+		}
+	}
+
+	return true;
+}
+
+bool ImageTheme::initSkills()
 {
 	CRE_ARRAY( listPixmapSkill, listPointSkill );
 	ADD_PIX( listPixmapSkill, listPointSkill, "technics/technic_1_1.png" );
 	ADD_PIX( listPixmapSkill, listPointSkill, "technics/technic_1_2.png" );
 	skills = new QCanvasPixmapArray( listPixmapSkill, listPointSkill );
+
+	return true;
 }
 
-void ImageTheme::initCells()
+bool ImageTheme::initCells()
 {
 	uint i, j;
 	QString name;
@@ -468,19 +515,25 @@ void ImageTheme::initCells()
 		QString name = "misc/arrow-" + QString::number( i ) + ".png";
 		ADD_PIX( listPixmapPathCell, listPointPathCell, name.latin1() );
 	}
+	for( i = 0; i < 33; i++ ) {
+		QString name = "misc/arrowFar-" + QString::number( i ) + ".png";
+		ADD_PIX( listPixmapPathCell, listPointPathCell, name.latin1() );
+	}
 	pathCells = new QCanvasPixmapArray( listPixmapPathCell, listPointPathCell );
+
+	return true;
 }
 
-void ImageTheme::initCreatures()
+bool ImageTheme::initCreatures()
 {
 	uint i, j;
 	int cpt = 0;
 	creatures = new CreaturePixmap * [DataTheme.creatures.count()];
 	for( i = 0; i < DataTheme.countRace(); i++ ) {
 		for( j = 0; j < DataTheme.creatures.getRace( i )->count(); j++ ) {
-			QList<QPixmap> listPixmapFightUnit;
+			QPtrList<QPixmap> listPixmapFightUnit;
 			listPixmapFightUnit.setAutoDelete( true );
-			QList<QPoint> listPointFightUnit;
+			QPtrList<QPoint> listPointFightUnit;
 			listPointFightUnit.setAutoDelete( true );
 
 			if ( DataTheme.creatures.at (i , j)->isAnimated () )
@@ -506,9 +559,11 @@ void ImageTheme::initCreatures()
 	listPixmapDead.append( new QPixmap( IMAGE_PATH + "units/dead.png" ) ); \
 	listPointDead.append( new QPoint( 0, -70 ) );
 	deadCreature = new QCanvasPixmapArray( listPixmapDead, listPointDead );
+
+	return true;
 }
 
-void ImageTheme::initLords()
+bool ImageTheme::initLords()
 {
 	uint nbLord = DataTheme.lords.count();
 	uint i;
@@ -526,9 +581,11 @@ void ImageTheme::initLords()
 	for( i = 0; i < nbLord; i++ ) {
 		_lordSmallPixmap[i] = 0;
 	}
+
+	return true;
 }
 
-void ImageTheme::initBases()
+bool ImageTheme::initBases()
 {
 	uint i;
 	
@@ -545,9 +602,11 @@ void ImageTheme::initBases()
 
 	_baseSmallPixmap = new QPixmap * [1];
 	_baseSmallPixmap[0] = new QPixmap( IMAGE_PATH + "base/smallBase.png" );
+
+	return true;
 }
 
-void ImageTheme::initArtefacts()
+bool ImageTheme::initArtefacts()
 {
 	uint i;
 	CRE_ARRAY( listPixmapArtefact, listPointArtefact );
@@ -560,9 +619,11 @@ void ImageTheme::initArtefacts()
 	for( i = 0; i < DataTheme.artefacts.count(); i++ ) {
 		_artefactIcon[i] = 0;
 	}
+
+	return true;
 }
 
-void ImageTheme::initResources()
+bool ImageTheme::initResources()
 {
 	uint i;
 
@@ -572,9 +633,11 @@ void ImageTheme::initResources()
 		_resourceIcon[i] = 0;
 		_resourceSmallIcon[i] = 0;
 	}
+
+	return true;
 }
 
-void ImageTheme::initBonus()
+bool ImageTheme::initBonus()
 {
 	uint j;
 	QString name;
@@ -601,16 +664,20 @@ void ImageTheme::initBonus()
 	name = "events/scroll.png";
 	ADD_PIX( listPixmapBonus3, listPointBonus3, name );
 	bonus[3] = new QCanvasPixmapArray( listPixmapBonus3, listPointBonus3 );
+
+	return true;
 }
 
-void ImageTheme::initChest()
+bool ImageTheme::initChest()
 {
 	CRE_ARRAY( listPixmapChest, listPointChest );
 	ADD_PIX( listPixmapChest, listPointChest, "events/chest.png" );
 	chest = new QCanvasPixmapArray( listPixmapChest, listPointChest );
+
+	return true;
 }
 
-void ImageTheme::initBuildings()
+bool ImageTheme::initBuildings()
 {
 	uint i, j;
 	buildings = new QCanvasPixmapArray * [ DataTheme.buildings.count() ];
@@ -632,9 +699,11 @@ void ImageTheme::initBuildings()
 		}
 		insideBuildings[i] = new QCanvasPixmapArray( listPixmapInside, listPointInside );
 	}
+
+	return true;
 }
 
-void ImageTheme::initTransitions()
+bool ImageTheme::initTransitions()
 {
 	uint i, j;
 	transition = new QCanvasPixmapArray * [ DataTheme.tiles.count() ];
@@ -646,10 +715,11 @@ void ImageTheme::initTransitions()
 		}
 		transition[i-1] = new QCanvasPixmapArray( listPixmapTrans, listPointTrans );
 	}
-	
+
+	return true;
 }
 
-void ImageTheme::initDecorations()
+bool ImageTheme::initDecorations()
 {
 	uint i;
 	CRE_ARRAY( listPixmapDeco, listPointDeco );
@@ -657,9 +727,11 @@ void ImageTheme::initDecorations()
 		ADD_PIX( listPixmapDeco, listPointDeco, "decor/decoration_" + QString::number( i ) + ".png" );
 	}
 	decoration = new QCanvasPixmapArray( listPixmapDeco, listPointDeco );
+
+	return true;
 }
 
-void ImageTheme::initEvents()
+bool ImageTheme::initEvents()
 {
 	uint i;
 	events = new QCanvasPixmapArray * [ 3 ];
@@ -682,11 +754,11 @@ void ImageTheme::initEvents()
 	fileName = "events/chest.png";
 	ADD_PIX( listPixmapEvent3, listPointEvent3, fileName );
 	events[2] = new QCanvasPixmapArray( listPixmapEvent3, listPointEvent3 );
+
+	return true;
 }
 
-
-
-void ImageTheme::initMapCreatures()
+bool ImageTheme::initMapCreatures()
 {
 	uint i, j;
 
@@ -700,6 +772,8 @@ void ImageTheme::initMapCreatures()
 			mapCreatures[i][j] = new MapCreaturePixmap( listPixmapMapCreature, listPointMapCreature );
 		}
 	}
+
+	return true;
 }
 
 QPixmap * ImageTheme::getMapCreature( uint race, uint level, bool rightLooking )
@@ -724,10 +798,12 @@ CreaturePixmap * ImageTheme::getCreature ( uint race, uint level )
 	return ( creatures[nCnt] );
 }
 
-void ImageTheme::initSound()
+bool ImageTheme::initSound()
 {
 	_sound = new AttalSound();
 	_sound->init();
+
+	return true;
 }
 
 void ImageTheme::playMusicMap()
@@ -745,6 +821,10 @@ void ImageTheme::playMusicFight()
 	_sound->playMusicFight();
 }
 
+void ImageTheme::playSound( AttalSound::SoundType snd )
+{
+	_sound->playSound( snd );
+}
 
 
 
