@@ -5,7 +5,7 @@
 ** attalSocket.cpp
 ** socket for Attal over network
 **
-** Version : $Id: attalSocket.cpp,v 1.11 2004/04/08 12:48:04 lusum Exp $
+** Version : $Id: attalSocket.cpp,v 1.19 2004/10/08 23:05:54 audoux Exp $
 **
 ** Author(s) : Pascal Audoux
 **
@@ -179,6 +179,9 @@ void AttalSocket::sendExchangeStart( GenericLord * lord1, GenericLord * lord2 )
 	send();
 }
 
+ /* NOTE: if regroup 2 same units remember that the server 
+	* regroup the units on position unit2 not unit1
+	*/ 
 void AttalSocket::sendExchangeUnit( GenericLord * lord1, int unit1, GenericLord * lord2, int unit2 )
 {
 	init( (uchar)SO_EXCH, (uchar)C_EXCH_UNIT );
@@ -246,21 +249,42 @@ void AttalSocket::sendPlayerResource( char res, int nb )
 	send();
 }
 
-void AttalSocket::sendAskNone( QString msg )
+void AttalSocket::sendAskNone( const QString & msg )
 {
-	init( (uchar) SO_QR, (uchar) C_QR_NONE );
-	appendChar( (uchar) QMIN( msg.length(), 250 ) );
+	uint len = msg.length();
 	
+	while( len > 250 ) {
+		init( (uchar) SO_QR, (uchar) C_QR_MSG_NEXT );
+		appendChar( (uchar) 250 );
+
+		/// XXX: we suppose small messages for the moment
+		for( uint i = 0; i < 250; i++ ) {
+			appendChar( (uchar) (msg.latin1())[i] );
+		}
+		send();
+		
+		len -= 250;
+	}
+	
+	init( (uchar) SO_QR, (uchar) C_QR_MSG_END );
+	appendChar( (uchar) len );
+
 	/// XXX: we suppose small messages for the moment
-	for( uint i=0; i< QMIN( msg.length(), 250 ); i++ ) {
+	for( uint i = 0; i < len; i++ ) {
 		appendChar( (uchar) (msg.latin1())[i] );
 	}
 	send();
 }
 
+void AttalSocket::sendAskChest()
+{
+	init( (uchar) SO_QR, (uchar) C_QR_CHEST );
+	send();
+}
+
 void AttalSocket::sendBegGame( char nb ) 
 {
-	init( (uchar)SO_GAME, (uchar)C_GAME_BEG );
+	init( (uchar)SO_GAME, (uchar)C_GAME_BEGIN );
 	appendChar( nb );
 	send();
 }
@@ -283,15 +307,32 @@ void AttalSocket::sendLostGame( GenericPlayer * player )
 	send();
 }
 
+void AttalSocket::sendWinGame( GenericPlayer * player )
+{
+	init( (uchar)SO_GAME, (uchar)C_GAME_WIN );
+	appendChar( player->getNum() );
+	send();
+}
+
 void AttalSocket::sendEndGame()
 {
 	init( (uchar)SO_GAME, (uchar)C_GAME_END );
 	send();
 }
 
-void AttalSocket::sendTurnBeg()
+void AttalSocket::sendGameInfoPlayerName( GenericPlayer * player )
 {
-	init( (uchar)SO_TURN, (uchar)C_TURN_BEG );
+	init( (uchar)SO_GAME, (uchar)C_GAME_INFO, (uchar)C_INFOPLAYER_NAME );
+	appendChar( player->getNum() );
+	/// XXX: add name
+	send();
+}
+	
+void AttalSocket::sendGameInfoPlayerTeam( GenericPlayer * player )
+{
+	init( (uchar)SO_GAME, (uchar)C_GAME_INFO, (uchar)C_INFOPLAYER_TEAM );
+	appendChar( player->getNum() );
+	appendChar( player->getTeamId() );
 	send();
 }
 
@@ -434,12 +475,24 @@ void AttalSocket::sendFightModifyUnit( CLASS_FIGHTER fighter, char num, GenericF
 	send();
 }
 
-void AttalSocket::sendFightDamageUnit( CLASS_FIGHTER fighter, char num, int damage )
+void AttalSocket::sendFightDamageUnit( CLASS_FIGHTER attacker,
+				       char numAttacker,
+				       CLASS_ATTACK_TYPE attackType,
+				       CLASS_FIGHTER defender,
+				       char numDefender,
+				       uint damage )
 {
 	init( (uchar) SO_FIGHT, (uchar) C_FIGHT_DAMAGE );
-	appendChar( (uchar) fighter );
-	appendChar( (uchar) num );
-	appendInt( damage );
+
+	appendChar( (uchar) attacker );
+	appendChar( (uchar) numAttacker );
+
+	appendChar( (uchar) attackType );
+
+	appendChar( (uchar) defender );
+	appendChar( (uchar) numDefender );
+
+	appendInt( (int)damage );
 
 	send();
 }
@@ -514,6 +567,20 @@ void AttalSocket::sendAnswer( char resp )
 	send();
 }
 
+void AttalSocket::sendAnswerYesNo( bool answer )
+{
+	init( SO_QR, (uchar) C_QR_ANSWER, (uchar) ANSWER_YESNO );
+	appendChar( (uchar) answer );
+	send();
+}
+
+void AttalSocket::sendAnswerEnum( char answer )
+{
+	init( SO_QR, (uchar) C_QR_ANSWER, (uchar) ANSWER_ENUM );
+	appendChar( (uchar) answer );
+	send();
+}
+
 void AttalSocket::sendLordVisit( GenericLord * lord, bool state )
 {
 	init( (uchar) SO_MODIF, (uchar)C_MOD_LORD, (uchar) C_LORD_VISIT );
@@ -664,6 +731,7 @@ void AttalSocket::sendBaseNew( GenericBase * base )
 		appendChar( 0 );
 		appendInt( 0 );
 		appendInt( 0 );
+		appendInt( 0 );
 	}
 	appendChar( base->getId() );
 	appendChar( (uchar)base->getForbiddenBuildingsNumber() );
@@ -684,6 +752,17 @@ void AttalSocket::sendBaseOwner( GenericBase * base, GenericPlayer * player )
 	send();
 }
 
+void AttalSocket::sendBasePopulation( GenericBase * base )
+{
+	init( (uchar)SO_MODIF, (uchar)C_MOD_BASE, (uchar)C_BASE_POPUL );
+	appendInt( base->getCell()->getRow() );
+	appendInt( base->getCell()->getCol() );
+	appendInt( base->getPopulation() );
+	send();
+}
+
+
+
 void AttalSocket::sendBaseBuilding( GenericBase * base, GenericInsideBuilding * building, bool create )
 {
 	init( (uchar)SO_MODIF, (uchar)C_MOD_BASE, (uchar)C_BASE_BUILDING );
