@@ -5,9 +5,9 @@
 ** genericBase.cpp
 ** in order to manage buildings...
 **
-** Version : $Id: genericBase.cpp,v 1.7 2004/04/05 18:40:16 lusum Exp $
+** Version : $Id: genericBase.cpp,v 1.18 2004/08/06 10:33:03 lusum Exp $
 **
-** Author(s) : Pascal Audoux
+** Author(s) : Pascal Audoux - Sardi Carlo
 **
 ** Date : 10/08/2000
 **
@@ -40,6 +40,7 @@
 #include "libCommon/genericPlayer.h"
 #include "libCommon/log.h"
 #include "libCommon/unit.h"
+#include "libCommon/priceMarket.h"
 
 extern DataTheme DataTheme;
 extern QString DATA_PATH;
@@ -66,13 +67,17 @@ GenericBase::GenericBase()
 		_units[i] = 0;
 	}
 
+
 	_buildings.setAutoDelete( true );
 	_forbidden.setAutoDelete( true );
+	
 }
 
 GenericBase::~GenericBase()
 {
-
+	for( uint i = 0; i < MAX_UNIT; i++ ) {
+		delete _units[ i ];
+	}
 }
 
 void GenericBase::save( QTextStream * ts, int indent )
@@ -143,7 +148,7 @@ void GenericBase::exchangeLords()
 	_garrisonLord = temp;
 }
 
-int GenericBase::getDoorRow()
+uint GenericBase::getDoorRow()
 {
 	if( (uint)_race < DataTheme.bases.count() ) {
 		return DataTheme.bases.at( _race )->getDoorRow();
@@ -152,7 +157,7 @@ int GenericBase::getDoorRow()
 	}
 }
 
-int GenericBase::getDoorCol()
+uint GenericBase::getDoorCol()
 {
 	if( (uint)_race < DataTheme.bases.count() ) {
 		return DataTheme.bases.at( _race )->getDoorCol();
@@ -172,12 +177,36 @@ void GenericBase::getInitPopul()
 
 }
 
-int GenericBase::getDispo( int row, int col )
+void GenericBase::getPopGrowth()
+{
+
+	if( (uint)_race < DataTheme.bases.count() ) {
+		_population = (_population * (100 + (DataTheme.bases.at( _race )->getPopGrowth()))/100);
+	} else {
+		_population = 0;
+	}
+
+}
+
+void GenericBase::getPopLoss()
+{
+
+	if( (uint)_race < DataTheme.bases.count() ) {
+		_population = (_population * (100 - (DataTheme.bases.at( _race )->getPopLoss()))/100);
+		if(_population <= 0)
+			_population = 100;
+	} else {
+		_population = 0;
+	}
+
+}
+
+GenericMapDisposition::DispositionType GenericBase::getDisposition( uint row, uint col )
 {
 	if( (uint)_race < DataTheme.bases.count() ) {
-		return DataTheme.bases.at( _race )->getDispo( row, col );
+		return DataTheme.bases.at( _race )->getDisposition( row, col );
 	} else {
-		return 0;
+		return GenericMapDisposition::OCCUPIED;
 	}
 }
 
@@ -313,9 +342,8 @@ void GenericBase::initCreatureProduction()
 		GenericInsideBuilding * building = _buildings.at( i );
 		InsideBuildingModel * model = baseModel->getBuildingModel( building->getLevel() );
 		InsideAction * action = model->getAction();
-		// XXX: change '3' in an enum...
 		if( action ) {
-			if( action->getType() == 3 ) {
+			if( action->getType() == INSIDE_CREA ) {
 				int race = action->getParam( 0 );
 				int level = action->getParam( 1 );
 				Creature * creature = DataTheme.creatures.at( race, level );
@@ -387,23 +415,15 @@ int GenericBase::getVision()
 //
 
 GenericBaseModel::GenericBaseModel()
-: _race( 0 ), _doorRow( 0 ), _doorCol( 0 ), _vision( 3 )
+: _race( 0 ), _vision( 3 )
 {
 	_population = 0;
+	_growth = 0;
+	_loss = 0;
 	_buildings.setAutoDelete( true );
-}
-
-void GenericBaseModel::setDispo( int row, int col, int disp )
-{
-	if( ( row > 4 ) || ( row < 0 ) || ( col > 4 ) || (col < 0 ) ) {
-		return;
-	}
-
-	_dispo[row][col] = disp;
-	if( disp == 1 ) {
-		_doorCol = col;
-		_doorRow = row;
-	}
+	GenericMapDisposition::init( 5, 5 );
+	setDisposition( 4, 0, DOOR );
+	_price= new PriceMarket();
 }
 
 void GenericBaseModel::addBuilding( InsideBuildingModel * building )
@@ -424,6 +444,100 @@ void GenericBaseModel::removeBuilding( uint num )
 	}
 }
 
+void GenericBaseModel::save( QTextStream * ts, int indent )
+{
+
+	uint i,j,k;
+	uint nbRes = DataTheme.resources.count();
+
+	indentation( ts, indent );
+	*ts << "<base>" << endl;
+
+	indentation( ts, indent );
+	*ts << "\t<name>" << _modelName << "</name>" << endl;
+	
+	indentation( ts, indent );
+	*ts << "\t<!--race>" << _race << "</race-->" << endl;
+
+
+	GenericMapDisposition::save( ts, indent+1 );
+	
+
+	indentation( ts, indent );
+	*ts << "\t<population>" << endl;
+				indentation( ts, indent+1 );
+				*ts << "\t<value>" << _population << "</value>" << endl;
+				indentation( ts, indent+1 );
+				*ts << "\t<growth>" << _growth << "</growth>" << endl;
+				indentation( ts, indent+1 );
+				*ts << "\t<loss>" << _loss << "</loss>" << endl;
+	indentation( ts, indent+1 );
+	*ts << "</population>" << endl;
+	indentation( ts, indent+1 );
+	*ts << "<rescost>" << endl;
+	for( k = 0; k < nbRes; k++ ) {
+			if( _price->getResourcePrice(k) > 0 ) {
+				indentation( ts, indent+1 );
+				*ts << "\t<cost ressource=\"" << k << "\">";
+				*ts << _price->getResourcePrice( k ) << "</cost>" << endl;
+			}
+		}
+	indentation( ts, indent+1 );
+	*ts << "</rescost>" << endl;
+
+	//indentation( ts, indent );
+
+	for( i = 0; i < _buildings.count(); ++i ) {
+		indentation( ts, indent+1 );
+		*ts << "<building>" << endl;
+		indentation( ts, indent+1 );
+		InsideBuildingModel * build = _buildings.at(i);
+		*ts << "\t<name>" << build->getName() << "</name>" << endl;
+		indentation( ts, indent+1 );
+		*ts << "\t<description>" << build->getDescription() << "</description>" << endl;
+		indentation( ts, indent+1 );
+		*ts << "\t<x>" << build->getX() << "</x>" << endl;
+		indentation( ts, indent+1 );
+		*ts << "\t<y>" << build->getY() << "</y>" << endl;
+		for( k = 0; k < DataTheme.resources.count(); k++ ) {
+			if( build->getCost( k ) > 0 ) {
+				indentation( ts, indent+1 );
+				*ts << "\t<cost ressource=\"" << k << "\">";
+				*ts << build->getCost( k ) << "</cost>" << endl;
+			}
+		}
+		for( k = 0; k < DataTheme.resources.count(); k++ ) {
+			if( build->getMantCost( k ) > 0 ) {
+				indentation( ts, indent+1 );
+				*ts << "\t<mcost ressource=\"" << k << "\">";
+				*ts << build->getMantCost( k ) << "</mcost>" << endl;
+			}
+		}
+		if(build->getAction()){
+		indentation( ts, indent+1 );
+			*ts << "\t<action type=\"" << (uint) ( build->getAction()->getType() )  << "\">" << endl; 
+			for( j = 0; j < build->getAction()->getParamNumber(); ++j ) {
+				indentation( ts, indent+2 );
+				*ts << "\t<param>" << build->getAction()->getParam(j)  << "</param>" << endl;
+			}
+			indentation( ts, indent+2 );
+			*ts << "</action>" << endl;
+		}
+
+		indentation( ts, indent+1 );
+		*ts << "</building>" << endl;
+	}
+
+
+
+	indentation( ts, indent );
+	*ts << "</base>" << endl;
+	*ts << flush;
+
+}
+
+
+
 //
 // ----- BaseList -----
 //
@@ -453,11 +567,45 @@ bool BaseList::init()
 	return true;
 }
 
+bool BaseList::save()
+{
+	
+	QString filename = DATA_PATH + "bases.dat";
+	QFile file( filename );
+
+	if (! file.open( IO_WriteOnly ) ) {
+		logEE( "Could not open file %s for writing\n", filename.latin1() );
+		return false;
+	}
+
+	QTextStream ts( &file );
+
+	ts << "<?xml version=\"1.0\" encoding=\"UTF-8\"?><!DOCTYPE bases>" << endl;
+	ts << "<bases>" << endl;
+
+	GenericBaseModel * base;
+	for( uint i = 0; i < count(); i++ ) {
+		base = at( i );
+		if( base ) {
+			base->save( &ts, 1 );
+		}
+	}
+
+	ts << "</bases>" << endl;
+
+	file.close();
+
+	return true;
+	
+}
+
+
+
 GenericBaseModel * BaseList::at( QString typeName )
 {
 	GenericBaseModel * ret = first();
 	
-	QListIterator<GenericBaseModel> ite( *this );
+	QPtrListIterator<GenericBaseModel> ite( *this );
 	
 	for( ite.toFirst(); ite.current(); ++ite ) {
 		if( ite.current()->getModelName() == typeName ) {
@@ -470,13 +618,13 @@ GenericBaseModel * BaseList::at( QString typeName )
 
 // void BaseList::clear()
 // {
-// 	QList<GenericBaseModel>::clear();
+// 	QPtrList<GenericBaseModel>::clear();
 // 	_type.clear();
 // }
 
 // int BaseList::addType( QString typeName )
 // {
-// 	QListIterator<QString> ite( _type );
+// 	QPtrListIterator<QString> ite( _type );
 // 	int cpt = 0, ret = -1;
 	
 // 	for( ite.toFirst(); ite.current(); ++ite ) {
@@ -529,8 +677,27 @@ bool BaseHandler::startElement( const QString &, const QString &, const QString
 		_state = StateName;
 	} else if( qName == "disposition" && _state == StateBase ) {
 		_state = StateDisposition;
+		_height = atts.value( "height" ).toUInt();
+		_width = atts.value( "width" ).toUInt();
+		_base->GenericMapDisposition::init( _height, _width );
 	} else if( qName == "population" && _state == StateBase ) {
 		_state = StatePopulation;
+	} else if( qName == "value" && _state == StatePopulation ) {
+		_state = StatePopulationValue;
+	} else if( qName == "growth" && _state == StatePopulation ) {
+		_state = StatePopulationGrowth;
+	} else if( qName == "loss" && _state == StatePopulation ) {
+		_state = StatePopulationLoss;
+	} else if( qName == "rescost" && _state == StateBase ) {
+		_price = new PriceMarket();
+		_state = StateRess;
+	} else if( qName == "cost" && _state == StateRess ) {
+		if( atts.index( "ressource" ) != -1 ) {
+			_csress = atts.value( "ressource" ).toInt();
+		} else {
+			_csress = 0;
+		}
+		_state = StateRessCost;
 	} else if( qName == "building" && _state == StateBase ) {
 		_building = new InsideBuildingModel();
 		_building->setRace( _race );
@@ -598,6 +765,22 @@ bool BaseHandler::endElement( const QString &, const QString &, const QString &
 	case StatePopulation:
 		_state = StateBase;
 		break;
+	case StatePopulationValue:
+		_state = StatePopulation;
+		break;
+	case StatePopulationGrowth:
+		_state = StatePopulation;
+		break;
+	case StatePopulationLoss:
+		_state = StatePopulation;
+		break;
+	case StateRess:
+		_base->setPriceMarket( _price );
+		_state = StateBase;
+		break;
+	case StateRessCost:
+		_state = StateRess;
+		break;
 	case StateBuilding:
 		_base->addBuilding( _building );
 		_state = StateBase;
@@ -652,15 +835,31 @@ bool BaseHandler::characters( const QString& ch )
 		break;
 	case StateDisposition:{
 		QStringList li = QStringList::split( " ", ch_simplified );
-		for( int i = 0; i < 5; i++ ) {
-			for( int j = 0; j < 5; j++ ) {
-				_base->setDispo( i, j, li[ i*5 + j ].toInt() );
+		GenericMapDisposition::DispositionType type;
+		for( int i = 0; i < _height; i++ ) {
+			for( int j = 0; j < _width; j++ ) {
+				type = GenericMapDisposition::DispositionType( li[ i * _width + j ].toInt() );
+				_base->setDisposition( i, j, type );
 			}
-		}	}
+		}
+		}
 		break;
-	case StatePopulation:
+	case StatePopulationValue:
 		_base->setPopulation( ch_simplified.toInt() );
 		break;
+	case StatePopulationGrowth:
+		_base->setPopGrowth( ch_simplified.toInt() );
+		break;
+	case StatePopulationLoss:
+		_base->setPopLoss( ch_simplified.toInt() );
+		break;
+	case StateRessCost:{
+		int cost = ch_simplified.toInt();
+		 cost = cost < 10000 ?  cost : 100;
+		 cost = cost > 0 ?  cost : 100;
+		_price->setResourcePrice( _csress,cost );
+	 }
+		break;
 	case StateBuildingName:
 		_building->setName( ch_simplified );
 		break;
