@@ -5,7 +5,7 @@
 ** genericLord.cpp
 ** manages a lord and its units
 **
-** Version : $Id: genericLord.cpp,v 1.13 2004/03/07 18:31:03 audoux Exp $
+** Version : $Id: genericLord.cpp,v 1.15 2004/07/28 21:09:04 lusum Exp $
 **
 ** Author(s) : Pascal Audoux
 **
@@ -34,13 +34,15 @@
 // application specific include files
 #include "libCommon/artefact.h"
 #include "libCommon/artefactManager.h"
+#include "libCommon/categoryManager.h"
 #include "libCommon/dataTheme.h"
 #include "libCommon/genericPlayer.h"
 #include "libCommon/log.h"
+#include "libCommon/lordCategoryModel.h"
 #include "libCommon/pathFinder.h"
 #include "libCommon/unit.h"
 #include "libCommon/warMachine.h"
-#include "libCommon/categoryManager.h"
+
 
 extern DataTheme DataTheme;
 extern QString DATA_PATH;
@@ -155,6 +157,10 @@ GenericLord::GenericLord()
 	for( int i = 0; i < MAX_UNIT; i++ ) {
 		_units[i] = 0;
 	}
+	
+	for(int i = PR_ENEMY;i<=PR_LAST;i++){ 
+		_priorities[i]=i;
+	}	
 
 	_artefactManager = new ArtefactManager( this );
 	_machines.setAutoDelete( true );
@@ -189,7 +195,7 @@ QString GenericLord::getCategoryName()
 {
 	QString ret = "";
 	if( _id != 0 ) {
-		ret = _model->getCategory();
+		ret = _model->getCategory()->getName();
 	}
 	return ret;
 }
@@ -769,16 +775,15 @@ uint GenericLord::computeForceIndicator()
 //
 
 GenericLordModel::GenericLordModel()
-	: _race( 0 ),
-	_name( "" ),
-	_category( "" ),
+	: _name( "" ),
+	_category( 0 ),
 	_move( 0 ),
 	_maxMove( 0 ),
 	_technicPoints( 0 ),
 	_maxTechnicPoints( 0 ),
-	_morale( 0 ), 
+	_morale( 0 ),
 	_luck( 0 ),
-	_power( 0 ), 
+	_power( 0 ),
 	_knowledge( 0 ),
 	_attack( 0 ),
 	_defense( 0 ),
@@ -791,6 +796,17 @@ GenericLordModel::GenericLordModel()
 	_machines.setAutoDelete( true );
 }
 
+uint GenericLordModel::getRace()
+{
+	uint ret = 0;
+
+	if( _category ) {
+		ret = _category->getRace();
+	}
+
+	return ret;
+}
+
 
 void GenericLordModel::setBaseCharac( LordCharac type, int value )
 {
@@ -912,11 +928,9 @@ void GenericLordModel::save( QTextStream & ts, int indent )
 	uint j;
 
 	indentation( &ts, indent );
-	ts << "<lord name=\"" << getName() << "\">" << endl;
+	ts << "<lord category=\"" << DataTheme.getLordCategory( _category ) << "\">" << endl;
 	indentation( &ts, indent + 1 );
-	ts << "<race>" << DataTheme.creatures.getRace( getRace() )->getName() << "</race>" << endl;
-	indentation( &ts, indent + 1 );
-	ts << "<category>" << getCategory() << "</category>" << endl;
+	ts << "<name>" << getName() << "</name>" << endl;
 	indentation( &ts, indent + 1 );
 	ts << "<characteristic type=\"attack\">" << getBaseCharac( ATTACK ) << "</characteristic>" << endl;
 	indentation( &ts, indent + 1 );
@@ -991,7 +1005,7 @@ bool LordList::init()
 		logEE( "Parse Error (%s) : %s", QString( DATA_PATH + "lords.dat" ).latin1(), handler.errorProtocol().latin1() );
 		return false;
 	}
-	
+
 	return true;
 }
 
@@ -1025,7 +1039,9 @@ bool LordList::save()
 	return true;
 }
 
-/***************************************************************************/
+//
+// ----- LordHandler -----
+//
 
 LordHandler::LordHandler( LordList * list )
 {
@@ -1051,12 +1067,10 @@ bool LordHandler::startElement( const QString &, const QString &, const QString
 	} else if ( qName == "lord" && _state == StateDocument ) {
 		_state = StateLord;
 		_lord = new GenericLordModel();
-		_lord->setName( atts.value( "name" ) );
+		_lord->setCategory( DataTheme.lordCategories.at( atts.value( "category" ).toUInt() ) );
 		_numUnit = 0;
-	} else if ( qName == "race" && _state == StateLord ) {
-		_state = StateRace;
-	} else if ( qName == "category" && _state == StateLord ) {
-		_state = StateCategory;
+	} else if ( qName == "name" && _state == StateLord ) {
+		_state = StateName;
 	} else if( qName == "characteristic" && _state == StateLord ) {
 		_state = StateCharac;
 		_charac = detectCharac( atts.value( "type" ) );
@@ -1087,10 +1101,7 @@ bool LordHandler::endElement( const QString &, const QString &, const QString &
 		_state = StateDocument;
 		_list->append( _lord );
 		break;
-	case StateRace:
-		_state = StateLord;
-		break;
-	case StateCategory:
+	case StateName:
 		_state = StateLord;
 		break;
 	case StateCharac:
@@ -1133,11 +1144,8 @@ bool LordHandler::characters( const QString& ch )
 		return true;
 
 	switch( _state ) {
-	case StateRace:
-		_lord->setRace( DataTheme.creatures.giveNumRace( ch_simplified ) );
-		break;
-	case StateCategory:
-		_lord->setCategory( ch_simplified );
+	case StateName:
+		_lord->setName( ch_simplified );
 		break;
 	case StateCharac:
 		_lord->setBaseCharac( _charac, ch_simplified.toInt() );
