@@ -5,7 +5,7 @@
 ** fight.cpp
 ** Manages the whole fight
 **
-** Version : $Id: fight.cpp,v 1.15 2004/04/06 20:39:16 audoux Exp $
+** Version : $Id: fight.cpp,v 1.20 2004/08/08 14:32:32 audoux Exp $
 **
 ** Author(s) : Cyrille Verrier, Pascal Audoux
 **
@@ -47,13 +47,16 @@
 #include "libFight/fightResult.h"
 #include "libFight/fightSettingsDialog.h"
 
+#include "libClient/attalSound.h"
 #include "libClient/chatWidget.h"
 #include "libClient/game.h"
+#include "libClient/imageTheme.h"
 #include "libClient/lord.h"
 #include "libClient/widget.h"
 
 extern QString DATA_PATH;
 extern QString IMAGE_PATH;
+extern ImageTheme ImageTheme;
 
 /** add comments here */
 Fight::Fight( QWidget * parent , const char * name )
@@ -67,9 +70,9 @@ Fight::Fight( QWidget * parent , const char * name )
 	_isActive = false;
 	_isCreature = false;
 	_activeUnit = 0;
-	_lostAttack = new QList<GenericFightUnit>;
+	_lostAttack = new QPtrList<GenericFightUnit>;
 	_lostAttack->setAutoDelete( true );
-	_lostDefense = new QList<GenericFightUnit>;
+	_lostDefense = new QPtrList<GenericFightUnit>;
 	_lostDefense->setAutoDelete( true );
 
 	for( int i = 0; i < MAX_UNIT; i ++ ) {
@@ -429,21 +432,23 @@ void Fight::updateUnits( void )
 	GenericFightUnit * oldUnit, * newUnit;
 	uint  i;
 
-	oldLord = _game->getLord( getAttack()->getId() );
-	for( i = 0; i < MAX_UNIT; i++ ) {
-		newUnit = getUnit( i, FIGHTER_ATTACK );
-		if(newUnit){
-			if(newUnit->getNumber()==0){
-				newUnit=0;
+	if( getAttack() ) {
+		oldLord = _game->getLord( getAttack()->getId() );
+		for( i = 0; i < MAX_UNIT; i++ ) {
+			newUnit = getUnit( i, FIGHTER_ATTACK );
+			if(newUnit){
+				if(newUnit->getNumber()==0){
+					newUnit=0;
+				}
+			}
+			oldUnit = oldLord->getUnit( i );
+			if( newUnit && oldUnit ) {
+				oldUnit->setNumber( newUnit->getNumber()  );
+				oldUnit->setMove( newUnit->getMove() );
+				oldUnit->setHealth( newUnit->getHealth() );
+			} else if (oldUnit) {
+				oldLord->setUnit(i,0);
 			}
-		}
-		oldUnit = oldLord->getUnit( i );
-		if( newUnit && oldUnit ) {
-			oldUnit->setNumber( newUnit->getNumber()  );
-			oldUnit->setMove( newUnit->getMove() );
-			oldUnit->setHealth( newUnit->getHealth() );
-		} else if (oldUnit) {
-			oldLord->setUnit(i,0);
 		}
 	}
 
@@ -525,18 +530,49 @@ void Fight::socketFightMove()
 void Fight::socketFightDamage()
 {
 	//logDD("fight dama");
-	uchar cla = _socket->readChar();
-	uchar num = _socket->readChar();
+	uchar claAtt = _socket->readChar ();
+	uchar numAtt = _socket->readChar();
+
+	CLASS_ATTACK_TYPE type = (CLASS_ATTACK_TYPE) _socket->readChar ();
+
+	uchar claDef = _socket->readChar();
+	uchar numDef = _socket->readChar();
 	int damages = _socket->readInt();
 
-	int numKilled = 0;
-	if( (CLASS_FIGHTER)cla == FIGHTER_ATTACK ) {
-		numKilled = _unitsAtt[ num ]->hit( damages );
-		//logDD( "DAMAGES %d", numKilled );
-		addCasualties( FIGHTER_ATTACK, _unitsAtt[num]->getRace(), _unitsAtt[num]->getLevel(), numKilled );
+	FightUnit* attUnit = 0;
+	FightUnit* defUnit = 0;
+	
+	if ( (CLASS_FIGHTER)claAtt == FIGHTER_ATTACK ) {
+		attUnit = _unitsAtt[ numAtt ];
+		defUnit = _unitsDef[ numDef ];
 	} else {
-		numKilled = _unitsDef[ num ]->hit( damages );
-		addCasualties( FIGHTER_DEFENSE, _unitsDef[num]->getRace(), _unitsDef[num]->getLevel(), numKilled );
+		attUnit = _unitsDef[ numAtt ];
+		defUnit = _unitsAtt[ numDef ];
+	}
+
+	switch ( type ) {
+		case ATTACK_SHOOT:
+			ImageTheme.playSound( AttalSound::SND_ARROW );
+			attUnit->animateShooting();
+			break;
+		case ATTACK_FIGHT:
+			ImageTheme.playSound( AttalSound::SND_HIT );
+			attUnit->animateFighting();
+			break;
+		default: 
+			break;
+	};
+
+	defUnit->animateDefending ();
+
+	int numKilled = 0;
+	if( (CLASS_FIGHTER)claDef == FIGHTER_ATTACK ) {
+		numKilled = _unitsAtt[ numDef ]->hit( damages );
+		//logDD( "DAMAGES %d", numKilled );
+		addCasualties( FIGHTER_ATTACK, _unitsAtt[numDef]->getRace(), _unitsAtt[numDef]->getLevel(), numKilled );
+	} else {
+		numKilled = _unitsDef[ numDef ]->hit( damages );
+		addCasualties( FIGHTER_DEFENSE, _unitsDef[numDef]->getRace(), _unitsDef[numDef]->getLevel(), numKilled );
 	}
 }
 
@@ -577,13 +613,13 @@ void Fight::setActive( CLASS_FIGHTER cla, int num )
 
 void Fight::moveUnit( FightCell * cell )
 {
- GenericFightCell * current;
-	QStack<GenericFightCell> path = _map->computePath( _activeUnit, cell );
+	GenericFightCell * current;
+	QPtrStack<GenericFightCell> path = _map->computePath( _activeUnit, cell );
 
- while( ! path.isEmpty() ) {
+ 	while( ! path.isEmpty() ) {
 		current = path.pop();
 		_socket->sendFightUnitMove( giveClass( _activeUnit ), giveNum( _activeUnit ), current );
- }
+	}
 
 	_socket->sendFightUnitEndMove();
 	_activeUnit->setActive( false );
@@ -668,7 +704,7 @@ void Fight::addCasualties( CLASS_FIGHTER fighter, uint race, uint level, uint nb
 
 	bool found = false;
 
-	QList<GenericFightUnit> * list;
+	QPtrList<GenericFightUnit> * list;
 
 	if( fighter == FIGHTER_ATTACK ) {
 		list = _lostAttack;
