@@ -5,7 +5,7 @@
 ** attalServer.cpp
 ** the server : manage connections
 **
-** Version : $Id: attalServer.cpp,v 1.10 2004/04/09 17:14:05 audoux Exp $
+** Version : $Id: attalServer.cpp,v 1.20 2004/10/08 23:04:08 audoux Exp $
 **
 ** Author(s) : Pascal Audoux
 **
@@ -37,9 +37,13 @@
 #include "libCommon/genericMapCreature.h"
 #include "libCommon/log.h"
 #include "libCommon/unit.h"
+#include "libCommon/dataTheme.h"
+
 
 #include "server/engine.h"
 
+extern DataTheme DataTheme;
+
 //
 // ----- AttalPlayerSocket -----
 //
@@ -116,6 +120,7 @@ void AttalServer::slot_socketClose()
 	if( !ite.isEmpty() ) {
 		for( ite.atFirst(); ite.current(); ++ite ) {
 			num=_theSockets.find(ite.current());
+			_mapper->setMapping( ite.current(), num);
 			ite.current()->sendConnectionId(num);
 		}
 	}
@@ -195,6 +200,29 @@ void AttalServer::playerLose( GenericPlayer * player )
 	}
 }
 
+void AttalServer::playerWin( GenericPlayer * player )
+{
+	QListIterator<AttalPlayerSocket> ite( _theSockets );
+
+	if( !ite.isEmpty() ) {
+		for( ite.atFirst(); ite.current(); ++ite ) {
+			ite.current()->sendWinGame( player );
+		}
+	}
+}
+
+void AttalServer::sendGameInfoPlayer()
+{
+	QListIterator<AttalPlayerSocket> ite( _theSockets );
+
+	if( !ite.isEmpty() ) {
+		for( ite.atFirst(); ite.current(); ++ite ) {
+			_currentSocket->sendGameInfoPlayerTeam( ite.current()->getPlayer() );
+		}
+	}
+}
+
+
 void AttalServer::endGame()
 {
 	QListIterator<AttalPlayerSocket> ite( _theSockets );
@@ -208,12 +236,18 @@ void AttalServer::endGame()
 
 void AttalServer::beginTurn()
 {
-	_currentSocket->sendTurnBeg();
+	QListIterator<AttalPlayerSocket> ite( _theSockets );
+
+	if( !ite.isEmpty() ) {
+		for( ite.atFirst(); ite.current(); ++ite ) {
+			ite.current()->sendTurnPlaying( _currentSocket->getPlayer() );
+		}
+	}
 }
 
-void AttalServer::sendLordPlTurn(int count)
+void AttalServer::sendLordPlTurn( int count )
 {
-	_currentSocket->sendLordPlTurn(count);
+	_currentSocket->sendLordPlTurn( count );
 }
 
 void AttalServer::startFight( GenericLord * myLord, GenericPlayer * opponent, GenericLord * opponentLord )
@@ -263,10 +297,21 @@ void AttalServer::updateUnit( GenericPlayer * player, CLASS_FIGHTER fighter, int
 	sock->sendFightModifyUnit( fighter, num, unit );
 }
 
-void AttalServer::damageUnit( GenericPlayer * player, CLASS_FIGHTER fighter, int num, int damage )
+void AttalServer::damageUnit( GenericPlayer * player,
+			      CLASS_FIGHTER attacker,
+			      int numAttacker,
+			      CLASS_ATTACK_TYPE attackType,
+			      CLASS_FIGHTER defender,
+			      int numDefender,
+			      uint damage )
 {
 	AttalPlayerSocket * sock = findSocket( player );
-	sock->sendFightDamageUnit( fighter, num, damage );
+	sock->sendFightDamageUnit( attacker,
+				   numAttacker,
+				   attackType,
+				   defender,
+				   numDefender,
+				   damage );
 }
 
 void AttalServer::activateUnit( GenericPlayer * player, CLASS_FIGHTER fighter, int num )
@@ -316,7 +361,7 @@ void AttalServer::sendPlayerResource( char ressource, int nb )
 void AttalServer::sendPlayerResources( GenericPlayer * player )
 {
 	AttalPlayerSocket * current = findSocket( player );
-	for( int i = 0; i < MAX_RESS; i++ ) {
+	for( uint i = 0; i < DataTheme.resources.count(); i++ ) {
 		current->sendPlayerResource( i, player->getResource( i ) );
 	}
 }
@@ -341,7 +386,7 @@ void AttalServer::sendCell( GenericCell * cell )
 	_currentSocket->sendCell( cell );
 }
 
-void AttalServer::sendAskNone( QString msg )
+void AttalServer::sendAskNone( const QString & msg )
 {
  	QListIterator<AttalPlayerSocket> ite( _theSockets );
 
@@ -352,6 +397,24 @@ void AttalServer::sendAskNone( QString msg )
 	}
 }
 
+void AttalServer::sendAskChest()
+{
+	_currentSocket->sendAskChest();
+}
+
+void AttalServer::updateUnits( GenericLord * lord )
+{
+
+	if( lord ) {
+		if( _currentSocket->getPlayer() == lord->getOwner() ) {
+			_currentSocket->sendLordUnits( lord );
+		} else {
+			/// XXX: would be better to send category of units and not real values
+			_currentSocket->sendLordUnits( lord );
+		}
+	}
+}
+
 void AttalServer::newLord( GenericLord * lord )
 {
 	if( lord ) {
@@ -496,25 +559,21 @@ void AttalServer::newBase( GenericBase * base )
 }
 
 
-void AttalServer::updateBaseBuilding( GenericBase * base, GenericInsideBuilding * building )
+void AttalServer::updateBaseBuilding( GenericBase * base, GenericInsideBuilding * building , GenericPlayer * player )
 {
-	QListIterator<AttalPlayerSocket> ite( _theSockets );
+	AttalPlayerSocket * socket = findSocket( player );
 
-	if( !ite.isEmpty() ) {
-		bool found = false;
-		for( ite.atFirst(); ite.current(); ++ite ) {
-			for( uint i = 0; i < base->getBuildingCount(); i++ ) {
-				GenericInsideBuilding * build = base->getBuilding( i );
-				if( build == building ) {
-					ite.current()->sendBaseBuilding( base, build, true );
-					found = true;
-				}
-			}
-			if( ! found ) {
-				ite.current()->sendBaseBuilding( base, building, false );
-			}
+	bool found = false;
+	for( uint i = 0; i < base->getBuildingCount(); i++ ) {
+		GenericInsideBuilding * build = base->getBuilding( i );
+		if( build == building ) {
+			socket->sendBaseBuilding( base, build, true );
+			found = true;
 		}
 	}
+	if( ! found ) {
+		socket->sendBaseBuilding( base, building, false );
+	}
 }
 
 void AttalServer::sendBaseUnit( GenericBase * base, Creature * creature, int number )
@@ -529,6 +588,14 @@ void AttalServer::sendBaseUnit( GenericBase * base, Creature * creature, int num
 	}
 }
 
+void AttalServer::sendBasePopulation( GenericBase * base , GenericPlayer * player)
+{
+	
+ 	AttalPlayerSocket * socket = findSocket( player );
+
+	socket->sendBasePopulation( base );
+}
+
 void AttalServer::sendLordExchange( GenericLord * lord1, GenericLord * lord2 )
 {
 	_currentSocket->sendExchangeStart( lord1, lord2 );
@@ -567,6 +634,7 @@ void AttalServer::ownBase( GenericBase * base, GenericPlayer * player )
 	/// XXX: owner could be computed in AttalSocket
 	GenericPlayer * owner = base->getOwner();
  	socket->sendBaseOwner( base, owner );
+	socket->sendBasePopulation( base );
 }
 
 /*!
@@ -621,7 +689,7 @@ void AttalServer::delCreature( GenericCell * cell )
 
 void AttalServer::newEvent( GenericEvent * event )
 {
-	QListIterator<AttalPlayerSocket> ite( _theSockets );
+/*	QListIterator<AttalPlayerSocket> ite( _theSockets );
         if( !ite.isEmpty() ) {
                 for( ite.atFirst(); ite.current(); ++ite ) {
 			if( ite.current()->canSee( event->getCell() ) ) {
@@ -629,6 +697,9 @@ void AttalServer::newEvent( GenericEvent * event )
 			}
                 }
         }
+*/
+	if( _currentSocket->canSee( event->getCell() ) ) 
+		_currentSocket->sendNewEvent( event );
 }
 
 void AttalServer::delEvent( GenericEvent * event )
