@@ -5,7 +5,7 @@
 ** parser.cpp
 ** Parser for scenarii and saved games.
 **
-** Version : $Id: parser.cpp,v 1.12 2004/02/14 10:33:53 audoux Exp $
+** Version : $Id: parser.cpp,v 1.20 2004/07/14 19:10:01 lusum Exp $
 **
 ** Author(s) : Pascal Audoux
 **
@@ -43,7 +43,6 @@
 #include "libCommon/genericMap.h"
 #include "libCommon/genericMapCreature.h"
 #include "libCommon/log.h"
-#include "libCommon/quest.h"
 #include "libCommon/unit.h"
 
 #include "libServer/gameData.h"
@@ -61,6 +60,8 @@ bool ScenarioParser::startDocument()
 	_errorProt = "";
 	_player = 0;
 	_state = StateInit;
+	_conditionStack.setAutoDelete( false );
+	_currentCondition = 0;
 	return true;
 }
 
@@ -156,6 +157,8 @@ bool ScenarioParser::startElement( const QString& namespaceURI, const QString& l
 		_data->addPlayer();
 	} else if( qName == "name" && _state == StatePlayer ) {
 		_state = StatePlayerName;
+	} else if( qName == "ruledbyai" && _state == StatePlayer ) {
+		_state = StatePlayerRuled;
 	} else if( qName == "base" && _state == StatePlayer ) {
 		_state = StatePlayerBase;
 	} else if( qName == "building" && _state == StatePlayer ) {
@@ -165,7 +168,7 @@ bool ScenarioParser::startElement( const QString& namespaceURI, const QString& l
 	} else if( qName == "resource" && _state == StatePlayer ) {
 		_state = StatePlayerResource;
 		_res = atts.value( "type" ).toInt();
-	} else if( qName == "quest" && _state == StateDocument ) {
+	} else if( qName == "quests" && _state == StateDocument ) {
 		_state = StateQuest;
 		_questState = QuestInit;
 	} else if( qName == "event" && _state == StateDocument ) {
@@ -198,100 +201,6 @@ bool ScenarioParser::startElement( const QString& namespaceURI, const QString& l
 	return ret;
 }
 
-bool ScenarioParser::startElementLord( const QString &, const QString &, const QString & qName, const QXmlAttributes & atts )
-{
-	if( qName == "col" && _lordState == LordStateInit ) {
-		_lordState = LordStateCol;
-	} else if( qName == "row" && _lordState == LordStateInit ) {
-		_lordState = LordStateRow;
-	} else if( qName == "characteristic" && _lordState == LordStateInit ) {
-		_lordState = LordStateCharac;
-		_charac = detectCharac( atts.value( "type" ) );
-	} else if( qName == "unit" && _lordState == LordStateInit ) {
-		_lordState = LordStateUnit;
-		_pos = atts.value( "pos" ).toInt();
-		_unit = new GenericFightUnit();
-		_race = 0;
-		_level = 0;
-	} else if( qName == "race" && _lordState == LordStateUnit ) {
-		_lordState = LordStateUnitRace;
-	} else if( qName == "level" && _lordState == LordStateUnit ) {
-		_lordState = LordStateUnitLevel;
-	} else if( qName == "number" && _lordState == LordStateUnit ) {
-		_lordState = LordStateUnitNumber;
-	} else if( qName == "move" && _lordState == LordStateUnit ) {
-		_lordState = LordStateUnitMove;
-	} else if( qName == "health" && _lordState == LordStateUnit ) {
-		_lordState = LordStateUnitHealth;
-	} else if( qName == "artefact" && _lordState == LordStateInit ) {
-		_lordState = LordStateArtefact;
-		_pos = 0;
-		_lordArtefact = new GenericLordArtefact();
-		_lordArtefact->setType( atts.value( "type" ).toInt() );
-	} else if( qName == "position" && _lordState == LordStateArtefact ) {
-		_lordState = LordStateArtefactPosition;
-	} else if( qName == "machine" && _lordState == LordStateInit ) {
-		_lordState = LordStateMachine;
-	} else {
-		logEE( "Not found %s", qName.latin1() );
-		return false;
-	}
-	return true;
-}
-
-bool ScenarioParser::startElementQuest( const QString &, const QString &, const QString & qName, const QXmlAttributes & )
-{
-	if( qName == "start" && _questState == QuestInit ) {
-		_questState = QuestStart;
-	} else if( qName == "message" && ( _questState == QuestStart || _questState == QuestEnd ) ) {
-		_oldQuestState = _questState;
-		_questState = QuestStartEndMessage;
-	} else if( qName == "agree" && _questState == QuestStart ) {
-		_questState = QuestStartAgree;
-	} else if( qName == "disagree" && _questState == QuestStart ) {
-		_questState = QuestStartDisagree;
-	} else if( qName == "arg" && ( _questState == QuestStart || _questState == QuestEnd ) ) {
-		_oldQuestState = _questState;
-		_questState = QuestStartEndArg;
-	} else if( qName == "condition" && ( _questState == QuestStart || _questState == QuestEnd ) ) {
-		_oldQuestState = _questState;
-		_questState = QuestStartEndCondition;
-	} else if( qName == "end" && _questState == QuestInit ) {
-		_questState = QuestEnd;
-	} else if( qName == "message" && _questState == QuestInit ) {
-		_questState = QuestMessage;
-	} else {
-		logEE( "Not found %s", qName.latin1() );
-		return false;
-	}
-	return true;
-}
-
-bool ScenarioParser::startElementEvent( const QString &, const QString &, const QString& qName, const QXmlAttributes& atts )
-{
-	if( qName == "row" && _eventState == EventInit ) {
-		_eventState = EventRow;
-	} else if( qName == "col" && _eventState == EventInit ) {
-		_eventState = EventCol;
-	} else if( qName == "artefact" && _eventState == EventInit ) {
-		_eventState = EventArtefact;
-		_event->getArtefact()->setType( atts.value( "type" ).toInt() );
-	} else if( qName == "bonus" && _eventState == EventInit ) {
-		_eventState = EventBonus;
-	} else if( qName == "param" && _eventState == EventBonus ) {
-		_eventState = EventBonusParam;
-	} else if( qName == "chest" && _eventState == EventInit ) {
-		_eventState = EventChest;
-	} else if( qName == "param" && _eventState == EventChest ) {
-		_eventState = EventChestParam;
-	} else {
-		logEE( "Not found %s", qName.latin1() );
-		return false;
-	}
-	return true;
-}
-
-
 bool ScenarioParser::endElement( const QString& namespaceURI, const QString& localName, const QString& qName )
 {
 	bool ret = true;
@@ -326,7 +235,7 @@ bool ScenarioParser::endElement( const QString& namespaceURI, const QString& loc
 		_state = StateDocument;
 		_base->setRace( _baseType );
 		_base->setPosition( _data->getCell( _row, _col ) );
-		_base->setId( _data->getBaseNumber() );
+		_base->setId( _data->getBaseNumber()-1 );
 		break;
 	case StateBaseType:
 		_state = StateBase;
@@ -340,7 +249,7 @@ bool ScenarioParser::endElement( const QString& namespaceURI, const QString& loc
 	case StateBaseBuilding:
 		{
 			GenericInsideBuilding * building = new GenericInsideBuilding();
-			building->setRace( _base->getRace() );
+			building->setRace( _baseType );
 			building->setLevel( _id );
 			_base->addBuilding( building );
 			_state = StateBase;
@@ -402,6 +311,9 @@ bool ScenarioParser::endElement( const QString& namespaceURI, const QString& loc
 	case StatePlayerName:
 		_state = StatePlayer;
 		break;
+	case StatePlayerRuled:
+		_state = StatePlayer;
+		break;
 	case StatePlayerBase:
 		_state = StatePlayer;
 		break;
@@ -426,139 +338,6 @@ bool ScenarioParser::endElement( const QString& namespaceURI, const QString& loc
     return ret;
 }
 
-bool ScenarioParser::endElementLord( const QString &, const QString &, const QString & )
-{
-	switch ( _lordState ) {
-	case LordStateInit:
-		_state = StateDocument;
-		if( _posOk ) {
-			_lord->setPosition( _data->getCell( _row, _col ) );
-		}
-		break;
-	case LordStateCol:
-		_lordState = LordStateInit;
-		_posOk = true;
-		break;
-	case LordStateRow:
-		_lordState = LordStateInit;
-		_posOk = true;
-		break;
-	case LordStateCharac:
-		_lordState = LordStateInit;
-		break;
-	case LordStateUnit:
-		_unit->setCreature( _race, _level );
-		_lord->setUnit( _pos, _unit );
-		_lordState = LordStateInit;
-		break;
-	case LordStateUnitRace:
-		//_unit->setCreature( _type );
-		_lordState = LordStateUnit;
-		break;
-	case LordStateUnitLevel:
-		_lordState = LordStateUnit;
-		break;
-	case LordStateUnitNumber:
-		_unit->setNumber( _number );
-		_lordState = LordStateUnit;
-		break;
-	case LordStateUnitMove:
-		_unit->setMove( _move );
-		_lordState = LordStateUnit;
-		break;
-	case LordStateUnitHealth:
-		_unit->setHealth( _health );
-		_lordState = LordStateUnit;
-		break;
-	case LordStateArtefact:
-		_lord->getArtefactManager()->addArtefact( _lordArtefact );
-		_lordArtefact->setLord( _lord );
-		_lordState = LordStateInit;
-		break;
-	case LordStateArtefactPosition:
-		_lordState = LordStateArtefact;
-		break;
-	case LordStateMachine:
-		_lordState = LordStateInit;
-		_lord->addMachine( _machine );
-		break;
-	default:
-		break;
-	}
-	return true;
-}
-
-bool ScenarioParser::endElementQuest( const QString &, const QString &, const QString & )
-{
-	switch ( _questState ) {
-	case QuestInit:
-		_state = StateDocument;
-		break;
-	case QuestStart:
-		_questState = QuestInit;
-		break;
-	case QuestStartEndMessage:
-		_questState = _oldQuestState;
-		break;
-	case QuestStartAgree:
-		_questState = QuestStart;
-		break;
-	case QuestStartDisagree:
-		_questState = QuestStart;
-		break;
-	case QuestStartEndArg:
-		_questState = _oldQuestState;
-		break;
-	case QuestStartEndCondition:
-		_questState = _oldQuestState;
-		break;
-	case QuestEnd:
-		_questState = QuestInit;
-		break;
-	case QuestMessage:
-		_questState = QuestInit;
-		break;
-	default:
-		break;
-	}
-	return true;
-}
-
-bool ScenarioParser::endElementEvent( const QString &, const QString &, const QString & )
-{
-	switch ( _eventState ) {
-	case EventInit:
-		_event->setCell( _data->getCell( _row, _col ) );
-		_data->getCell( _row, _col )->setEvent( _event );
-		_state = StateDocument;
-		break;
-	case EventRow:
-		_eventState = EventInit;
-		break;
-	case EventCol:
-		_eventState = EventInit;
-		break;
-	case EventArtefact:
-		_eventState = EventInit;
-		break;
-	case EventBonus:
-		_eventState = EventInit;
-		break;
-	case EventBonusParam:
-		_eventState = EventBonus;
-		break;
-	case EventChest:
-		_eventState = EventInit;
-		break;
-	case EventChestParam:
-		_eventState = EventChest;
-		break;
-	default:
-		break;
-	}
-	return true;
-}
-
 bool ScenarioParser::characters( const QString& ch )
 {
 	bool ret = true;
@@ -637,6 +416,11 @@ bool ScenarioParser::characters( const QString& ch )
 		break;
 	case StatePlayerName:
 		break;
+	case StatePlayerRuled:
+		if( _data->getPlayer( _player ) ) {
+			_data->getPlayer( _player )->setRuledByAi( ch_simplified.toInt() );
+		}
+		break;
 	case StatePlayerBase:
 		_data->setBase2Player( ch_simplified.toInt(), _player );
 		break;
@@ -666,6 +450,111 @@ bool ScenarioParser::characters( const QString& ch )
 	return ret;
 }
 
+// Parsing of Lords
+
+bool ScenarioParser::startElementLord( const QString &, const QString &, const QString & qName, const QXmlAttributes & atts )
+{
+	if( qName == "col" && _lordState == LordStateInit ) {
+		_lordState = LordStateCol;
+	} else if( qName == "row" && _lordState == LordStateInit ) {
+		_lordState = LordStateRow;
+	} else if( qName == "characteristic" && _lordState == LordStateInit ) {
+		_lordState = LordStateCharac;
+		_charac = detectCharac( atts.value( "type" ) );
+	} else if( qName == "unit" && _lordState == LordStateInit ) {
+		_lordState = LordStateUnit;
+		_pos = atts.value( "pos" ).toInt();
+		_unit = new GenericFightUnit();
+		_race = 0;
+		_level = 0;
+	} else if( qName == "race" && _lordState == LordStateUnit ) {
+		_lordState = LordStateUnitRace;
+	} else if( qName == "level" && _lordState == LordStateUnit ) {
+		_lordState = LordStateUnitLevel;
+	} else if( qName == "number" && _lordState == LordStateUnit ) {
+		_lordState = LordStateUnitNumber;
+	} else if( qName == "move" && _lordState == LordStateUnit ) {
+		_lordState = LordStateUnitMove;
+	} else if( qName == "health" && _lordState == LordStateUnit ) {
+		_lordState = LordStateUnitHealth;
+	} else if( qName == "artefact" && _lordState == LordStateInit ) {
+		_lordState = LordStateArtefact;
+		_pos = 0;
+		_lordArtefact = new GenericLordArtefact();
+		_lordArtefact->setType( atts.value( "type" ).toInt() );
+	} else if( qName == "position" && _lordState == LordStateArtefact ) {
+		_lordState = LordStateArtefactPosition;
+	} else if( qName == "machine" && _lordState == LordStateInit ) {
+		_lordState = LordStateMachine;
+	} else {
+		logEE( "Not found %s", qName.latin1() );
+		return false;
+	}
+	return true;
+}
+
+bool ScenarioParser::endElementLord( const QString &, const QString &, const QString & )
+{
+	switch ( _lordState ) {
+	case LordStateInit:
+		_state = StateDocument;
+		if( _posOk ) {
+			_lord->setPosition( _data->getCell( _row, _col ) );
+		}
+		break;
+	case LordStateCol:
+		_lordState = LordStateInit;
+		_posOk = true;
+		break;
+	case LordStateRow:
+		_lordState = LordStateInit;
+		_posOk = true;
+		break;
+	case LordStateCharac:
+		_lordState = LordStateInit;
+		break;
+	case LordStateUnit:
+		_unit->setCreature( _race, _level );
+		_lord->setUnit( _pos, _unit );
+		_lordState = LordStateInit;
+		break;
+	case LordStateUnitRace:
+		//_unit->setCreature( _type );
+		_lordState = LordStateUnit;
+		break;
+	case LordStateUnitLevel:
+		_lordState = LordStateUnit;
+		break;
+	case LordStateUnitNumber:
+		_unit->setNumber( _number );
+		_lordState = LordStateUnit;
+		break;
+	case LordStateUnitMove:
+		_unit->setMove( _move );
+		_lordState = LordStateUnit;
+		break;
+	case LordStateUnitHealth:
+		_unit->setHealth( _health );
+		_lordState = LordStateUnit;
+		break;
+	case LordStateArtefact:
+		_lord->getArtefactManager()->addArtefact( _lordArtefact );
+		_lordArtefact->setLord( _lord );
+		_lordState = LordStateInit;
+		break;
+	case LordStateArtefactPosition:
+		_lordState = LordStateArtefact;
+		break;
+	case LordStateMachine:
+		_lordState = LordStateInit;
+		_lord->addMachine( _machine );
+		break;
+	default:
+		break;
+	}
+	return true;
+}
+
 bool ScenarioParser::charactersLord( const QString& ch )
 {
 	bool ret = true;
@@ -707,27 +596,67 @@ bool ScenarioParser::charactersLord( const QString& ch )
 	return ret;
 }
 
-bool ScenarioParser::charactersQuest( const QString& /*ch*/ )
-{
-	bool ret = true;
+// Parsing of Events
 
-	switch( _questState ) {
-	case QuestStartEndMessage:
+bool ScenarioParser::startElementEvent( const QString &, const QString &, const QString& qName, const QXmlAttributes& atts )
+{
+	if( qName == "row" && _eventState == EventInit ) {
+		_eventState = EventRow;
+	} else if( qName == "col" && _eventState == EventInit ) {
+		_eventState = EventCol;
+	} else if( qName == "artefact" && _eventState == EventInit ) {
+		_eventState = EventArtefact;
+		_event->getArtefact()->setType( atts.value( "type" ).toInt() );
+	} else if( qName == "bonus" && _eventState == EventInit ) {
+		_eventState = EventBonus;
+		_event->getBonus()->setType( (GenericBonus::BonusType) atts.value( "type" ).toInt() );
+	} else if( qName == "param" && _eventState == EventBonus ) {
+		_eventState = EventBonusParam;
+	} else if( qName == "chest" && _eventState == EventInit ) {
+		_eventState = EventChest;
+	} else if( qName == "param" && _eventState == EventChest ) {
+		_eventState = EventChestParam;
+	} else {
+		logEE( "Not found %s", qName.latin1() );
+		return false;
+	}
+	return true;
+}
+
+bool ScenarioParser::endElementEvent( const QString &, const QString &, const QString & )
+{
+	switch ( _eventState ) {
+	case EventInit:
+		_event->setCell( _data->getCell( _row, _col ) );
+		_data->getCell( _row, _col )->setEvent( _event );
+		_state = StateDocument;
 		break;
-	case QuestStartAgree:
+	case EventRow:
+		_eventState = EventInit;
 		break;
-	case QuestStartDisagree:
+	case EventCol:
+		_eventState = EventInit;
 		break;
-	case QuestStartEndArg:
+	case EventArtefact:
+		_eventState = EventInit;
 		break;
-	case QuestStartEndCondition:
+	case EventBonus:
+		_event->getBonus()->setupBonus();
+		_eventState = EventInit;
 		break;
-	case QuestMessage:
+	case EventBonusParam:
+		_eventState = EventBonus;
+		break;
+	case EventChest:
+		_eventState = EventInit;
+		break;
+	case EventChestParam:
+		_eventState = EventChest;
 		break;
 	default:
-		ret = false;
+		break;
 	}
-	return ret;
+	return true;
 }
 
 bool ScenarioParser::charactersEvent( const QString& ch )
@@ -753,6 +682,218 @@ bool ScenarioParser::charactersEvent( const QString& ch )
 	return ret;
 }
 
+// Parsing of Quests
+
+bool ScenarioParser::startElementQuest( const QString &, const QString &, const QString & qName, const QXmlAttributes & atts )
+{
+	if( qName == "quest" && _questState == QuestInit ) {
+		_questState = QuestQuest;
+		if( atts.value( "type" ) == "main" ) {
+			_quest = _data->getMainQuest();
+		} else {
+			_quest = _data->getNewQuest();
+		}
+	} else if( qName == "name" && _questState == QuestQuest ) {
+		_questState = QuestName;
+	} else if( qName == "description" && _questState == QuestQuest ) {
+		_questState = QuestDescription;
+	} else if( qName == "confirmation" && _questState == QuestQuest ) {
+		_questState = QuestConfirmation;
+	} else if( qName == "start" && _questState == QuestQuest ) {
+		_questState = QuestStart;
+	} else if( qName == "message" && ( _questState == QuestStart || _questState == QuestFail || _questState == QuestSuccess ) ) {
+		_oldQuestState = _questState;
+		_questState = QuestStartEndMessage;
+	} else if( qName == "agree" && _questState == QuestStart ) {
+		_questState = QuestStartAgree;
+	} else if( qName == "disagree" && _questState == QuestStart ) {
+		_questState = QuestStartDisagree;
+	} else if( qName == "arg" && ( _questState == QuestStart || _questState == QuestFail || _questState == QuestSuccess ) ) {
+		_oldQuestState = _questState;
+		_questState = QuestStartEndArg;
+	} else if( qName == "condition" && ( _questState == QuestStart || _questState == QuestFail || _questState == QuestSuccess ) ) {
+		_oldQuestState = _questState;
+		_questState = QuestDefCondition;
+		_conditionStack.clear();
+		_currentCondition = 0;
+		manageCondition( atts.value( "type" ) );
+	} else if( qName == "condition" && _questState == QuestDefCondition ) {
+		manageCondition( atts.value( "type" ) );
+	} else if( qName == "param" && _questState == QuestDefCondition ) {
+		_questState = QuestConditionParam;
+	} else if( qName == "fail" && _questState == QuestQuest ) {
+		_questState = QuestFail;
+	} else if( qName == "success" && _questState == QuestQuest ) {
+		_questState = QuestSuccess;
+	} else if( qName == "message" && _questState == QuestQuest ) {
+		_questState = QuestMessage;
+	} else {
+		logEE( "Not found %s", qName.latin1() );
+		return false;
+	}
+	return true;
+}
+
+void ScenarioParser::manageCondition( const QString & type )
+{
+	_params.clear();
+	if( _currentCondition ) {
+		_conditionStack.push( (const QuestConditionComposite *)_currentCondition );
+	}
+
+	if( type == "composite" ) {
+		_currentCondition = new QuestConditionComposite();
+	} else if( type == "lord" ) {
+		_currentCondition = new QuestConditionLord();
+	} else if( type == "date" ) {
+		_currentCondition = new QuestConditionDate();
+	}
+
+	if( _conditionStack.isEmpty() ) {
+		switch( _oldQuestState ) {
+		case QuestStart:
+			_quest->setStartCondition( _currentCondition );
+			break;
+		case QuestFail:
+			_quest->setFailCondition( _currentCondition );
+			break;
+		case QuestSuccess:
+			_quest->setSuccessCondition( _currentCondition );
+			break;
+		default:
+			logEE( "Should not happen" );
+		}
+	} else {
+		_conditionStack.top()->addCondition( _currentCondition );
+	}
+}
+
+bool ScenarioParser::endElementQuest( const QString &, const QString &, const QString & )
+{
+	switch ( _questState ) {
+	case QuestInit:
+		_state = StateDocument;
+		break;
+	case QuestQuest:
+		_questState = QuestInit;
+		break;
+	case QuestName:
+		_questState = QuestQuest;
+		break;
+	case QuestDescription:
+		_questState = QuestQuest;
+		break;
+	case QuestConfirmation:
+		_questState = QuestQuest;
+		break;
+	case QuestStart:
+		_questState = QuestQuest;
+		break;
+	case QuestStartEndMessage:
+		_questState = _oldQuestState;
+		break;
+	case QuestStartAgree:
+		_questState = QuestStart;
+		break;
+	case QuestStartDisagree:
+		_questState = QuestStart;
+		break;
+	case QuestStartEndArg:
+		_questState = _oldQuestState;
+		break;
+	case QuestDefCondition:
+		if( _conditionStack.isEmpty() ) {
+			_questState = _oldQuestState;
+		} else {
+			_currentCondition = _conditionStack.pop();
+		}
+		break;
+	case QuestConditionParam:
+		_questState = QuestDefCondition;
+		break;
+	case QuestFail:
+		_questState = QuestQuest;
+		break;
+	case QuestSuccess:
+		_questState = QuestQuest;
+		break;
+	case QuestMessage:
+		_questState = QuestQuest;
+		break;
+	default:
+		break;
+	}
+	return true;
+}
+
+bool ScenarioParser::charactersQuest( const QString& ch )
+{
+	bool ret = true;
+
+	switch( _questState ) {
+	case QuestName:
+		_quest->setName( ch );
+		break;
+	case QuestDescription:
+		_quest->setDescription( ch );
+		break;
+	case QuestConfirmation:
+		_quest->setConfirmationNeeded( true );
+		_quest->setConfirmationQuestion( ch );
+		break;
+	case QuestStartEndMessage:
+		break;
+	case QuestStartAgree:
+		break;
+	case QuestStartDisagree:
+		break;
+	case QuestStartEndArg:
+		break;
+	case QuestDefCondition:
+		break;
+	case QuestConditionParam:
+		manageConditionParam( ch );
+		break;
+	case QuestQuest:
+		break;
+	case QuestFail:
+		break;
+	case QuestSuccess:
+		break;
+	case QuestMessage:
+		break;
+	default:
+		ret = false;
+	}
+	return ret;
+}
+
+void ScenarioParser::manageConditionParam( const QString & param )
+{
+	switch( _currentCondition->getType() ) {
+	case QuestCondition::COMPOSITE:
+		if( param == "OR" ) {
+			( ( QuestConditionComposite * ) _currentCondition )->setCompositeType( QuestConditionComposite::OR );
+		} else {
+			( ( QuestConditionComposite * ) _currentCondition )->setCompositeType( QuestConditionComposite::AND );
+		}
+		break;
+	case QuestCondition::DATE:
+		break;
+	case QuestCondition::LORD:
+		_params.append( param.toUInt() );
+		if( ( _params.count() == 3 ) && ( _params[ 0 ] == 2 ) ) {
+			( ( QuestConditionLord * ) _currentCondition )->setArtefactCondition( _params[ 1 ], (bool)_params[ 2 ] );
+		} else if( ( _params.count() == 4 ) && ( _params[ 0 ] == 0 ) ) {
+			( ( QuestConditionLord * ) _currentCondition )->setPrimarySkillCondition( (LordCharac)_params[1], (QuestCondition::CheckType)_params[2], _params[3] );
+		} else {
+		}
+		break;
+	case QuestCondition::PLAYER:
+		break;
+	}
+}
+
 bool ScenarioParser::fatalError( const QXmlParseException& exception )
 {
      logEE( "state %d, lordState %d, questState %d, eventState %d", _state, _lordState, _questState, _eventState );
