@@ -5,7 +5,7 @@
 ** propertiesLord.cpp
 ** this is a template for all .cpp files
 **
-** Version : $Id: propertiesLord.cpp,v 1.10 2004/04/09 17:14:06 audoux Exp $
+** Version : $Id: propertiesLord.cpp,v 1.12 2004/08/01 21:08:37 audoux Exp $
 **
 ** Author(s) : Pascal Audoux
 **
@@ -52,7 +52,7 @@ extern ImageTheme ImageTheme;
 // ----- PropertiesLord -----
 //
 
-PropertiesLord::PropertiesLord( QList<GenericPlayer> * players, QWidget  * parent, const char * name )
+PropertiesLord::PropertiesLord( QPtrList<GenericPlayer> * players, QWidget  * parent, const char * name )
 	:QTabDialog( parent, name, true )
 {
 	setCaption( tr( "Lord properties" ) );
@@ -126,7 +126,7 @@ void GeneralCharacteristic::init (GenericLord* lord)
 
     int value = lord->getBaseCharac ( charac );
 
-    setRange(0, 255);
+    setRange( 0, 10000 );
     setValue( value );
 }
 
@@ -227,7 +227,7 @@ QString GeneralCharacteristic::getText ()
 // ----- PropertiesLordGeneral -----
 //
 
-PropertiesLordGeneral::PropertiesLordGeneral( QList<GenericPlayer> * players, QWidget * parent, const char * name )
+PropertiesLordGeneral::PropertiesLordGeneral( QPtrList<GenericPlayer> * players, QWidget * parent, const char * name )
 : QWidget( parent, name )
 {
        QLabel* playerLabel = new QLabel( this );
