@@ -5,7 +5,7 @@
 ** engine.cpp
 ** the game engine !
 **
-** Version : $Id: engine.cpp,v 1.25 2004/04/08 12:49:53 lusum Exp $
+** Version : $Id: engine.cpp,v 1.51 2004/10/12 21:40:37 audoux Exp $
 **
 ** Author(s) : Pascal Audoux
 **
@@ -30,24 +30,32 @@
 // generic include files
 #include <stdlib.h>
 // include files for QT
+#include <qapplication.h>
 #include <qfile.h>
-#include <qxml.h>
-#include <qtextstream.h>
 #include <qmessagebox.h>
+#include <qtextstream.h>
+#include <qxml.h>
 // application specific includes
 #include "libCommon/artefact.h"
 #include "libCommon/artefactManager.h"
 #include "libCommon/dataTheme.h"
+#include "libCommon/define.h"
 #include "libCommon/genericBonus.h"
 #include "libCommon/genericEvent.h"
 #include "libCommon/genericMapCreature.h"
 #include "libCommon/genericInsideBuilding.h"
 #include "libCommon/log.h"
 #include "libCommon/unit.h"
+#include "libCommon/priceMarket.h"
 
+#include "libServer/campaign.h"
 #include "libServer/parser.h"
+#include "libServer/questManager.h"
+
+#include "server/questionManager.h"
 
 extern DataTheme DataTheme;
+extern QString CAMPAIGN_PATH;
 
 Engine::Engine( AttalServer * serv )
 	:GameData()
@@ -59,6 +67,9 @@ Engine::Engine( AttalServer * serv )
 	_state = NOT_PLAYING;
 	_calendar = new Calendar();
 	_isCreature = false;
+	_question = new QuestionManager();
+	_campaign = 0;
+	_tmpPlay = 0;
 
 	QObject::connect( _server, SIGNAL( sig_readEvent( int ) ), SLOT( slot_readSocket( int ) ) );
 	QObject::connect( _server, SIGNAL( sig_newPlayer( AttalPlayerSocket * ) ), SLOT( slot_newPlayer( AttalPlayerSocket * ) ) );
@@ -76,6 +87,9 @@ void Engine::slot_readSocket( int num )
 	case IN_GAME:
 		stateInGame( num );
 		break;
+	case IN_QUESTION:
+		stateInQuestion( num );
+		break;
 	case IN_FIGHT:
 		stateInFight( num );
 		break;
@@ -154,12 +168,7 @@ void Engine::stateInGame( int num )
 			handleInGameMvt( num );
 			break;
 		case SO_QR:
-			switch( _server->getCla2() ) {
-			case C_QR_ANSWER:
-				break;
-			default:
-				logEE( "Should not happen (Server : SO_QR/...)" );
-			}
+			logEE( "Should not happen (Server : SO_QR/... state must be IN_QUESTION)" );
 			break;
 		case SO_TECHNIC:
 			logDD( "Not yet implemented" );
@@ -212,6 +221,50 @@ void Engine::stateInGame( int num )
 	}
 }
 
+void Engine::stateInQuestion( uint num )
+{
+	if( num == (uint) _players.find( _currentPlayer ) ) {
+		switch( _server->getCla1() ) {
+		case SO_MSG:
+			handleMessage();
+			break;
+		case SO_QR:
+			switch( _server->getCla2() ) {
+			case C_QR_ANSWER:
+				handleAnswer();
+				break;
+			default:
+				logEE( "Should not happen (Server : SO_QR/...)" );
+			}
+			break;
+		default:
+			logEE( "Should not happen" );
+		}
+	}
+}
+
+void Engine::handleAnswer()
+{
+	switch( _server->getCla3() ) {
+	case ANSWER_ENUM:{
+		uchar choice = _server->readChar();
+		if( choice == 0 ) {
+			_currentPlayer->increaseResource( 0, 1000 );
+			_server->sendPlayerResource( 0, _currentPlayer->getResource( 0 ) );
+		} else	{
+			GenericLord * lord = _question->getLord();
+			if( lord ) {
+				manageIncreaseExperience( lord, 2500 );
+			} else {
+				logEE( "Lord in _question should not be NULL" );
+			}
+		}
+		_state = IN_GAME;
+		}
+		break;
+	}
+}
+
 void Engine::handleInGameMvt( int num )
 {
 	if( _server->getCla2() == C_MVT_ONE ) {
@@ -333,7 +386,7 @@ void Engine::movingOnArtefact( GenericLord * movingLord, GenericCell * destCell
 	//delete event;
 }
 
-void Engine::movingOnBonus( GenericLord * /*movingLord*/, GenericCell * destCell )
+void Engine::movingOnBonus( GenericLord * movingLord, GenericCell * destCell )
 {
 	GenericEvent * event = destCell->getEvent();
 	GenericBonus * bonus = event->getBonus();
@@ -345,6 +398,7 @@ void Engine::movingOnBonus( GenericLord * /*movingLord*/, GenericCell * destCell
 		movingOnBonusResource( bonus );
 		break;
 	case GenericBonus::BonusPrimSkill:
+		movingOnBonusPrimSkill( movingLord, bonus );
 		break;
 	case GenericBonus::BonusSkill:
 		break;
@@ -382,13 +436,50 @@ void Engine::movingOnBonusResource( GenericBonus * bonus )
 	}
 }
 
-void Engine::movingOnChest( GenericLord * /*movingLord*/, GenericCell * destCell )
+void Engine::movingOnBonusPrimSkill( GenericLord * movingLord, GenericBonus * bonus )
+{
+	uint skill = bonus->getParam( 0 );
+	uint value = bonus->getParam( 1 );
+	LordCharac charac;
+
+	switch( skill ) {
+	case 0:
+		charac = ATTACK;
+		break;
+	case 1:
+		charac = DEFENSE;
+		break;
+	case 2:
+		charac = POWER;
+		break;
+	case 3:
+		charac = KNOWLEDGE;
+		break;
+	case 4:
+		charac = MORALE;
+		break;
+	case 5:
+		charac = LUCK;
+		break;
+	default:
+		logEE( "Should not happen" );
+		charac = ATTACK;
+		break;
+	}
+
+	movingLord->increaseBaseCharac( charac, value );
+	_server->sendLordCharac( movingLord->getOwner(), movingLord, charac );
+}
+
+void Engine::movingOnChest( GenericLord * movingLord, GenericCell * destCell )
 {
 	GenericEvent * event = destCell->getEvent();
 
+	_question->setLord( movingLord );
+	_server->sendAskChest();
+	_state = IN_QUESTION;
 	destCell->setEvent( 0 );
 	_server->delEvent( event );
-
 	_events.remove(event);
 	//delete event;
 }
@@ -439,6 +530,7 @@ void Engine::movingOnBase( GenericLord * movingLord, GenericCell * destCell, int
 		}
 		_currentPlayer->addBase( base );
 		base->setOwner( _currentPlayer );
+		base->getPopLoss();
 		for( index = 0; index < _players.count(); index++ ) {
 			tempPlayer = _players.at( index );
 			if( tempPlayer->canSee( destCell ) ) {
@@ -482,9 +574,9 @@ void Engine::movingOnFreeCell( GenericLord * movingLord, GenericCell * destCell,
 	int lordCol = movingLord->getCell()->getCol();
 
 	movingLord->decreaseBaseCharac( MOVE, cost );
-	QList<GenericCell> removedCells = _currentPlayer->removeLordVision( movingLord );
+	QPtrList<GenericCell> removedCells = _currentPlayer->removeLordVision( movingLord );
 	movingLord->moveTo( destCell );
-	QList<GenericCell> addedCells = _currentPlayer->addLordVision( movingLord );
+	QPtrList<GenericCell> addedCells = _currentPlayer->addLordVision( movingLord );
 	updateMapVision( removedCells, addedCells );
 
 	// XXX: test if enter in vision field of other players...
@@ -647,6 +739,9 @@ void Engine::handleInGameModif()
 
 void Engine::handleInGameModifBase()
 {
+	uint index;
+	GenericPlayer * tempPlayer; 
+
 	switch( _server->getCla3() ) {
 	case C_BASE_BUILDING: {
 		int id = _server->readChar();
@@ -660,7 +755,7 @@ void Engine::handleInGameModifBase()
 
 		if(isBuy==true){
 			if( base->canBuild() && _currentPlayer->canBuy( buildingModel ) ) {
-				for( uint i = 0; i < MAX_RESS; i++ ) {
+				for( uint i = 0; i < DataTheme.resources.count(); i++ ) {
 					if( buildingModel->getCost( i ) != 0 ) {
 						_currentPlayer->decreaseResource( i, buildingModel->getCost( i ) );
 						_server->sendPlayerResource( i, _currentPlayer->getResource( i ) );
@@ -668,11 +763,16 @@ void Engine::handleInGameModifBase()
 				}
 				base->addBuilding( building );
 				base->canBuild( false );
-				_server->updateBaseBuilding( base, base->getBuildingByType( building ) );
+				for( index = 0; index < _players.count(); index++ ) {
+					tempPlayer = _players.at( index );
+					if( tempPlayer->canSee( base->getCell() ) ) {
+						_server->updateBaseBuilding( base, base->getBuildingByType( building ), tempPlayer );
+					}
+				}
 			}
 		} else {
 			if( base->canSell()) {
-				for( uint i = 0; i < MAX_RESS; i++ ) {
+				for( uint i = 0; i < DataTheme.resources.count(); i++ ) {
 					if( buildingModel->getCost( i ) != 0 ) {
 						_currentPlayer->increaseResource( i, buildingModel->getCost( i )/2 );
 						_server->sendPlayerResource( i, _currentPlayer->getResource( i ) );
@@ -681,7 +781,12 @@ void Engine::handleInGameModifBase()
 				GenericInsideBuilding * tmpbuil = base->getBuildingByType( building );
 				base->removeBuilding( tmpbuil );
 				base->canSell( false );
-				_server->updateBaseBuilding( base , tmpbuil  );
+				for( index = 0; index < _players.count(); index++ ) {
+					tempPlayer = _players.at( index );
+					if( tempPlayer->canSee( base->getCell() ) ) {
+						_server->updateBaseBuilding( base , tmpbuil , tempPlayer);
+					}
+				}
 			}
 		}
 
@@ -711,14 +816,48 @@ void Engine::handleInGameModifBase()
 		int firstRes = _server->readInt();
 		int secondRes = _server->readInt();
 		int value = _server->readInt();
-		
-		//logDD("firstRes %d, secondRes %d, value %d",firstRes,secondRes,value);
-		if(firstRes != secondRes){
-			_currentPlayer->increaseResource( secondRes, value);
-			_currentPlayer->decreaseResource( firstRes, value);
-			_server->sendPlayerResource( firstRes, _currentPlayer->getResource(firstRes));
-			_server->sendPlayerResource( secondRes, _currentPlayer->getResource(secondRes));
-		}
+		int cupr,tmpr;
+		uint nbRes = DataTheme.resources.count();
+				
+		 PriceMarket * realPrice = new PriceMarket();
+	
+		 if(firstRes != secondRes){
+			 cupr = 10000;	
+
+			 for( uint i = 0; i < nbRes; i++ ) {
+				 uint nbases = _currentPlayer->numBase();
+				 for( uint j = 0 ; j < nbases ; j++){
+					 PriceMarket * price = DataTheme.bases.at( _currentPlayer->getBase( j )->getRace())->getPriceMarket();
+					 tmpr= price->getResourcePrice( i ) ;
+					 if( tmpr < cupr ) {
+						 cupr = tmpr;
+					 }
+				 }
+				 if(cupr==10000){
+					 cupr=1;
+				 }
+				 realPrice->setResourcePrice(i,cupr);
+				 cupr = 10000;
+			 }
+
+			 if(realPrice->getResourcePrice( firstRes ) >= realPrice->getResourcePrice( secondRes )){
+
+				 cupr= realPrice->getResourceInResource( firstRes,secondRes );
+
+				 //logDD("firstRes %d, secondRes %d, value %d, cupr %d",firstRes,secondRes,value, cupr);
+				 _currentPlayer->increaseResource( secondRes, value*cupr);
+				 _currentPlayer->decreaseResource( firstRes, value);
+			 } else {
+				 cupr= realPrice->getResourceInResource( secondRes,firstRes );
+
+				 //logDD("firstRes %d, secondRes %d, value %d, cupr",firstRes,secondRes,value, cupr);
+				 _currentPlayer->increaseResource( secondRes, value);
+				 _currentPlayer->decreaseResource( firstRes, value*cupr);
+
+			 }
+			 _server->sendPlayerResource( firstRes, _currentPlayer->getResource(firstRes));
+			 _server->sendPlayerResource( secondRes, _currentPlayer->getResource(secondRes));
+		 }
 		} break;
 	default:
 		logDD( "Not yet implemented" );
@@ -772,7 +911,7 @@ void Engine::handleInGameModifLord()
 bool Engine::handleBuildingEnter( GenericBuilding * building, GenericLord * lord )
 {
 	bool enter = false;
-	QList<Action> list;
+	QPtrList<Action> list;
 
 	if( ! building->hasBeenVisited() ) {
 		if( building->getCondition() ) {
@@ -885,9 +1024,6 @@ void Engine::handleBuildingAction( Action * action, GenericLord * lord )
 void Engine::handleInGameTurn()
 {
 	switch( _server->getCla2() ) {
-		case C_TURN_BEG:
-			logEE( "Should not happen (Server : SO_TURN/C_TURN_BEG)" );
-			break;
 		case C_TURN_PLAY:
 			logEE( "Should not happen (Server : SO_TURN/C_TURN_PLAY)" );
 			break;
@@ -945,8 +1081,24 @@ void Engine::reinit()
 	_server->clear();
 }
 
+void Engine::startCampaign()
+{
+	if( _campaign ) {
+		QString filename;
+		uint nbScen = _campaign->getScenarioNumber();
+		
+		for( uint i = 0; i < nbScen; i++ ) {
+			filename = _campaign->getScenario( i );
+			if( loadGame( CAMPAIGN_PATH + filename , false) ) {
+				startGame();
+			}
+		}
+	}
+}
+
 void Engine::startGame()
 {
+	_isFinished = false;
 	if( _players.count() > _server->getNbSocket() ) {
 		return;
 	}
@@ -964,26 +1116,28 @@ void Engine::startGame()
 		_currentPlayer = _players.at( i );
 		_currentPlayer->setMap( _map );
 		_currentPlayer->setNum( i );
+		_currentPlayer->setAlive( true );
 
 		_currentPlayer->initMapVision();
 		_server->setCurrentPlayer( _currentPlayer );
+		_server->sendGameInfoPlayer();
 		for( j = 0; j < _currentPlayer->numLord(); j++ ) {
-			QList<GenericCell> removed;
-			QList<GenericCell> added = _currentPlayer->addLordVision( _currentPlayer->getLord( j ) );
+			QPtrList<GenericCell> removed;
+			QPtrList<GenericCell> added = _currentPlayer->addLordVision( _currentPlayer->getLord( j ) );
 			//updateMapVision( removed, added );
 			//_server->newLord( _currentPlayer->getLord( j ) );
 
 		}
 		for( j = 0; j < _currentPlayer->numBase(); j++ ) {
-			QList<GenericCell> removed;
-			QList<GenericCell> added = _currentPlayer->addBaseVision( _currentPlayer->getBase( j ) );
+			QPtrList<GenericCell> removed;
+			QPtrList<GenericCell> added = _currentPlayer->addBaseVision( _currentPlayer->getBase( j ) );
 			updateMapVision( removed, added );
 			//_server->ownBase( _currentPlayer->getBase( j ), _currentPlayer );
 		}
 
 		for( j = 0; j < _currentPlayer->numBuilding(); j++ ) {
-			QList<GenericCell> removed;
-			QList<GenericCell> added = _currentPlayer->addBuildingVision( _currentPlayer->getBuilding( j ) );
+			QPtrList<GenericCell> removed;
+			QPtrList<GenericCell> added = _currentPlayer->addBuildingVision( _currentPlayer->getBuilding( j ) );
 			updateMapVision( removed, added );
 			//_server->ownBuilding( _currentPlayer->getBuilding( j ), _currentPlayer );
 		}
@@ -1002,8 +1156,8 @@ void Engine::startGame()
 				}
 			}
 		}
-
 	}
+	_server->sendAskNone( getScenarioDescription() );
 	
 	newDay();
 	_currentPlayer = _players.at( 0 );
@@ -1011,10 +1165,15 @@ void Engine::startGame()
 	_currentPlayer->newWeek();
 	_currentPlayer->newTurn();
 	_server->beginTurn();
+	/// XXX: a good idea could be to set a game loop here !! (beware of not bypassing qt event loop)
+	while( ! _isFinished ) {
+		qApp->processEvents();
+	}
 }
 
 void Engine::endGame()
 {
+	_isFinished = true;
 	_state = NOT_PLAYING;
 	_server->endGame();
 }
@@ -1076,10 +1235,7 @@ void Engine::slot_endFight( char result )
 		loser = _fight->getDefendLord();
 		winner = _fight->getAttackLord();
 	}
-	/*if( !_isCreature || (loser!=_fight->getDefendLord())){
-		_server->sendLordRemove( loser );
-		loser->removeFromGame();
-	}*/
+	
 	if( _isCreature ) {
 		if( loser == _fight->getDefendLord() ) {
 			GenericCell * cell = _fight->getDefendCell();
@@ -1087,8 +1243,9 @@ void Engine::slot_endFight( char result )
 			GenericMapCreature * creature = cell->getCreature();
 			cell->setCreature( 0 );
 			_creatures.remove(creature);
-			//delete( creature );
-			manageFightExperience( winner );
+			
+			uint experience = _fight->getExperience( winner );
+			manageIncreaseExperience( winner, experience );
 		} else {
 			_server->sendLordRemove( loser );
 			loser->removeFromGame();
@@ -1096,7 +1253,8 @@ void Engine::slot_endFight( char result )
 	} else {
 		_server->sendLordRemove( loser );
 		loser->removeFromGame();
-		manageFightExperience( winner );
+		uint experience = _fight->getExperience( winner );
+		manageIncreaseExperience( winner, experience );
 	}
 
 	_state = IN_GAME;
@@ -1106,17 +1264,37 @@ void Engine::slot_endFight( char result )
 	_fight = 0;
 }
 
-void Engine::manageFightExperience( GenericLord * winner )
+void Engine::manageIncreaseExperience( GenericLord * lord, uint experience )
 {
-	uint experience = _fight->getExperience( winner );
-	if( experience ) {
-		winner->increaseBaseCharac( EXPERIENCE, experience );
-		/// XXX: checks if level change...
-		_server->sendLordCharac( winner->getOwner(), winner, EXPERIENCE );
+	uint currentLevel, nextLevelExp;
+		
+	currentLevel = DataTheme.lordExperience.computeLevelForExperience( lord->getCharac( EXPERIENCE ) );
+		
+	while( experience > 0 ) {
+		if( currentLevel < DataTheme.lordExperience.getLevelNumber() ) {
+			nextLevelExp = DataTheme.lordExperience.getLevel( currentLevel + 1 );
+			nextLevelExp -= lord->getCharac( EXPERIENCE );
+			
+			if( experience >= nextLevelExp ) {
+				lord->increaseBaseCharac( EXPERIENCE, experience - nextLevelExp );
+				GenericLordModel * model = DataTheme.lords.at( lord->getId() );
+				LordCharac charac = model->getCategory()->getRandomEvolution();
+				lord->increaseBaseCharac( charac, 1 );
+				_server->sendLordCharac( lord->getOwner(), lord, charac );
+				currentLevel++;
+				experience -= nextLevelExp;
+			} else {
+				lord->increaseBaseCharac( EXPERIENCE, experience );
+				_server->sendLordCharac( lord->getOwner(), lord, EXPERIENCE );
+				experience = 0;
+			}				
+		} else {
+			experience = 0;
+		}
 	}
 }
 
-bool Engine::saveGame( QString filename )
+bool Engine::saveGame( const QString & filename )
 {
     	QFile f( filename );
 
@@ -1124,26 +1302,31 @@ bool Engine::saveGame( QString filename )
 		logEE("Could not open file %s for writing\n", filename.latin1() );
 		return false;
 	}
-/*
+	
 	QTextStream ts( &f );
-	_map->save( &ts );
-	ts << _players.count() << endl;
-	for( uint i = 0; i < _players.count(); i++ ) {
-		_players.at(i)->save( &ts );
-	}
+	GameData::save( &ts );
 	f.close();
-*/
-	logEE( "Save not implemented !" );
+	
 	return true;
 }
 
 void Engine::newDay()
 {
+	uint index;
+	GenericPlayer * tempPlayer; 
+
 	_calendar->newDay();
 	if( _calendar->getDay() == 1 ) {
 		// new week
 		for( uint i = 0; i < _bases.count(); ++i ) {
 			_bases.at( i )->initCreatureProduction();
+			_bases.at( i )->getPopGrowth();
+			for( index = 0; index < _players.count(); index++ ) {
+				tempPlayer = _players.at( index );
+				if( tempPlayer->canSee( _bases.at( i )->getCell() ) ) {
+					_server->sendBasePopulation( _bases.at( i ) , tempPlayer );
+				}
+			}
 		}
 	}
 }
@@ -1151,6 +1334,12 @@ void Engine::newDay()
 
 void Engine::nextPlayer()
 {
+	if( ! enoughPlayers() ) {
+		endGame();
+		return;
+	}
+
+	checkMainQuest();
 	_counter=0;
 	uint num = _players.find( _currentPlayer );
 	num++;
@@ -1160,44 +1349,39 @@ void Engine::nextPlayer()
 	} else {
 		_currentPlayer = _players.at( num );
 	}
-
+  
+	/// XXX: could happen ?
 	if( ! _currentPlayer->isAlive() ) {
 		nextPlayer();
+		return;
 	}
-
-	if( ! _currentPlayer->hasLost() ) {
-		_server->setCurrentPlayer( _currentPlayer );
-		uint i;
-
-
-		for( i = 0; i < _currentPlayer->numBuilding(); i++ ) {
-			handleBuildingTurn( _currentPlayer, _currentPlayer->getBuilding( i ) );
-		}
-		for( i = 0; i < _currentPlayer->numBase(); i++ ) {
-			handleBaseTurn( _currentPlayer, _currentPlayer->getBase( i ) );
-		}
-		for( i = 0; i < _currentPlayer->numLord(); i++ ) {
-			handleCreatTurn( _currentPlayer, _currentPlayer->getLord( i ) );
-		}
-		//if( _calendar->getDay() == 1 ) {
-		//	_currentPlayer->newWeek();
-		//}
-		_currentPlayer->newTurn();
-		_server->beginTurn();
-	} else {
+	if( ( _currentPlayer->numBase() == 0 ) and ( _currentPlayer->numLord() == 0 ) ) {
+		_currentPlayer->setAlive( false );
 		_server->playerLose( _currentPlayer );
-		// XXX: add better test for end of game (quests, and so on)
-		if( ( getAlivePlayersNumber() < 2 ) && ( getAlivePlayersNumber() < _players.count() ) ) {
-			endGame();
-		} else {
-			nextPlayer();
-		}
+		nextPlayer();
+		return;
 	}
+	_server->setCurrentPlayer( _currentPlayer );
+	uint i;
+
+	for( i = 0; i < _currentPlayer->numBuilding(); i++ ) {
+		handleBuildingTurn( _currentPlayer, _currentPlayer->getBuilding( i ) );
+	}
+	for( i = 0; i < _currentPlayer->numBase(); i++ ) {
+		handleBaseTurn( _currentPlayer, _currentPlayer->getBase( i ) );
+	}
+	for( i = 0; i < _currentPlayer->numLord(); i++ ) {
+		handleCreatTurn( _currentPlayer, _currentPlayer->getLord( i ) );
+	}
+	_currentPlayer->newTurn();
+	_server->beginTurn();
+	checkMainQuest();
+	//checkPlayerQuests();
 }
 
 void Engine::handleBuildingTurn( GenericPlayer * player, GenericBuilding * building )
 {
-	QList<Action> list = building->getActionList( Action::DATE );
+	QPtrList<Action> list = building->getActionList( Action::DATE );
 	for( uint i = 0; i < list.count(); i++ ) {
 		handleBuildingAction( list.at( i ), player );
 	}
@@ -1208,12 +1392,12 @@ void Engine::handleBaseTurn( GenericPlayer * player, GenericBase * base )
 	
 	for( uint i = 0; i < base->getBuildingCount(); i++ ) {
 		GenericInsideBuilding * inbuil = base->getBuilding(i);
-		for( uint j = 0; j < MAX_RESS; j++ ) {
+		for( uint j = 0; j < DataTheme.resources.count(); j++ ) {
 			player->decreaseResource( j,inbuil->getMantCost(j));
 			_server->sendPlayerResource( j, player->getResource(j)  );
 		}
 	}
-	for( uint j = 0; j < MAX_RESS; j++ ) {
+	for( uint j = 0; j < DataTheme.resources.count(); j++ ) {
 		player->increaseResource( j, base->collectRessource(j));
 		_server->sendPlayerResource( j, player->getResource(j)  );
 	}
@@ -1224,13 +1408,26 @@ void Engine::handleCreatTurn( GenericPlayer * player, GenericLord * lord )
 	for( uint i = 0; i < MAX_UNIT; i++ ) {
 		GenericFightUnit * unit = lord->getUnit(i);
 		if( unit ) {
-			for( uint j = 0; j < MAX_RESS; j++ ) {
-				int mant = ( unit->getMantCost( j ) * unit->getNumber() );
-				player->decreaseResource( j, mant );
-				_server->sendPlayerResource( j, player->getResource( j )  );
+			for( uint j = 0; j < DataTheme.resources.count(); j++ ) {
+				if(unit->getMantCost (j)) {
+					int mant = ( unit->getMantCost( j ) * unit->getNumber() );
+#if 0
+					int ress = player->getResource(j);
+					uint decr = (mant - ress) / unit->getMantCost( j ) ;
+					decr = decr > 0 ? decr : 0;
+					if (decr > 0) {
+						decr = decr > unit->getNumber() ? unit->getNumber() : unit->getNumber()-decr;
+						unit->setNumber(decr);
+						lord->setUnit(i,unit);
+					}
+#endif	
+					player->decreaseResource( j, mant );
+					_server->sendPlayerResource( j, player->getResource( j )  );
+				}
 			}
 		}
 	}
+	//_server->updateUnits(lord);
 }
 
 void Engine::handleBuildingAction( Action * action, GenericPlayer * player )
@@ -1252,7 +1449,34 @@ void Engine::handleBuildingAction( Action * action, GenericPlayer * player )
 	}
 }
 
-bool Engine::loadGame( QString filename )
+bool Engine::loadCampaign( const QString & filename )
+{
+	bool ret = true;
+	
+	if( _campaign ) {
+		delete _campaign;
+	}
+	_campaign = new Campaign();
+	
+	CampaignParser handler( _campaign );
+	QFile file( filename );
+	QXmlInputSource source( file );
+	QXmlSimpleReader reader;
+	reader.setContentHandler( &handler );
+	reader.setErrorHandler( &handler );
+	bool ok = reader.parse( source );
+	file.close();
+	if( ! ok ) {
+		delete _campaign;
+		_campaign = 0;
+		logEE( "Parse Error (%s) : %s", filename.latin1(), handler.errorProtocol().latin1() );
+		ret = false;
+	}
+	
+	return ret;
+}
+
+bool Engine::loadGame( const QString & filename, bool silent )
 {
 	for( uint i = 0; i < _players.count(); i++ )
 	{
@@ -1275,15 +1499,18 @@ bool Engine::loadGame( QString filename )
 		return false;
 	}
 
-	if( _players.count() != (uint)_nbPlayer ) {
-		QMessageBox::critical( 0, tr( "Error with scenario" ), tr( "Wrong number of connected players" ) );
+	if( _players.count() != (uint) _nbPlayer ) {
+		if(!silent){
+			QMessageBox::critical( 0, tr( "Error with scenario" ), tr( "Wrong number of connected players" ) );
+			for( uint i = 0; i < _players.count(); i++ ) {
+				_currentPlayer = _players.at( i );
+				logDD( "replayers %d ", _players.count());
+				logDD( "relords %d ", _currentPlayer->numLord()  );
+			}
+		}
+		_tmpPlay = _nbPlayer - _players.count();
 		_state = NOT_PLAYING;
 		GameData::reinit();
-		for( uint i = 0; i < _players.count(); i++ ) {
-			_currentPlayer = _players.at( i );
-			logDD( "replayers %d ",  _players.count());
-			logDD( "relords %d ",_currentPlayer->numLord()  );
-		}
 		return false;
 	} else {
 		return true;
@@ -1303,7 +1530,25 @@ uint Engine::getAlivePlayersNumber()
 	return ret;
 }
 
-void Engine::updateMapVision( QList<GenericCell> & removed, QList<GenericCell> & added )
+bool Engine::enoughPlayers()
+{
+	uint ret = 0;
+	uint num = _players.count();
+
+	ret = getAlivePlayersNumber();
+	
+	if( num == 1 && ret == 1 ) {
+		 return true;
+	}
+	
+	if( num > 1 && ret > 1 ) {
+		return true;
+	}
+
+	return false; 
+}
+
+void Engine::updateMapVision( QPtrList<GenericCell> & removed, QPtrList<GenericCell> & added )
 {
 	for( uint i = 0; i < added.count(); i++ ) {
 		GenericCell * cell = added.at( i );
@@ -1394,4 +1639,44 @@ Engine::CreatureAction Engine::computeCreatureAction( GenericMapCreature * creat
 	return ret;
 }
 
+void Engine::checkMainQuest()
+{
+	QuestData data;
+	QuestCondition * failCondition, * successCondition;
+
+	if( not _isFinished ) {
+		data.setPlayer( _currentPlayer );
+	
+		Quest * main = _quests->getMainQuest();
+	
+		if( main ) {
+			failCondition = main->getFailCondition();
+			successCondition = main->getSuccessCondition();
+	
+			uint nbLord = _currentPlayer->numLord();
+			for( uint i = 0; i < nbLord; i++ ) {
+				data.setLord( _currentPlayer->getLord( i ) );
+	
+				if( failCondition ) {
+					if( failCondition->check( &data ) ) {
+						_currentPlayer->setAlive( false );
+						_server->playerLose( _currentPlayer );
+						if( ! enoughPlayers() ) {
+							endGame();
+						}
+						return;
+					}
+				}
+	
+				if( successCondition ) {
+					if( successCondition->check( &data ) ) {
+						_server->playerWin( _currentPlayer );
+						endGame();
+						return;
+					}
+				}
+			}
+		}
+	}
+}
 
